#
# spec file for package gtk3
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2010 Dominique Leuenberger, Amsterdam, Netherlands
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without broadway
%bcond_with    clouds
%bcond_with    tests

%define _name gtk
# When updating the binary version, please do not forget to also update the
# baselibs.conf file accordingly.
%define binary_version 3.0.0
%define _immoduledir %{_libdir}/gtk-3.0/%{binary_version}/immodules
# Filter out provides for private modules
%define __provides_exclude_from ^%{_libdir}/gtk-3.0

Name:           gtk3
Version:        3.24.48
Release:        4.2
Summary:        The GTK+ toolkit library (version 3)
License:        LGPL-2.1-or-later
Group:          Development/Libraries/X11
URL:            https://www.gtk.org/
Source0:        %{_name}-%{version}.tar.xz
Source1:        README.SUSE
Source2:        settings.ini
Source3:        macros.gtk3
Source99:       baselibs.conf
# PATCH-FIX-OPENSUSE gtk3-GTK_PATH64.patch sbrabec@novell.com - 64-bit dual install. Use GTK_PATH64 environment variable instead of GTK_PATH
Patch0:         gtk3-GTK_PATH64.patch
# PATCH-FIX-OPENSUSE gtk3-revert-forced-xftdpi.patch fvogt@opensuse.org -- Revert very controversal commit on GTK3, forcing DPI to 96
Patch1:         gtk3-revert-forced-xftdpi.patch

BuildRequires:  cups-devel >= 1.7
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  fdupes
BuildRequires:  gettext-devel >= 0.19.7
BuildRequires:  gtk-doc
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(atk) >= 2.15.1
BuildRequires:  pkgconfig(atk-bridge-2.0)
BuildRequires:  pkgconfig(cairo) >= 1.14.0
BuildRequires:  pkgconfig(cairo-gobject) >= 1.14.0
BuildRequires:  pkgconfig(colord) >= 0.1.9
BuildRequires:  pkgconfig(epoxy) >= 1.4
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(fribidi)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) >= 2.30.0
BuildRequires:  pkgconfig(gio-2.0) >= 2.53.4
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.53.4
BuildRequires:  pkgconfig(glib-2.0) >= 2.57.2
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.39.0
BuildRequires:  pkgconfig(harfbuzz) >= 0.9
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(pango) >= 1.41.0
BuildRequires:  pkgconfig(pangoft2)
BuildRequires:  pkgconfig(wayland-client) >= 1.14.91
BuildRequires:  pkgconfig(wayland-cursor) >= 1.14.91
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(wayland-protocols) >= 1.14
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xkbcommon) >= 0.2.0
BuildRequires:  pkgconfig(xrandr)
# Enable cloudproviders once upstream settles on a location and version
%if %{with clouds}
BuildRequires:  pkgconfig(cloudproviders) >= 0.2.5
%endif

%description
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

%package -n libgtk-3-0
Summary:        The GTK+ toolkit library (version 3)
Group:          System/Libraries
Requires:       %{name}-data >= %{version}
Requires:       %{name}-schema >= %{version}
# Require gdk-pixbuf-loader-rsvg - bsc#1007453. We require adwaita-icon-theme
# so we need something to load the svg icons.
Requires:       gdk-pixbuf-loader-rsvg
# While hicolor is not a Requires strictly speaking, we put it as
# such instead of as a Recommends because many applications just
# assume it's there and we need to have a low-level package to
# bring it in.
Requires:       hicolor-icon-theme
Requires(post): %{name}-tools
# gtk+ can work without branding/translations. Built in defaults will be used then.
Recommends:     %{name}-branding
# it's nice to have input modules for various locales installed by default
Recommends:     %{name}-immodule-amharic = %{version}
Recommends:     %{name}-immodule-inuktitut = %{version}
Recommends:     %{name}-immodule-thai = %{version}
Recommends:     %{name}-immodule-tigrigna = %{version}
Recommends:     %{name}-immodule-vietnamese = %{version}
# Recommend Adwaita Icon Theme: GTK3 references this icon set in the code,
# but some setups might still want to eliminate it (think limited size Live CDs)
Recommends:     adwaita-icon-theme
Recommends:     gvfs
# Provide %%{name} to make the lang and immodules packages installable
Provides:       %{name} = %{version}
# Before 3.0, the package was actually libgtk-3_0-0 and files might
# conflict
Provides:       libgtk-3_0-0 = %{version}
Obsoletes:      libgtk-3_0-0 < %{version}

%description -n libgtk-3-0
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

%package -n typelib-1_0-Gtk-3_0
Summary:        Introspection bindings for the GTK+ toolkit library (version 3)
Group:          System/Libraries
Requires:       (python3-gobject-Gdk if python3-gobject)
Requires:       (python310-gobject-Gdk if python310-gobject)
Requires:       (python38-gobject-Gdk if python38-gobject)
Requires:       (python39-gobject-Gdk if python39-gobject)

%description -n typelib-1_0-Gtk-3_0
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

This package provides the GObject Introspection bindings for GTK+.

%package immodule-amharic
Summary:        Amharic input method for the GTK+ toolkit library v3
Group:          System/Libraries
Requires:       %{name} = %{version}
Requires(post): %{name}-tools
Requires(postun): %{name}-tools
Provides:       locale(%{name}:am)

%description immodule-amharic
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

This package provides an input method for Amharic.

%package immodule-broadway
Summary:        Broadway input method for the GTK+ toolkit library v3
Group:          System/Libraries
Requires:       %{name} = %{version}
Requires(post): %{name}-tools
Requires(postun): %{name}-tools

%description immodule-broadway
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

This package provides an input method for Broadway.

%package immodule-inuktitut
Summary:        Inuktitut input method for the GTK+ toolkit library v3
Group:          System/Libraries
Requires:       %{name} = %{version}
Requires(post): %{name}-tools
Requires(postun): %{name}-tools
Provides:       locale(%{name}:iu)

%description immodule-inuktitut
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

This package provides an input method for Inuktitut.

%package immodule-multipress
Summary:        Multipress input method for the GTK+ toolkit library v3
Group:          System/Libraries
Requires:       %{name} = %{version}
Requires(post): %{name}-tools
Requires(postun): %{name}-tools

%description immodule-multipress
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

This package provides an input method which allows text entry via the
multi-press method, as on a mobile phone.

%package immodule-thai
Summary:        Thai-Lao input method for the GTK+ toolkit library v3
Group:          System/Libraries
Requires:       %{name} = %{version}
Requires(post): %{name}-tools
Requires(postun): %{name}-tools
Provides:       locale(%{name}:lo)
Provides:       locale(%{name}:th)

%description immodule-thai
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

This package provides an input method for Thai-Lao.

%package immodule-tigrigna
Summary:        Tigrigna input method for the GTK+ toolkit library v3
Group:          System/Libraries
Requires:       %{name} = %{version}
Requires(post): %{name}-tools
Requires(postun): %{name}-tools
Provides:       %{name}-immodules-tigrigna = %{version}
Provides:       locale(%{name}:ti)
Obsoletes:      %{name}-immodules-tigrigna < %{version}

%description immodule-tigrigna
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

This package provides two input methods for Tigrigna.

%package immodule-vietnamese
Summary:        Vietnamese input method for the GTK+ toolkit library v3
Group:          System/Libraries
Requires:       %{name} = %{version}
Requires(post): %{name}-tools
Requires(postun): %{name}-tools
Provides:       locale(%{name}:vi)

%description immodule-vietnamese
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

This package provides an input method for Vietnamese.

%package immodule-wayland
Summary:        Wayland input method for the GTK+ toolkit library (version 3)
Group:          System/Libraries
Requires:       %{name} = %{version}
Requires(post): %{name}-tools
Requires(postun): %{name}-tools

%description immodule-wayland
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

This package provides an input method which allows text entry via
wayland.

%package immodule-xim
Summary:        X input method for the GTK+ toolkit library v3
Group:          System/Libraries
Requires:       %{name} = %{version}
Requires(post): %{name}-tools
Requires(postun): %{name}-tools
Provides:       locale(%{name}:ja)
Provides:       locale(%{name}:ko)
Provides:       locale(%{name}:th)
Provides:       locale(%{name}:zh)

%description immodule-xim
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

This package provides an input method based on the X Input Method.

%package tools
Summary:        Auxiliary utilities for the GTK+ toolkit library v3
Group:          System/Libraries

%description tools
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

%package data
Summary:        Data files for the GTK+ toolkit library v3
Group:          System/Libraries
BuildArch:      noarch

%description data
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

%package schema
Summary:        Config schema for the GTK+ toolkit library v3
Group:          System/Libraries
BuildArch:      noarch

%description schema
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

%package branding-upstream
Summary:        Upstream theme configuration for the GTK+ toolkit library v3
Group:          System/Libraries
Requires:       libgtk-3-0 = %{version}
Supplements:    (%{name} and branding-upstream)
Conflicts:      %{name}-branding
Provides:       %{name}-branding = %{version}
BuildArch:      noarch
#BRAND: Provides /etc/gtk-3.0/settings.ini, to define default theme and icon
#BRAND: theme.
#BRAND: Do not forget to add proper Requires in branding package if changing
#BRAND: those.

%description branding-upstream
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

This package provides the upstream theme configuration for widgets and
icon themes.

%package devel
Summary:        Development files for the GTK+ toolkit library v3
Group:          Development/Libraries/X11
Requires:       gettext-its-%{name} >= %{version}
Requires:       libgtk-3-0 = %{version}
Requires:       typelib-1_0-Gtk-3_0 = %{version}

%description devel
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

This package contains the development files for GTK+ 3.x.

%package -n gettext-its-%{name}
Summary:        International Tag Set for GTK+ 3
Group:          Development/Libraries/X11
BuildArch:      noarch

%description -n gettext-its-%{name}
This package enhances gettext with an International Tag Set for GTK+ 3

%lang_package

%package -n gtk3-devel-doc
Summary:        API documentation for the GTK+ toolkit library v3
Group:          Documentation/HTML
BuildArch:      noarch

%description -n gtk3-devel-doc
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

This package contains the API documentation for GTK+ 3.x.

%prep
%autosetup -N -n %{_name}-%{version}
%if "%{_lib}" == "lib64"
cp -a %{SOURCE1} .
%if !0%{?sle_version}
%autopatch -p1 0
%else
%patch -P 0 -p1
%endif
%endif

%if !0%{?sle_version}
# Apply patches 1 to 999 (1 >= 999)
%autopatch -p1 -m 1 -M 999
%else
%patch -P 1 -p1
%endif

%build
%meson \
    -D broadway_backend=%{?with_broadway:true}%{!?with_broadway:false} \
    -D cloudproviders=%{?with_clouds:true}%{!?with_clouds:false} \
    -D gtk_doc=true \
    -D man=true \
    -D tests=%{?with_tests:true}%{!?with_tests:false} \
    -D builtin_immodules=wayland,waylandgtk \
    ;
%meson_build

%install
%meson_install
%find_lang gtk30
%find_lang gtk30-properties

# Do not install the exampleapp glib schema, as the app itself is noinst
rm -v %{buildroot}%{_datadir}/glib-2.0/schemas/org.gtk.exampleapp.gschema.xml

# Upstream's default UI settings.
install -v -m 644 -D %{SOURCE2} \
  %{buildroot}%{_sysconfdir}/gtk-3.0/settings.ini

# Input Method Modules cache needs to be created in order to be ghosted in the
# files directive, allowing it to be removed along with the package upon
# uninstallation.
touch %{buildroot}%{_libdir}/gtk-3.0/%{binary_version}/immodules.cache

# This hack needs to be done as long as we offer openSUSE 32-bit.
# Maybe upstream could do something about it.
%if "%{_lib}" == "lib64"
  mv -v %{buildroot}%{_bindir}/gtk-query-immodules-3.0 \
        %{buildroot}%{_bindir}/gtk-query-immodules-3.0-64
  mv -v %{buildroot}%{_mandir}/man1/gtk-query-immodules-3.0.1 \
        %{buildroot}%{_mandir}/man1/gtk-query-immodules-3.0-64.1
%endif

# Create modules directory that should have been created during the build
test ! -d %{buildroot}%{_libdir}/gtk-3.0/modules \
  && mkdir -v %{buildroot}%{_libdir}/gtk-3.0/modules

# Create immodules directory that should have been created during the build
test ! -d %{buildroot}%{_libdir}/gtk-3.0/immodules \
  && mkdir -v %{buildroot}%{_libdir}/gtk-3.0/immodules

# Create theming-engines directory that should have been created during the build
test ! -d %{buildroot}%{_libdir}/gtk-3.0/%{binary_version}/theming-engines \
  && mkdir -v %{buildroot}%{_libdir}/gtk-3.0/%{binary_version}/theming-engines

# Install rpm macros
mkdir -p %{buildroot}%{_rpmmacrodir}
cp %{SOURCE3} %{buildroot}%{_rpmmacrodir}

%fdupes %{buildroot}%{_datadir}
%fdupes %{buildroot}%{_libdir}

###########################################################################
# Note: when updating scriptlets, don't forget to also update baselibs.conf
###########################################################################

%if "%_lib" == "lib64"
%define ext_64 -64
%endif
%define __gtk_query_immodules %{_bindir}/gtk-query-immodules-3.0%{?ext_64}
%define __update_iconcache %{_bindir}/gtk-update-icon-cache

# Until RPM (trans)filetriggers gets implemented for ldconfig calls, use
# whatever we got.
%ldconfig_scriptlets -n libgtk-3-0

%filetriggerin tools -- %{_immoduledir}
%__gtk_query_immodules --update-cache \
  || echo "[GTK3] Update IM modules cache: failed"

%filetriggerpostun tools -- %{_immoduledir}
# We ignore upgrades (already handled by the newer package's filetriggerin).
if [ "$1" -eq 0 ]; then
  %__gtk_query_immodules --update-cache \
    || echo "[GTK3] Update IM modules cache: failed"
fi

%filetriggerin tools -- %{_datadir}/icons
if [ -x "%__update_iconcache" ]; then
  for ICON_THEME in $(cut -d / -f 5 | sort -u); do
    if [ -f "%{_datadir}/icons/${ICON_THEME}/index.theme" ]; then
      %__update_iconcache --quiet --force "%{_datadir}/icons/${ICON_THEME}" \
        || echo "[GTK3] Update icons cache: failure to add ${ICON_THEME} icons"
    fi
  done
fi

%filetriggerpostun tools -- %{_datadir}/icons
# We ignore upgrades (already handled by the newer package's filetriggerin).
if [ -x "%__update_iconcache" ]; then
  for ICON_THEME in $(cut -d / -f 5 | sort -u); do
    if [ -f "%{_datadir}/icons/${ICON_THEME}/index.theme" ]; then
      %__update_iconcache --quiet --force "%{_datadir}/icons/${ICON_THEME}" \
        || echo "[GTK3] Update icons cache: failure to remove ${ICON_THEME} icons"
    fi
  done
fi

%files -n libgtk-3-0
%license COPYING
%if "%{_lib}" == "lib64"
%doc README.SUSE
%endif
%dir %{_sysconfdir}/gtk-3.0
%dir %{_libdir}/gtk-3.0
%dir %{_libdir}/gtk-3.0/%{binary_version}
%dir %{_immoduledir}
%{_immoduledir}/im-cedilla.so
%{_immoduledir}/im-cyrillic-translit.so
%{_immoduledir}/im-ipa.so
%dir %{_libdir}/gtk-3.0/%{binary_version}/printbackends/
%{_libdir}/gtk-3.0/%{binary_version}/printbackends/libprintbackend-cups.so
%{_libdir}/gtk-3.0/%{binary_version}/printbackends/libprintbackend-file.so
%{_libdir}/gtk-3.0/%{binary_version}/printbackends/libprintbackend-lpr.so
%dir %{_libdir}/gtk-3.0/%{binary_version}/theming-engines/
%ghost %{_libdir}/gtk-3.0/%{binary_version}/immodules.cache
%dir %{_libdir}/gtk-3.0/modules
%{_libdir}/libgailutil-3.so.*
%{_libdir}/libgdk-3.so.*
%{_libdir}/libgtk-3.so.*

%files -n typelib-1_0-Gtk-3_0
%{_libdir}/girepository-1.0/Gdk-3.0.typelib
%{_libdir}/girepository-1.0/GdkX11-3.0.typelib
%{_libdir}/girepository-1.0/Gtk-3.0.typelib

%files immodule-amharic
%{_immoduledir}/im-am-et.so

%files immodule-broadway
%{_immoduledir}/im-broadway.so

%files immodule-inuktitut
%{_immoduledir}/im-inuktitut.so

%files immodule-multipress
%doc modules/input/README.multipress
%{_immoduledir}/im-multipress.so
%config %{_sysconfdir}/gtk-3.0/im-multipress.conf

%files immodule-thai
%{_immoduledir}/im-thai.so

%files immodule-tigrigna
%{_immoduledir}/im-ti-er.so
%{_immoduledir}/im-ti-et.so

%files immodule-vietnamese
%{_immoduledir}/im-viqr.so

%files immodule-xim
%{_immoduledir}/im-xim.so

%files tools
%doc README.md NEWS
%{_bindir}/broadwayd
%{_bindir}/gtk3-icon-browser
%{_bindir}/gtk-builder-tool
%{_bindir}/gtk-encode-symbolic-svg
%{_bindir}/gtk-launch
%{_bindir}/gtk-query-immodules-3.0*
%{_bindir}/gtk-query-settings
%{_bindir}/gtk-update-icon-cache
%{_datadir}/applications/gtk3-icon-browser.desktop
%{_mandir}/man1/broadwayd.1%{?ext_man}
%{_mandir}/man1/gtk3-icon-browser.1%{?ext_man}
%{_mandir}/man1/gtk-builder-tool.1%{?ext_man}
%{_mandir}/man1/gtk-encode-symbolic-svg.1%{?ext_man}
%{_mandir}/man1/gtk-launch.1%{?ext_man}
%{_mandir}/man1/gtk-query-immodules-3.0*.1%{?ext_man}
%{_mandir}/man1/gtk-query-settings.1%{?ext_man}
%{_mandir}/man1/gtk-update-icon-cache.1%{?ext_man}
%dir %{_datadir}/gtk-3.0/
%dir %{_datadir}/gtk-3.0/emoji
%{_datadir}/gtk-3.0/emoji/*.gresource

%files schema
%{_datadir}/glib-2.0/schemas/org.gtk.Settings.ColorChooser.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gtk.Settings.EmojiChooser.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gtk.Settings.FileChooser.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gtk.Settings.Debug.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gtk.Demo.gschema.xml

%files data
%{_datadir}/locale/en/
%{_datadir}/themes/Default/
%{_datadir}/themes/Emacs/

%files branding-upstream
%config(noreplace) %{_sysconfdir}/gtk-3.0/settings.ini

%files devel
%doc CONTRIBUTING.md
%{_bindir}/gtk3-demo
%{_bindir}/gtk3-demo-application
%{_bindir}/gtk3-widget-factory
%{_mandir}/man1/gtk3-demo.1%{?ext_man}
%{_mandir}/man1/gtk3-demo-application.1%{?ext_man}
%{_mandir}/man1/gtk3-widget-factory.1%{?ext_man}
%{_datadir}/aclocal/gtk-3.0.m4
%{_datadir}/applications/gtk3-demo.desktop
%{_datadir}/applications/gtk3-widget-factory.desktop
%{_datadir}/gir-1.0/*.gir
%{_datadir}/gtk-3.0/gtkbuilder.rng
%dir %{_datadir}/gtk-3.0/valgrind
%{_datadir}/gtk-3.0/valgrind/gtk.supp
%{_datadir}/icons/hicolor/*/apps/gtk3-demo.png
%{_datadir}/icons/hicolor/*/apps/gtk3-widget-factory.png
%{_datadir}/icons/hicolor/*/apps/gtk3-demo-symbolic.symbolic.png
%{_datadir}/icons/hicolor/*/apps/gtk3-widget-factory-symbolic.symbolic.png
%{_includedir}/gail-3.0/
%{_includedir}/gtk-3.0/
%{_libdir}/pkgconfig/gail-3.0.pc
%{_libdir}/pkgconfig/gdk-3.0.pc

%if %{with broadway}
%{_libdir}/pkgconfig/gdk-broadway-3.0.pc
%{_libdir}/pkgconfig/gtk+-broadway-3.0.pc
%endif

%{_libdir}/pkgconfig/gdk-wayland-3.0.pc
%{_libdir}/pkgconfig/gtk+-wayland-3.0.pc
%{_libdir}/pkgconfig/gdk-x11-3.0.pc
%{_libdir}/pkgconfig/gtk+-3.0.pc
%{_libdir}/pkgconfig/gtk+-unix-print-3.0.pc
%{_libdir}/pkgconfig/gtk+-x11-3.0.pc
%{_libdir}/libgailutil-3.so
%{_libdir}/libgdk-3.so
%{_libdir}/libgtk-3.so
%{_rpmmacrodir}/macros.gtk3

%files -n gettext-its-%{name}
%dir %{_datadir}/gettext/
%dir %{_datadir}/gettext/its/
%{_datadir}/gettext/its/gtkbuilder.its
%{_datadir}/gettext/its/gtkbuilder.loc

%files lang -f gtk30.lang -f gtk30-properties.lang
# English locale should be in the main package
%exclude %{_datadir}/locale/en

%files -n gtk3-devel-doc
%doc %{_datadir}/gtk-doc/html/gail-libgail-util3/
%doc %{_datadir}/gtk-doc/html/gdk3/
%doc %{_datadir}/gtk-doc/html/gtk3/

%changelog
* Mon Feb  3 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Fix %%filetriggerpostun for icon cache: ensure the icons that have
  just been removed are also cleared from the cache. We can't
  shortcut on upgrades, even though this would be nice. In context
  of RPM 4.20 this started breaking (boo#1236740).
* Sat Jan 25 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.24.48:
  + GtkFileChooser: Stop replacing : (colon) with U+2236 (ratio)
  + GtkEmojiChooser: Update to Unicode 16 / CLDR 46
  + GtkSpinButton:
  - Use semantically appropriate icon names
  - Make numeric spin buttons always LTR
  + GtkEntry:
  - Stop guessing text direction from keyboard layout
  - Add a shortcut and context menu item to change text direction
  + GtkEventControllerMotion: Make enter and leave signals work
  + Accessibility: Use message dialog titles as names
  + GDK: Fix portal handling of gvfs files
  + Wayland:
  - Support the xdg_foreign_v2 protocol
  - Try to fix monitor geometry on sway
  - Improve font setting fallback
  - Use a better default cursor size
  - Fix a crash during DND
  + Updated translations.
* Thu Oct 17 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Eliminate usage of update-alternatives: GTK2 no longer provides
  gtk-update-icon-cache, thus eliminating the need for this extra
  complexity.
* Thu Jul 11 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.24.43:
  + Stop looking for modules in cwd (bsc#1228120 CVE-2024-6655).
  + Updated translations.
* Thu May 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.24.42:
  + GtkFileChooser:
  - Avoid warnings about floating refs.
  - Improve performance of recursive search.
  - Populate search model in an idle.
  + GtkGLArea: Fix a regression in transparency handling.
  + Printing: Avoid accessing freed printers.
  + Accessibility: Drop support for the deprecated
    atk_focus_tracker.
  + Wayland:
  - Fix monitor sizes.
  - Fix a crash related to tablet removal.
  - Infer resizable edges for tiled windows.
  - Always commit soon after acking a configure.
  + gdk:
  - Use css cursor names as far as possible.
  - Sync DND cursor use with GTK4.
  + build: Allow building against sysprof-capture-4.
  + Updated translations.
* Mon Apr 15 2024 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire gettext-devel instead of gettext-tools-mini: the
  - devel provides is part of gettext-tools, but this allows OBS to
  pick the package it deems correct.
* Thu Jan 25 2024 dimstar@opensuse.org
- Update to version 3.24.41:
  + Fix a crash introduced in the X11 changes in 3.24.40.
  + Build fixes.
  + Wayland: Fix interpretation of gtk-shell protocol.
* Thu Jan 18 2024 dimstar@opensuse.org
- Update to version 3.24.40:
  * Free monitor name on finalize
  * Rework after first review
  * Rework to get rid of get_monitor_by_output
  * Use xorg 'monitor' the right way. See #2013
* Tue Jan 16 2024 dimstar@opensuse.org
- Update to version 3.24.39+23:
  * gdkdisplay-wayland: Init selection before roundtrips
  * Use consistent coordinates in get_toplevel_from_ns_event.
  * emoji: Update data to CLDR v44
  * emoji: Update data to CLDR v43
  * add hi-ja-et-fi-nb-th for gtkemojichooser
  * add bengali language bn.data for gtkemojichooser
  * emoji: Add more locales
  * emoji: Update data to CLDR v40
  * emoji: Fix the convert-emoji program
  * gtkgesture: Preserve accuracy when translating events
  * pathbar: Handle webdav where is the root is a path
  * GtkTooltip: Fix tooltip positioning on X11
  * gdkkeys-win32c: change registry key not found g_warning to g_debug
  * [gtk3/wayland] Expose XDG-shell suspended state via visibility events.
  * [gtk3/wayland] Only request v2 of xdg_wm_base.
  * test-msys2-meson: fix pipeline failure on GTK3
  * wayland: Fix wl_buffer size for custom cursors
  * GtkMenu: Fix positioning when attached to offscreen windows
  * gdk_display_get_monitor_at_window: Check for offscreen windows
  * GdkWindow: check for same impl class in set_transient_for ()
  * [gtk3] Cherry-pick gtkfilechoosernativeportal fixes from gtk4
  * wayland: Avoid more legacy cursor names
  * Fall back to the 'default' cursor
* Thu Dec  7 2023 dimstar@opensuse.org
- Update to version 3.24.38+111:
  + [gtk3] Support tiled windows from xdg-shell.
  + Fix a minor issue in the file portal test.
  + wayland: Be more careful when loading cursors.
  + gdk/wayland: Use g_warning_once for cursor scale mismatches.
  + gdk/wayland: Don't fall back directly to 1 for mismatched
    cursor sizes.
  + Updated translations.
- Drop upstream applied patch
  gtk3-gtkmountoperation-avoid-SEGV-after-bad-password-inpu.patch
* Tue Nov 28 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -p N instead of deprecated %%patchN.
* Sun Oct  8 2023 Yifan Jiang <yfjiang@suse.com>
- Revert RPM ternary operations on SLE where rpm version is not
  ready.
* Tue Sep 12 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Use RPM ternary operations to specify true/false arguments based
  on build conditions (%%[%%{with FOO} ? "true" : "false"])
* Mon Aug 14 2023 Yifan Jiang <yfjiang@suse.com>
- Do not use %%autopatch to build on SLE where rpm version is not
  ready for the macro.
* Fri Jun  2 2023 Martin Wilck <mwilck@suse.com>
- Fix nautilus crash after entering wrong SMB password (bsc#1211952)
  * add gtk3-gtkmountoperation-avoid-SEGV-after-bad-password-inpu.patch
* Mon May 22 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.24.38:
  + GtkFileChooser: Avoid warnings with GLib 2.76.
  + Theme: Set caret color in the dark theme.
  + Windows: Fix running under GLES.
  + Wayland:
  - Notify on initial setting changes.
  - Don't crash on 0 size cursors.
  - Don't crash if xdg_activation_v1 is missing.
  + Debugging: Show more information in the inspector.
  + Updated translations.
* Mon May  1 2023 bjorn.lie@gmail.com
- Update to version 3.24.37+70:
  + Fix a crash.
* Wed Apr 26 2023 bjorn.lie@gmail.com
- Update to version 3.24.37+68:
  + application: Clean up signal handlers
  + OLE2 DND: Check if move is supported
  + Address issue 5711 by checking that the context is not NULL
  + wayland:
  - Don't crash without xdg_activation_v1
  - Don't crash on cursor size 0
  + gdkscreen-wayland: Notify initial setting change from
    org.gtk.Settings
  + gdk: Swap Cairo calls when reading back from a GdkWindow
  + Updated translations.
* Mon Apr 10 2023 Luciano Santos <luc14n0@opensuse.org>
- Deprecate %%gtk_immodule_(requires|post|postun) macros defined in
  the macros.gtk3 file. Since we are using RPM file triggers to
  provide their functionality, without nullifying them the commands
  will run twice, once by the file triggers and another time by the
  macros.
* Tue Mar 21 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Re-add macros.gtk3: there are quite a few consumers left
  requiring the defined macros.
* Tue Mar  7 2023 Luciano Santos <luc14n0@opensuse.org>
- Prepend gtk3 to binary_version and _immoduledir macro names to
  avoid possible name clash now that they are being defined in the
  macros.gtk3 file instead of the spec file.
* Fri Mar  3 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.24.37:
  + Support the file transfer portal for copy-paste and DND
  + Treat XKB_MODE_NAME_LODO as super key
  + Refactor startup notification handling to be in sync with GTK 4
  + GL: Synchronie when calling MakeCurrent
  + CSS: Fix a problem with stopping animations
  + Wayland: Drop the legacy text input module
  + Updated translations.
* Thu Dec 29 2022 Luciano Santos <luc14n0@opensuse.org>
- Update to version 3.24.36:
  + GtkLabel: Tweak selection behavior.
  + GtkEmojiChooser: Properly handle empty recent section.
  + GtkFileChooser: Make ~ key work regardless of dead keys.
  + Wayland:
  - Fix problems with X<>Wayland DND.
  - Revert cursor changes from 3.24.35.
  - Fix handling of surrounding text in input.
  + Updated translation.
- Switch from Autotools to Meson, dropping libtool build
  requirement while adding meson and ninja. And replace configure,
  make_build, and make_install macros with meson, meson_build and
  meson_install.
- Adopt the use of autosetup and autopatch macro facilities to
  improve package maintainability.
- Drop multibuild facility due to the fact that Gtk 3 Meson build
  scripts can't fully disable some components. And, at least for
  now, we cannot achieve the same degree of modularity we had with
  Autotools.
- Drop macros.gtk3 file as no package (if it ever had any) consumes
  its macros.
- After switching to Meson, the build doesn't produce a Wayland
  Input Method module anymore, at least not as a standalone. Update
  baselibs.conf accordingly. And some GResource files are now being
  provided in the devel package for working with emojis.
- Define __provides_exclude_from macro with ^%%{_libdir}/gtk-3.0 as
  its value to prevent the automatic provision generator to offer
  private modules as requirable symbols.
- Make cloudproviders to be easily switchable, through bcond
  facility, to allow people to test it, or for maintainers to turn
  it on and off easily.
- Make gettext-its-gtk3 and gtk3-devel-doc sub-packages
  arch-independent (noarch), as they don't contain any binaries.
- Convert IM modules cache update post(un) scriptlets to RPM
  file triggers. Though we had good results with icon cache update
  scriptlets previously, we still can't use transfiletriggers to
  trigger the cache update only once, post transaction, because
  Zypper is still working on implementing support for them.
- Refresh patch with Quilt: gtk3-revert-forced-xftdpi.patch.
* Mon Dec  5 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.24.35+10:
  + Flush drawable surface when getting a pixbuf.
  + wayland: Look for cursor themes in $HOME (boo#1206001).
* Wed Nov 30 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.24.35:
  + GtkFontChooserWidget: Fix a critical.
  + GtkAccelLabel: Differentiate keypad keysyms in accelerators.
  + Input:
  - Recognize stylus devices as pens.
  - Fix problems with motion compression.
  + Windows: Build system improvements.
  + Wayland:
  - Fix problems with unreliable DND.
  - Use GLES if required.
  - Add support for titlebar gestures.
  - Refactor handling of IM client updates.
  - Fix cursor hotspots with scaled surfaces.
  - Use the xdg-activation protocol.
  - Load cursors on demand.
  - Fix cursor size on hi-dpi displays.
  + MacOS: Use a CVDisplayLink based frame clock.
  + Updated translations.
- Drop upstream merged patch
  gtk3-gdkwayland-Update-selections-offer-before-updating-dnd.patch.
* Fri Sep 23 2022 Fusion Future <qydwhotmail@gmail.com>
- Fix unstable drag-and-drop on Wayland KDE, add:
  * gtk3-gdkwayland-Update-selections-offer-before-updating-dnd.patch
  https://gitlab.gnome.org/GNOME/gtk/-/commit/56100ab4
* Thu Sep  1 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Drop pkgconfig(rest-0.7) BuildRequires: it seems to serve no
  purpose, nor can I find anything to suggest that gtk depends on
  it.
* Mon Aug 15 2022 Dirk Müller <dmueller@suse.com>
- avoid bashism in baselibs postscript (bsc#1195391).
* Mon Jul  4 2022 Yifan Jiang <yfjiang@suse.com>
- Add compatible dependency "python3-gobject-Gdk if python3-gobject"
  to the typelib package for SLE and Leap (boo#1200614).
* Fri Jun 17 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Add dependency "python3x-gobject-Gdk if python3x-gobject" to the
  typelib package (boo#1200614).
* Thu May 19 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 3.24.34:
  + Include legacy hicolor icons.
  + Fix the build with gcc 12.
  + X11: Trap errors when getting output properties.
  + Wayland: Ignore empty preedit updates. This fixes a problem
    with textview scrolling.
  + Updated translations.
* Thu Mar 24 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.24.33+12:
  + icons: add legacy icons (boo#1197480).
  + Updated translations.
* Sat Mar  5 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.24.33:
  + No changes.
* Fri Mar  4 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.24.32:
  + GtkCellRendererProgress: Use tabular figures.
  + GtkFontChooser:
  - Fix the build with older Pango.
  - Fix axis name handling.
  + Theme: Fix border color for tiled windows.
  + Accessibility: Fix cell accessible leak.
  + Wayland:
  - Support new high-contrast setting.
  - Only update scale when on any outputs.
  + Updated translations.
* Tue Dec 21 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.24.31:
  + input: Fix a crash with touch on GtkScale.
  + clipboard: Avoid a double-free.
  + css: Avoid a crash with radial gradients.
  + GtkFileChooser: Don't leak search results.
  + GtkTextView: Support css letterspacing.
  + Wayland:
  - Reset position when hiding popups.
  - Ignore globals we did not bind ourselves.
  - Avoid infinite loops when hiding surfaces.
  - Avoid clipboard-related lockups.
  + X11:
  - Trap errors while doing XRANDR calls.
  - Support touchpad gestures with XI 2.4.
  + Updated translations.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Mon Aug  2 2021 Yifan Jiang <yfjiang@suse.com>
- Drop patch fixed upstream on SLE and Leap 15.4:
  gtk3-x11-fix-menu-touch-by-pointer-emulation.patch
* Fri Jul  9 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.24.30:
  + Input:
  - Ignore NoSymbol key events (happens with some XKB options).
  - Fix incomplete reset in some cases.
  + GtkEmojiChooser:
  - Update data from CLDR 39.
  - Support translated keywords for multiple languages.
  - Allow inserting multiple Emoji with Ctrl.
  - Match keywords for search.
  - Fix a memory leak.
  + GtkFileChooser: Accessibility improvements.
  + GtkTreeView:
  - Fix an accessibility-related memory leak.
  - Fix assertion failures in some cases.
  + Printing: Remove the Google Cloud Print backend, since the
    service was shut down.
  + Wayland: Work with pointer-gestures v1 protocol.
  + Updated translations.
* Fri Apr 23 2021 Michael Gorse <mgorse@suse.com>
- Update to version 3.24.29:
  + Input:
  - Look for a Compose file in the right place.
  - Revert some Compose sequence changes (mainly around dead
    acute and apostrophe).
  - Consume all key events during preedit, to avoid unexpected
    interactions.
  - Ignore more modifiers during preedit, to allow using 3rd and
    5th level choosers.
  - Fix handling of cursor positions in non-ASCII preedit text.
  + GtkSpinButton: Interpret localized digits.
  + GtkScale: Fix sporadic criticals.
  + GtkScrolledWindow:
  - Cancel overshoot on size changes.
  - Avoid criticals with non-overlay scrollbars.
  + GtkFileChooser: Handle smb mounts better.
  + GtkListBox: Fix extending multi-selections.
  + Fix a possible crash in gtk_show_uri.
  + Wayland: Improve font settings fallback.
  + X11:
  - Avoid log spam on exit.
  - Don't beep on untrusted displays.
  + Updated translations.
- Drop gtk3-prevent-g_file_get_basename-return-NULL.patch: fixed
  upstream.
* Thu Apr 22 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.24.28:
  + Input: Improve dead key handling.
  + CSS: Fix rendering of scaled text shadows.
  + Wayland: Fix matching of accelerators with multiple layouts.
  + X11: Trap errors from the COW.
  + Build: Make gtk3-update-icon-cache output reproducible.
  + Updated translations.
* Wed Apr 21 2021 QK ZHU <qkzhu@suse.com>
- Add gtk3-prevent-g_file_get_basename-return-NULL.patch:
  + Fix a possible crash in gtk_show_uri
    (boo#1185082, glgo#GNOME/gtk!3458).
* Wed Mar 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.24.27:
  + Input: Ensure preedit-start and preedit-end are emitted
    properly.
  + GtkScrolledWindow: Revert a change that broke touch scrolling.
  + Theme:
  - Fix a problem with size changes in SSD decorations that
    caused mutter crashes
  - Use transparent black for window border in the dark theme.
  + Updated translations.
* Fri Feb 26 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.24.26:
  + Input:
  - Fix a few oversights in Compose file parsing.
  - Fine-tune Compose preedit display.
  + Theme:
  - Fine-tune scrollbar size and transitions.
  - Reinstate invisible borders for tiled windows.
  + Wayland: Fix a problem with font settings not being found.
  + Updated translations.
* Fri Feb 12 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.24.25:
  + Settings: Make cursor aspect ratio setting work.
  + Broadway:
  - Fix touchscreen event handling.
  - Support Android / Chrome on-screen keyboard.
  + Wayland:
  - Avoid crashes with tablet input.
  - Add api to support clients with subsurfaces better.
  + Inspector: Make the inspector available in non-debug builds.
  + Theme:
  - Make scrollbars larger.
  - Disable shadows on maximized, fullscreen and tiled windows.
  + Printing: Support Avahi-discovered printers better.
  + Input:
  - Show preedit for compose sequences.
  - Support long compose sequences.
  - Support compose sequences producing multiple characters.
  + Updated translations.
* Mon Dec  7 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.24.24:
  + GtkColorChooser: Update the default color palette.
  + GtkFontChooser: Fix family-only mode to return regular style.
  + GtkTreeView: Don't set focus-on-click for header buttons.
  + Accessibility:
  - Implement scrollSubstringTo.
  - Add a11y support to GtkPlug/GtkSocket.
  + Printing: Allow the lpr backend to print pdf and ps files.
  + Theme:
  - Update gesture graphics.
  - Update HighContrast css.
  + Wayland: Support the primary-selection-unstable-v1 protocol.
  + X11: Fix a crash with parent-relative backgrounds.
  + Broadway: Set modifier state of scroll events.
  + Build: Fix pc file generation on NixOS.
  + Updated translations.
* Tue Nov 24 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.24.23+118:
  + cssnode: Bail out nicely if there is no settings (#2780).
  + gdk/wayland: Add support for primary-selection-unstable-v1
    (#2591).
  + wayland: Emit dummy configure event when resizing while fixed.
  + colorchooser: Backport the new color palette.
  + gdk: Fix parent relative background crash.
  + Updated translations.
* Thu Oct 15 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Pass --disable-tracker3 to configure: This disables the tracker
  search integration in the file open dialog, but avoids crashes in
  apps loading GTK3 and still using Tracker.
* Mon Sep  7 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Enable tracker 3 support:
  + Add pkgconfig(tracker-sparql-3.0) BuildRequires.
  + Pass --enable-tracker3 to meson.
* Sat Sep  5 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.24.23:
  + Adwaita: Support error states for labels and entries.
  + Printing: Use the correct names for remote printers.
  + File choser: Default to tracker2 for search to prevent
    symbol clashes in tracker-using applications.
  + Wayland:
  - Support newer schemas for settings.
  - Fix DND hotspot handling.
  - Disconnect on display close.
  + X11: Fix a possible crash with disabled devices.
  + Updated translations.
- Switch to regular release tarballs: it's been a while that we
  deviated from the tags.
* Mon Aug 10 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.24.22:
  + GtkTextView:
  - Fix some corner cases of pixelcache invalidation.
  - Make select-all work on touch.
  + Fix print portal support.
  + Adwaita:
  - Tweak title style class.
  - Add a public color for text view background.
  + Wayland: Add a way to change the application id:
  + Add --enable-tracker3 option to configure.
  + Updated translations.
* Mon Aug 10 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Only recommend instead of Require adwaita-icon-theme: Even though
  GTK3 references this icon set as fallback, we only want to
  recommend it here to have a chance to make live CD's smaller
  (where we have good control of the apps on them).
* Sun Jun 28 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.24.21:
  + Wayland:
  - Prevent crashes with offscreen windows.
  - Handle disorderly tablet/pad disconnects.
  + GtkFileChooser:
  - Translate the type column.
  - Add a tracker3 search engine.
  - Rate-limit trash monitoring.
  - Make get_filter work for native chooser.
  + GtkGLArea: Fix a redraw problem.
  + GtkScrolledWindow: Fix kinetic scrolling.
  + Add a gtk-cursor-aspect-ratio setting.
  + GDK:
  - Improve frame clock smoothness.
  - Fix frame clock monotonicity.
  + Adwaita: Improve notebook tab legibility.
  + Updated translations.
* Thu Jun  4 2020 Alynx Zhou <alynx.zhou@suse.com>
- Add gtk3-x11-fix-menu-touch-by-pointer-emulation.patch: GtkMenu
  under X11 cannot work with touchscreen because it cannot handle
  touch events properly, this patch disable touch grabbing for it,
  so it will fallback to pointer emulation while touching
  (bsc#1167951, glgo#GNOME/gtk!1794).
* Mon Apr 27 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.24.20:
  + GtkFileChooser:
  - Prevent selection changes after overwrite confirmation
  - Don't grab focus to the sidebar on click
  - Avoid a use-after-free in GtkFileSystemModel
  + GtkEmojiChooser: Remove blacklist
  + GtkAboutDialog: Add more licenses
  + Adwaita: Lower the contrast of checkboxes
  + HighContrast: Export the same public colors as Adwaita
  + Updated translations.
* Fri Apr 10 2020 bjorn.lie@gmail.com
- Update to version 3.24.18:
  + Wayland: Fix more sizing regressions in Epiphany and
    LibreOffice menus, and popups in general.
  + Build: Make resource build reproducible.
  + Updated translations.
- Disable autogeneration of .changes in service, we are currently
  using released tags so it is not needed.
* Sat Apr  4 2020 bjorn.lie@gmail.com
- Update to version 3.24.17:
  + GtkFileChooser: Fix some keynav issues.
  + GtkMenuButton: disable focus-on-click.
  + Derive the HighContrast and HighContrastInverse themes from
    Adwaita.
  + Wayland:
  - Fix firefox sizing problems.
  - Prevent Alt lingering after Alt-Tab.
  - Load compose sequences from ~/.Compose.
  - Fix a crash in the Wayland input method.
  + Updated translations.
* Sat Mar 28 2020 dimstar@opensuse.org
- Update to version 3.24.16:
  + Fix the build.
- Changes from version 3.24.15:
  + filechooser:
  - Fix a crash.
  - Support selecting directories with a new enough file chooser
    portal.
  + textview: Speed up tag handling.
  + wayland:
  - Fix problems with clipboard handling.
  - Fix a crash in the Wayland input method.
  - Support cursor scale of 400%%.
  - Fix a crash in glade.
  + css: Support font-feature-settings
  + Adwaita:
  - Use tabular figures where appropriate.
  - Color tweaks for dark mode.
  - Improve rendering of rounded corners.
  + Updated translations.
* Mon Feb 17 2020 bjorn.lie@gmail.com
- Update to version 3.24.14:
  + Fix the opaque region for windows on X11.
  + Theme:
  - Fix flat buttons in backdrop.
  - Make popovers look more similar to menus.
  - Tweak checkbox & radiobutton appearance.
  - Add general typography classes (heading, title-1, etc).
  + Language bindings: Fix annotations for
    gtk_tree_model_sort_new_with_model.
  + Switch: Fix touch support.
  + Infobar: Make clickable for default action.
  + Emojichooser: Respect a no-emoji input hint.
  + Fontchooser: Fix an oversight with hiding the size label.
  + Filechooser: Disable recursive search without a system indexer.
  + Modelbutton: Fix a11y support to reflect button state.
  + Input: Fix touchpad gesture center calculation.
  + X11:
  - Fix root window scaling.
  - Support _GTK_WORKAREAS_Dn property.
  + Wayland:
  - Support a terminal purpose in input methods.
  - Fix preedit cursor positioning.
  - Fix enabling/disabling of text inputs.
  - Support simultaneous selection requests.
  - Require Wayland 1.14.91.
  + Printing: Fix a crash with Avahi.
  + Updated translations.
* Fri Jan 10 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Move /usr/share/locale/en from the -lang package to the -data
  package: English is installed on all systems. This avoids
  gtk3-lang being triggered for installation on english-only
  systems.
* Wed Dec 11 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Split API doc generation from main package using _multibuild,
  libgtk3 itself only takes a fraction of the time to build.
* Wed Nov 27 2019 bjorn.lie@gmail.com
- Update to version 3.24.13+0:
  + Fix a11y test output
  + HighContrast: Add missing color to entry
  + themes: remove various @extend with compound selectors
  + Avoid Broadwayd - GtkEntry popup takes 35s after application
    startup.
  + Hide Objective-C from outside GdkQuartz.
* Tue Nov 19 2019 Frederic Crozat <fcrozat@suse.com>
- Add Obsoletes/Provides to baselibs.conf to ensure
  gtk3-immodules-tigrigna-32bit can be upgraded from old version.
* Fri Nov  1 2019 Ismail Dönmez <idonmez@suse.com>
- Don't recommend -lang subpackage
* Wed Oct 23 2019 bjorn.lie@gmail.com
- Update to version 3.24.12+32:
  + gdk: Do not change the windowing selection when cancelling
    source
  + Revert "gdk: Do not call gdk_selection_owner_set() internally
    to the backend"
  + gtkwidget: Ensure to run key controllers in the bubble phase
  + keycontroller: Fix ::key-released signal argument
  + key controller: Don't eat modifier events
  + gdk: Do not call gdk_selection_owner_set() internally to the
    backend
  + gdk: Shuffle the situations where a selection is unset
  + gtkwidget: Forward unhandled scroll events through controllers
- Switch to gitcheckout of stable branch, needed to get fixes for
  copy/paste between Xwayland and wayland programs.
- Following the above, add gtk-doc and libtool BuildRequires and
  pass autogen.sh to bootstrap and --enable-gtk-doc to configure.
- No longer disable LTO, current versions of gtk3 builds fine with
  it enabled.
* Fri Oct  4 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.24.12:
  + file chooser: allow sorting by file type.
  + dnd: fix pointer offsets under X11 and Wayland.
  + broadway: Fix a font problem.
  + mir Drop this backend.
  + printing: Get PPD from original host if needed.
  + a11y: Fix interference with clutter a11y impl.
  + Updated translations.
* Wed Sep  4 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.24.11:
  + Adwaita:
  - Add drop shadow to icons.
  - Small color fixes.
  - Make title buttons round.
  + Wayland:
  - Support xdg-output v3.
  - Fix clipboard ownership handling.
  + X11: Improve monitor metadata.
  + Build: Require GLib 2.57.2.
  + Updated translations.
* Thu Jul  4 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.24.10:
  + Make gtk_widget_get_action_group behave as documented.
  + Make gdk_screen_get_monitor_plug_name works as before.
  + Adwaita:
  - Update infobar look.
  - Fix some issues with submenus and popovers.
  + Wayland: Use the xdg-output protocol.
  + Fix build issues around cups.
  + Quartz: Build fixes.
  + treeview: Bring the pixel cache back, since its removal was
    causing problems in some applications.
  + Various documentation improvements.
  + Updated translations.
* Tue Jun 18 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.24.9:
  + GTK can now be built with the meson build system.
  + Wayland:
  - Support the xdg-output protocol for correct monitor sizes
    with scaled displays.
  - Fix handling of cursor hotspots that was reading
    uninitialized memory.
  - Update tablet cursors when scale changes.
  + CSS: Use multiple font-family values (bsc#1134059,
    glgo#GNOME/gtk#1854).
  + Emoji: Populate the Emoji chooser incrementally.
  + Printing: Require CUPS 1.7.
  + Scrolling: Add a gtk-overlay-scrolling setting that can be used
    to force traditional (non-overlay) scrollbars.
  + GtkTreeView:
  - Update rubberband rectangles more often.
  - Remove the pixel cache, to avoid the redraw issues that it
    causes.
  + Tooling: Support sysprof profiling.
  + Themes:
  - Adwaita: Small tweaks to the theme refresh.
  - Adwaita: Update treeview progress bars.
  - HighContrast: Improve notebook tabs.
  + Updated translations.
* Wed May  8 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Move RPM macros to %%_rpmmacrodir.
* Wed Apr 24 2019 Martin Liška <mliska@suse.cz>
- Disable LTO (boo#1133119).
* Thu Apr 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.24.8:
  + Color editor: don't warn if editing is cancelled.
  + Always redraw on allocate - not doing so is not safe when any
    widget can have a background.
  + Use GLSL 3.30 for shaders.
  + Quartz: add a preliminary GdkGLContext implementation.
  + Win32: Fix a bug that prevented storing printer driver prefs.
  + Wayland: properly place window menus.
  + GtkApplication: support session state changes in sandboxes,
    using the inhibit portal.
  + Fix a problem with autostart notification.
  + Places: Show loop devices as reported by gvfs.
  + Updated translations.
* Tue Mar 12 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.24.7:
  + Undeprecate gtk_window_present.
* Tue Mar 12 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.24.6:
  + Link against fribidi.
  + Broadway: Ensure focus on click.
  + Fix some compiler warnings.
  + Improve menu positioning with move-to-rect.
  + Improve activation of the onscreen keyboard.
  + Use C locale when generating code.
  + Treeview: Make sure separator nodes have height > 0.
  + theme: Fix some inconsistences for radii.
  + Updated translations.
- Drop gtk3-boo1121456-a11y-export.patch: Fixed upstream.
* Mon Feb  4 2019 bjorn.lie@gmail.com
- Update to version 3.24.5:
  + Adwaita: Refresh the theme.
  + HighContrast: Refresh the theme.
  + Wayland: Implement gdk_window_present.
  + GtkSwitch: Use icons instead of glyphs.
  + Updated translations.
- Add explicit pkgconfig(fribidi) BuildRequires, new dependency.
* Mon Jan 21 2019 bjorn.lie@gmail.com
- Update to version 3.24.4:
  + Support gtk_file_chooser_set_filter in GtkFileChooserNative.
  + Bugs fixed:
  - wayland: Fix long combobox positioning.
  - about dialog: Activate all links in the same way.
  - switch: Add fallbacks for symbols.
  - spinbutton: Fix background color.
  + Updated translations.
- Drop gtk3-Add-fallbacks-GtkSwitch-labels.patch: Fixed upstream.
* Fri Jan 18 2019 bjorn.lie@gmail.com
- Add gtk3-Add-fallbacks-GtkSwitch-labels.patch: Add fallbacks for
  GtkSwitch state labels.
* Mon Jan 14 2019 mgorse@suse.com
- Replace gtk3-atk-table-cell.patch with
  gtk3-boo1121456-a11y-export.patch: the feature made it into
  3.24.3, without this bug fix (boo#1121456 glgo#GNOME/gtk!506).
* Mon Jan 14 2019 bjorn.lie@gmail.com
- Update to version 3.24.3:
  + Bugs fixed:
  - wayland:
    . Respect length limits in text protocol.
    . Support key themes.
    . Fix hi-dpi cursor scaling.
  - placessidebar: Insert drops in the right place.
  - x11:
    . Fix problems gdk_x11_get_parent_relative (glgo#GNOME/gtk#1280).
    . Fix Wacom tool types.
  - icons: Recolor polygons as well in symbolic icons.
  - switch: Use Unicode symbols for I/O instead of translations.
  + Updated translations.
- Drop upstream applied patches:
  + gtk3-revert-Fix-deprecation-warnings.patch.
  + gtk3-x11-fix-deprecation-macro-use.patch.
- Disable gtk3-atk-table-cell.patch: It was partly applied
  upstream, and needs a rebase.
* Sat Jan 12 2019 Andrei Dziahel <develop7@develop7.info>
- Update gtk3-atk-table-cell.patch to export
  gtk_cell_accessible_parent_get_(row|column)_header_cells
  functions (boo#1121456 glgo#GNOME/gtk!505)
* Wed Jan  9 2019 mgorse@suse.com
- Update gtk3-atk-table-cell.patch to include the new good
  accessibility-dump test output (bsc#1119306).
* Thu Jan  3 2019 Gary Ching-Pang Lin <glin@suse.com>
- Add gtk3-x11-fix-deprecation-macro-use.patch to fix the potential
  crash (boo#1120456)
* Thu Dec 13 2018 bjorn.lie@gmail.com
- Update to version 3.24.2:
  + new api: gdk_x11_display_get_parent_relative pattern.
  + wayland: Use the settings portal when sandboxed.
  + Bugs fixed:
  - widget-factory: Move app menu contents to primary menu.
  - Make dashed border-style work correctly.
  - gtkstack: fix null pointer dereference.
  - GDK W32: Support switching input modules at runtime.
  - Tooltip: Fix the used cursor size if 0 in Settings.
  - quartz: Fix crash when realizing GtkOffscreenWindow.
  - win32 dnd: Fix setting icon on drag-begin.
  - Fix race in GtkPlug window creation.
  - widget-factory: Add Keyboard Shortcuts menu item.
  - quartz: do not cache the screen in the gdkmonitor.
  - Trash in side bar sometimes contains a home icon.
  - wayland: Avoid crashes inside wl_proxy_marshal.
  - gtkimcontextime.c: Fix Korean input.
  - entry: Handle no-window events in gtk_entry_event.
  - Tooltip: Fix the used cursor size if 0 in Setting.
  - Notebook: Ensure menu_label updates with tab_label.
  - Adwaita: Improve headerbar theming.
  - win32: Make scroll behavior similar to Linux.
  - fix symbolic icon rendering with new librsvg.
  - emoji selector: force Emoji presentation.
  - a11y: fix a crash under wayland.
  + Updated translations.
- Add gtk3-revert-Fix-deprecation-warnings.patch: Revert "Fix
  deprecation warnings", fixes build.
* Mon Nov 12 2018 mgorse@suse.com
- Add gtk3-atk-table-cell.patch: add support for AtkTableCell
  (bsc#1119306 fate#326548 glgo#GNOME/gtk!411).
* Fri Sep 21 2018 Jan Engelhardt <jengelh@inai.de>
- Avoid em dash summaries
* Wed Sep 19 2018 luc14n0@linuxmail.org
- Update to version 3.24.1:
  + Adwaita: Improvements to headerbar styling.
  + Wayland: Fix handling of preedit text.
  + Windows: Implement smooth scrolling.
  + Fix critical warnings on shutdown.
  + Updated translations.
- Changes from version 3.24.0:
  + GtkApplication can now track screensaver state.
  + Updated translations.
- Drop gtk3-imwayland-clearing-preedit-text.patch: fixed upstream.
* Sun Sep 16 2018 badshah400@gmail.com
- Add gtk3-imwayland-clearing-preedit-text.patch: imwayland
  preedit text was not cleared the right way on focus out, causing
  some issues: glgo#GNOME/gtk#1316; patch taken from upstream git.
* Wed Aug 29 2018 bjorn.lie@gmail.com
- Update to version 3.23.3:
  + Deprecate a few APIs that are gone in GTK+ 4:
  - focus chains in GtkContainer.
  - stepper sensitivity in GtkRange.
  + Allow picking colors under kwin.
  + Bugs/issues fixed: glgo#GNOME/gtk#404, glgo#GNOME/gtk#770,
    glgo#GNOME/gtk#1263, glgo#GNOME/gtk#134, glgo#GNOME/gtk#432,
    glgo#GNOME/gtk#574, glgo#GNOME/gtk#579, glgo#GNOME/gtk#878,
    glgo#GNOME/gtk#844, glgo#GNOME/gtk#2393, glgo#GNOME/gtk#125,
    glgo#GNOME/gtk!290, glgo#GNOME/gtk!172.
  + Updated translations.
* Thu Aug  9 2018 tchvatal@suse.com
- Fix package name to be uniform immodules -> immodule bsc#1104264
* Tue Jul 31 2018 bjorn.lie@gmail.com
- Update to version 3.23.2:
  + Emoji chooser improvements:
  - Try harder to avoid fallback rendering.
  - Avoid hex boxes.
  - Use icons for sections.
  + Color chooser improvements: Allow picking colors from the
    screen again. The current implementation can use either the
    screnshot portal or a recent gnome-shell API.
  + GtkPlacesSidebar now shows a spinner during mount operations.
  + Wayland: Support both gtk-text-input and text-input-unstable-v3
    as input protocol.
  + Bugs fixed: glgo#GNOME/gtk#628, glgo#GNOME/gtk!248,
    glgo#GNOME/gtk!272.
  + Updated translations.
- Add new gtk3-immodule-wayland subpackage and handle it in
  post(un) and baselibs.
* Tue Jul 24 2018 bjorn.lie@gmail.com
- Update to version 3.23.1:
  + Backported event controllers from GTK+ 4:
  - GtkEventControllerScroll.
  - GtkEventControllerMotion.
  - GtkEventControllerKey.
  - GtkGestureStylus.
  + Support markup in GtkModelButtons.
  + Themes:
  - The Raleigh theme has been removed.
  - Expander size in HighContrast has been increased.
  + Wayland:
  - Update cursor scale when needed.
  - Decoration negotiation protocol fixes.
  + Windows: Add an EGL renderer based on ANGLE.
  + Updated translations.
- Drop gtk3-fix-wayland-csd-announce.patch: Fixed upstream.
* Tue Jul 24 2018 qkzhu@suse.com
- Add gtk3-fix-wayland-csd-announce.patch: This fixes libreoffice
  under kwin, which would remove it's own headers as per the
  manager's request but not inform kwin leaving it in the even
  more broken state of having none. (boo#1099991)
* Sun Jun 24 2018 luc14n0@linuxmail.org
- Update to version 3.23.0:
  + New font chooser features:
  - Allow setting OpenType font features;
  - Show examples for OpenType font features;
  - Allow selecting OpenType font variations;
  - Support levels of details for selection.
  + New Emoji features:
  - Support a completion popup for Emoji;
  - Drop Ctrl-Shift-e shortcut.
  + Other new apis: gdk_window_move_to_rect.
  + Bugs fixed: glgo#GNOME/GTK#85, glgo#GNOME/GTK#154,
    glgo#GNOME/GTK#193, glgo#GNOME/GTK#199, glgo#GNOME/GTK#292,
    glgo#GNOME/GTK#450, glgo#GNOME/gtk#550, glgo#GNOME/GTK#792,
    glgo#GNOME/GTK#898, glgo#GNOME/GTK#997, glgo#GNOME/GTK#1053,
    glgo#GNOME/GTK#1059, glgo#GNOME/GTK#1065, glgo#GNOME/GTK#1069,
    glgo#GNOME/GTK#1088, glgo#GNOME/GTK#1115, glgo#GNOME/GTK#1134,
    glgo#GNOME/GTK#1160, glgo#GNOME/GTK#1165, glgo#GNOME/GTK#1166,
    bgo#407242, bgo#686109, bgo#765327, bgo#772817, bgo#773299,
    bgo#775279, bgo#786524, bgo#787867, bgo#789215, bgo#791542,
    bgo#791802, boo#1136605, boo#1134062.
  + Updated translations.
- Drop gtk3-filechooserbutton-Fix-reserved-pointers.patch: fixed
  upstream.
* Tue Jun 12 2018 fezhang@suse.com
- Add gtk3-filechooserbutton-Fix-reserved-pointers.patch: Stop gcc
  from complaining about unnecessary parenthesis, fix gnucash build
  failures.
* Tue Apr 24 2018 dimstar@opensuse.org
- Mark /etc/gtk-3.0/settings.ini as config(noreplace): admins that
  update this file most likely want to keep their changes
  (boo#1087507) - and the distro does not have very frequent
  changes in this file.
* Wed Apr 18 2018 luc14n0@linuxmail.org
- Update to version 3.22.30:
  + gtk-demo has a new 'Widgetbowl' demo.
  + The wayland backend now supports the stable xdg-shell protocol.
  + Bugs fixed: glgo#GNOME/GTK#28, glgo#GNOME/GTK#83,
    glgo#GNOME/GTK#88, glgo#GNOME/GTK#114, glgo#GNOME/GTK#129,
    glgo#GNOME/GTK#132, glgo#GNOME/GTK#141, glgo#GNOME/GTK#146,
    glgo#GNOME/GTK#156, glgo#GNOME/GTK#157, glgo#GNOME/GTK#163,
    bgo#705509, bgo#745128, bgo#748784, bgo#791939, bgo#792632,
    bgo#793062.
* Wed Apr  4 2018 fezhang@suse.com
- Clean up specfile: Enable Wayland unconditionally.
* Thu Mar 22 2018 luc14n0@linuxmail.org
- Drop icon_theme_cache_* and glib2_gsettings_schema_* post/postun
  scriptlets, and glib2_gsettings_schema_requires macro: their
  functionality has been moved to RPM file triggers
  (RPM 4.13, suse_version 1330).
- Add cairo-gobject, gio-2.0, gio-unix-2.0 and harfbuzz pkgconfig
  modules BuildRequires to avoid implicit dependencies.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Tue Mar 13 2018 dimstar@opensuse.org
- Update to version 3.22.29:
  + Wayland: add an input method based on the text protocol.
  + File chooser: Stop activating without double-click.
  + Bugs fixed: bgo#710888, bgo#743975, bgo#775546, bgo#794008.
  + Updated translations.
- Drop gtk3-restore-filechooser-click-behavior.patch: fixed
  upstream.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Feb 26 2018 dimstar@opensuse.org
- Package COPYING as %%license instead of %%doc.
* Mon Feb 26 2018 dimstar@opensuse.org
- Drop gtk3-path-local.patch: patch had been disabled since GTK
  August 2016 with nobody missing the feature.
* Mon Feb 19 2018 dimstar@opensuse.org
- Update to version 3.22.28:
  + Improve frame clock accuracy (bgo#787665).
  + Bugs fixed: bgo#793442.
* Wed Feb 14 2018 dimstar@opensuse.org
- Update to version 3.22.27:
  + Require libcloudproviders 0.2.5.
  + The Emoji chooser can now be used with GtkTextView as well.
  + The Emoji chooser avoids fallback sequences that break the
    grid.
  + GTK+ is now using ~/.config/gtk-3.0/settings.ini when using
    Wayland without dconf.
  + Make fuse-mounted network filesystems show up in Other
    Locations.
  + The font chooser dialog supports search now.
  + Bugs fixed: bgo#737175, bgo#741633, bgo#771986, bgo#774248,
    bgo#779009, bgo#786123, bgo#786509, bgo#786528, bgo#787089,
    bgo#787128, bgo#789054, bgo#789160, bgo#789268, bgo#790029,
    bgo#790031, bgo#790033, bgo#790201, bgo#790270, bgo#790862,
    bgo#790963, bgo#791039, bgo#791062, bgo#791234, bgo#791281,
    bgo#791363, bgo#791549, bgo#791650, bgo#791710, bgo#791943,
    bgo#792279, bgo#792459, bgo#792624.
  + Updated translations.
- Drop
  gtk3-placesview-Present-FUSE-reachable-network-shares-in-.patch:
  fixed upstream.
* Fri Dec 29 2017 jengelh@inai.de
- Sync summaries with gtk4.
* Sat Nov 18 2017 dimstar@opensuse.org
- Update to version 3.22.26:
  + Bugs fixed: bgo#785176, bgo#787142, bgo#788898, bgo#789134,
    bgo#789213, bgo#789630, bgo#789678, bgo#789733.
  + Updated translations.
- Drop gtk3-wayland-distribute-server-decoration-xml.patch: fixed
  upstream.
- Comment gnome-common Buildrequires and call to autogen.sh again:
  no currently applied patch changes the build system.
* Fri Nov 17 2017 vliaskovitis@suse.com
- Add gtk3-placesview-Present-FUSE-reachable-network-shares-in-.patch:
  Present FUSE reachable network shares in gtkplacesview (bgo#787128,
  bsc#1062879)
* Tue Oct 31 2017 badshah400@gmail.com
- Update to version 3.22.25:
  + The HighContrast theme has received numerous improvements.
  + Middle-click on scrollbars jumps to the position again.
  + Wayland:
  - Terminal sizing problems are fixed.
  - The Wayland backend now implemented the KDE server-side
    decorations protocol.
  + X11: Problems with menus on several X servers are fixed.
  + Bugs fixed: bgo#701296, bgo#728452, bgo#738387, bgo#763517,
    bgo#769877, bgo#769879, bgo#771279, bgo#775217, bgo#776793,
    bgo#777072, bgo#778811, bgo#778930, bgo#780101, bgo#781909,
    bgo#782396, bgo#783995, bgo#784314, bgo#784509, bgo#786220,
    bgo#786794, bgo#787274, bgo#787669, bgo#787866, bgo#788053,
    bgo#788458, bgo#788496, bgo#788505, bgo#788516, bgo#788573,
    bgo#788574, bgo#788575, bgo#788577, bgo#788580, bgo#788614,
    bgo#788841, bgo#788905, bgo#789141, bgo#789149, bgo#789327,
    bgo#789357.
  + Updated translations.
- Drop gtk3-silence-log-spew-blank-cursors.patch: Fixed upstream.
- Add gtk3-wayland-distribute-server-decoration-xml.patch: Builds
  that include wayland fail unless
  gtk/wayland/protocol/server-decoration.xml is included in
  tarballs (bgo#789630). Patch touches Makefile.am, uncomment
  BuildRequires: gnome-common and ./autogen.sh before configure.
* Wed Oct 11 2017 yfjiang@suse.com
- Add gtk3-restore-filechooser-click-behavior.patch: The
  clicking behavior introduced by commit#fb0a13b has confused many
  users in the past 2 years. By reverting the commit, the patch
  makes the primary button clicking behave as consistent as most
  users has been used to (bgo#758065 bsc#1057471).
* Wed Oct  4 2017 zaitor@opensuse.org
- Update to version 3.22.24:
  + Combobox: Don't try to remove grabs on NULL devices.
  + Fix some issues with the new resizable tiling.
* Wed Oct  4 2017 zaitor@opensuse.org
- Update to version 3.22.23:
  + Bugs fixed: bgo#783669, bgo#784562.
* Tue Oct  3 2017 zaitor@opensuse.org
- Update to version 3.22.22:
  + Bugs fixed: bgo#639931, bgo#644248, bgo#775126, bgo#780758,
    bgo#781757, bgo#787021, bgo#787302, bgo#787303, bgo#787444,
    bgo#787531, bgo#787600, bgo#787757.
  + Updated translations.
* Fri Sep 15 2017 zaitor@opensuse.org
- Add gtk3-silence-log-spew-blank-cursors.patch wayland: Don't spew
  warnings for blank cursors. Patch from upstream bug (bgo#775217).
* Mon Sep 11 2017 zaitor@opensuse.org
- Update to version 3.22.21:
  + Bugs fixed: bgo#738893, bgo#786613, bgo#787172, bgo#787279,
    bgo#787280, bgo#787410.
  + Updated translations.
* Mon Sep  4 2017 dimstar@opensuse.org
- Update to version 3.22.20:
  + Add input hints for Emoji, that let applications indicate
    whether entries would benefit from Emoji support or not.
  + Add support for cloud services in GtkPlacesSidebar. This adds a
    new, optional dependency on libcloudproviders.
  + Buga fixed: bgo#468868, bgo#618160, bgo#705640, bgo#729651,
    bgo#759725, bgo#766909, bgo#774134, bgo#775074, bgo#776937,
    bgo#780750, bgo#783649, bgo#785306, bgo#785736, bgo#786029,
    bgo#786123, bgo#786209, bgo#786492, bgo#786553, bgo#786771,
    bgo#786841, bgo#786885, bgo#786932, bgo#786938, bgo#786940,
    bgo#786956, bgo#786960, bgo#786964, bgo#786966, bgo#786986,
    bgo#787103, bgo#787158, bgo#787195.
  + Updated translations.
- Add (commented out) pkgconfig(cloudproviders) BuildRequires: new
  dependency for the cloud support integration. As upstream is not
  yet in a situation to make proper versioned releases, we do not
  enable it yet.
* Tue Aug 22 2017 zaitor@opensuse.org
- Update to version 3.22.19:
  + Add support for Emoji input, with an Emoji chooser.
  + Bugs fixed: bgo#773299, bgo#784016, bgo#784421, bgo#785999,
    bgo#786144, bgo#786209, bgo#786287, bgo#786400, bgo#786469,
    bgo#786480, bgo#786594.
  + Updated translations.
* Tue Aug  8 2017 zaitor@opensuse.org
- Update to version 3.22.18:
  + Support entering emoji by name, using Ctrl-Shift-E.
  + Wayland:
  - Add support for the shortcut inhibitor protocol.
  - Support Wacome tablet wheel scrolling.
  + Bugs fixed: bgo#771959, bgo#776903, bgo#776909, bgo#777333,
    bgo#777515, bgo#778188, bgo#780938, bgo#781246, bgo#782870,
    bgo#783343, bgo#783649, bgo#783716, bgo#783906, bgo#784624,
    bgo#785255, bgo#785375, bgo#785423, bgo#785672.
  + Updated translations.
* Wed Jul 19 2017 zaitor@opensuse.org
- Update to version 3.22.17:
  + Add native file chooser support for OS X.
  + Bugs fixed: bgo#766517, bgo#781583, bgo#781935, bgo#781936,
    bgo#782040, bgo#782325, bgo#784323, bgo#784723, bgo#784888.
  + Updated translations.
* Thu Jul  6 2017 fvogt@suse.com
- Add gtk3-revert-forced-xftdpi.patch: revert upstream commit
  breaking DPI autodetection (boo#1022830, fate#322401, fdo#98909,
  kde#367499, bmo#1269274). Aligns GTK's DPI detection code back to
  what GTK2 does.
* Tue Jun 27 2017 dimstar@opensuse.org
- Migrate %%icon_theme_cache_post/postun macro from
  hicolor-icon-theme to gtk3-tools file triggers. Any package
  installing icons below /usr/share/icons will trigger. Each
  package will produce the cache for every icon theme being
  updated. The same trigger is also added to gtk2-tools, where only
  the one owning the current instance of
  /usr/bin/gtk-update-icon-cache update-alternative link actually
  executes the update.
* Wed Jun 21 2017 dimstar@opensuse.org
- Update to version 3.22.16:
  + GtkEntryBuffer no longer emits changed events when input is
    truncated.
  + gtk3-icon-browser now offers to copy the icon name to the
    clipboard.
  + Bugs fixed: bgo#745289, bgo#759308, bgo#770513, bgo#778853,
    bgo#779078, bgo#781285, bgo#781945, bgo#782117, bgo#782283,
    bgo#782325, bgo#783047, bgo#783347, bgo#783397, bgo#783587.
  + Updated translations.
* Fri May 19 2017 dimstar@opensuse.org
- Change gettext-tools BuildRequires to gettext-tools-mini: the
  - mini package has all we need and it helps us get out of the
  bootstrap cycle.
* Fri May 12 2017 zaitor@opensuse.org
- Update to version 3.22.15:
  + Revert an unexpeted change in listbox behavior.
  + Improve the Adwaita style for tagged entries.
* Wed May 10 2017 zaitor@opensuse.org
- Update to version 3.22.14:
  + Fix build without sassc.
  + Fix clipboard handling of UTF8 text.
* Wed May 10 2017 zaitor@opensuse.org
- Update to version 3.22.13:
  + Bugs fixed: bgo#358970, bgo#771269, bgo#773814, bgo#778301,
    bgo#778617, bgo#779570, bgo#780301, bgo#781118, bgo#781162,
    bgo#781195, bgo#781214, bgo#781422, bgo#781605, bgo#781622,
    bgo#781737, bgo#781767, bgo#781814, bgo#781992, bgo#782109,
    bgo#782180, bgo#782202.
  + Updated translations.
* Mon Apr 24 2017 dimstar@opensuse.org
- Update to version 3.22.12:
  + Bugs fixed: bgo#686838, bgo#734946, bgo#773228, bgo#776472,
    bgo#778853, bgo#779081, bgo#779184, bgo#780041, bgo#780234,
    bgo#780734, bgo#780735, bgo#780878, bgo#780994.
  + Updated translations.
* Fri Mar 24 2017 sreeves@suse.com
- Add Requires gdk-pixbuf-loader-rsvg. bsc#1007453
    We require adwaita-icon-theme so we need something to load
    the svg icons it provides.
* Mon Mar 20 2017 zaitor@opensuse.org
- Update to version 3.22.11:
  + Quartz: Fix build on osx < 10.12.
  + Cosmetic fixes.
  + Avoid a critical warning in the filechooser portal.
* Tue Mar 14 2017 zaitor@opensuse.org
- Update to version 3.22.10:
  + Theme: Improve styling for flow boxes.
  + Quartz:
  - Support fullscreen CSD windows.
  - Implement backdrop.
  - Implement gdk_window_set_functions.
  + Bugs fixed: bgo#778905, bgo#779073, bgo#779074, bgo#779317,
    bgo#779374, bgo#779383, bgo#779392.
  + Updated translations.
* Tue Feb 28 2017 zaitor@opensuse.org
- Update to version 3.22.9:
  + Bugs fixed: bgo#136059, bgo#776821, bgo#778203, bgo#778328,
    bgo#778534, bgo#778678, bgo#778726, bgo#778746, bgo#778835,
    bgo#778905, bgo#779005, bgo#136059, bgo#772505, bgo#774148,
    bgo#778019.
  + Updated translations.
* Mon Feb 13 2017 zaitor@opensuse.org
- Update to version 3.22.8:
  + Wayland: Avoid overlap between Alt and Meta.
  + Mir:
  - Implement window properties.
  - Track window focus.
  - Connect to content-hub and use it for copy/paste.
  - Use modal hint.
  + Bugs fixed: bgo#358970, bgo#765161, bgo#765410, bgo#770112,
    bgo#773686, bgo#775732, bgo#775864, bgo#777527, bgo#777547.
  + Updated translations.
* Mon Jan 16 2017 zaitor@opensuse.org
- Update to version 3.22.7:
  + Bugs fixed: bgo#165385, bgo#769214, bgo#769835, bgo#774726,
    bgo#775846, bgo#776031, bgo#776225, bgo#776485, bgo#776807,
    bgo#777031, bgo#777176.
  + Updated translations.
- Drop gtk3-wayland-handle-subsurface-popup-parent.patch: Fixed
  upstream.
* Sun Jan  8 2017 zaitor@opensuse.org
- Add gtk3-wayland-handle-subsurface-popup-parent.patch: Handle
  subsurface as popup parent (bgo#776225).
* Thu Jan  5 2017 zaitor@opensuse.org
- Update to version 3.22.6:
  + Fix GL checks to work better on OpenGL ES 2.0.
  + Avoid a possible crash in ::activate-url handlers.
  + scrolledwindow: Fix func summary being cut off in bindings
    using doxygen.
  + Bugs fixed: bgo#774534, bgo#776132, bgo#776187, bgo#776012,
    bgo#774784, bgo#776306, bgo#775808, bgo#776524,
    bgo#776560.
  + Updated translations.
* Fri Dec  9 2016 dimstar@opensuse.org
- Update to version 3.22.5:
  + gtk3-demo now has an example for using PangoTabArray to create
    a multi-column layout.
  + Bugs fixed: bgo#771242, bgo#774114, bgo#774265, bgo#774379,
    bgo#774686, bgo#774695, bgo#774699, bgo#774743, bgo#774760,
    bgo#774790, bgo#774893, bgo#774915, bgo#774917, bgo#774939,
    bgo#775212, bgo#775316, bgo#775319, bgo#775525.
  + Updated translations.
* Fri Dec  9 2016 dimstar@opensuse.org
- Split out glib schemas into gtk3-schema: gtk3 and gtk4 share the
  same schema (in order to sync their config changes). With this
  split we can have gtk4-schema provide/obsolete gtk3-schema and
  get around the two conflicting on file level.
- Move relevant %%gsettings macros from -data to -schema package.
- Require gtk3-schema by libgtk-3-0.
- Split out gettext-its-gtk3.
* Sat Nov 19 2016 dimstar@opensuse.org
- Update to version 3.22.4:
  + Bugs fixed: bgo#767713, bgo#768081, bgo#768531, bgo#772075,
    bgo#772202, bgo#773587, bgo#773916, bgo#773979, bgo#774046,
    bgo#774066, bgo#774097, bgo#774185, bgo#774352.
  + Updated translations.
- Drop gtk3-startupfix-wayland.patch: fixed upstream.
* Mon Nov  7 2016 dimstar@opensuse.org
- Update to version 3.22.3:
  + Deprecations have been added for APIs that will be removed
    in GTK+ 4.
  + gtk-demo has gained a new demo for showing (and testing)
    rendering preformance
  + Windows:
  - The GL support has been improved. Legacy contexts can now be
    created, and anti-aliasing is possible
  - Hi-DPI is now supported
  + Bugs fixed: bgo#768081, bgo#773274, bgo#773474, bgo#773479,
    bgo#773528, bgo#773799, bgo#773857, bgo#773885.
  + Updated translations.
* Tue Nov  1 2016 zaitor@opensuse.org
- Add gtk3-startupfix-wayland.patch: Fix slow startup notification
  for some gtk3 apps when running on wayland (bgo#768531).
* Mon Oct 24 2016 zaitor@opensuse.org
- Update to version 3.22.2:
  + Several improvements to the win32 theme.
  + Deprecations have been added for APIs that will be removed in
    GTK+ 4.
  + Bugs fixed: bgo#767713, bgo#771320, bgo#772345, bgo#772389,
    bgo#772415, bgo#772552, bgo#772683, bgo#772695, bgo#772775,
    bgo#772859, bgo#772922, bgo#772926, bgo#773029, bgo#773082,
    bgo#773113, bgo#773180, bgo#773246.
  + Updated translations.
* Sat Oct  1 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Reduce runtime warnings.
  + Bugs fixed: bgo#765649, bgo#769500, bgo#769554, bgo#770388,
    bgo#771516, bgo#771553, bgo#771666, bgo#771812, bgo#771826,
    bgo#771915, bgo#771959, bgo#771963, bgo#772057, bgo#772215.
  + Updated translations.
- Drop patches fixed upstream:
  + gtk3-widget-warn-consistency-check-only.patch.
  + gtk3-add-missing-annotations.patch.
  + gtk3-wayland-always-sync-state.patch.
  + gtk3-wayland-avoid-negative-size-constraints.patch.
* Tue Sep 27 2016 zaitor@opensuse.org
- Add gtk3-wayland-avoid-negative-size-constraints.patch: Fix
  totem window misplaced after a state change (bgo#771915).
* Mon Sep 26 2016 zaitor@opensuse.org
- Add gtk3-wayland-always-sync-state.patch: wayland: always sync
  state after a frame is painted. Fix black areas in webkit based
  apps (bgo#771553).
* Thu Sep 22 2016 zaitor@opensuse.org
- Add gtk3-add-missing-annotations.patch: Add some missing
  (nullable) annotations (bgo#771826).
- Rebase settings.ini, set Adwaita as gtk-fallback-icon-theme.
* Tue Sep 20 2016 dimstar@opensuse.org
- Add gtk3-widget-warn-consistency-check-only.patch: widget: Only
  warn about missing allocation if G_ENABLE_CONSISTENCY_CHECKS. The
  previously chosen G_ENABLE_DEBUG is by default set on gtk+ unless
  it is explicitly disabled by configure --disable-debug. As the
  default is too noisy, we move it to a flag that is only switched
  on by configure --enable-debug.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Reduce some noisy warnings.
  + Improve positioning and sizing of popups on Wayland.
  + Update Adwaita assets.
  + Bugs fixed: bgo#602773, bgo#771117, bgo#771349, bgo#771568,
    bgo#771561.
  + Updated translations.
* Tue Sep 13 2016 zaitor@opensuse.org
- Update to version 3.21.6:
  + GtkScrolledWindow sizing behavior has been changed back to the
    previous behavior, with new API to change it.
  + Some GtkPopover size allocation problems have been fixed.
  + Wayland: We require xdg-shell version 6 now.
  + Bugs fixed: bgo#764979, bgo#766569, bgo#767391, bgo#769498,
    bgo#770278, bgo#770508, bgo#770614, bgo#770624, bgo#770703,
    bgo#770745, bgo#770849, bgo#770906, bgo#771033.
  + Updated translations.
* Tue Aug 30 2016 zaitor@opensuse.org
- Update to version 3.21.5:
  + Make GtkShortcutLabel public.
  + Add an API to obtain window IDs for sharing.
  + Add explicit API to show/hide popovers with animation.
  + Wayland:
  - Switch to xdg-shell v6.
  - Use tablet pad protocol to support Wacom tablets fully.
  - Use the xdg_foreign protocol to export window handles.
  - Improve menu positioning.
  - Improve handling of tiled window state.
  + Add GtkPadController to bind GActions to tablet pad events.
  + Bugs fixed: bgo#569581, bgo#712760, bgo#755947, bgo#756579,
    bgo#762260, bgo#764413, bgo#768017, bgo#768081, bgo#768138,
    bgo#768722, bgo#768902, bgo#768930, bgo#768999, bgo#769003,
    bgo#769004, bgo#769047, bgo#769126, bgo#769162, bgo#769205,
    bgo#769236, bgo#769287, bgo#769402, bgo#769451, bgo#769485,
    bgo#769568, bgo#769601, bgo#769603, bgo#769706, bgo#769937,
    bgo#770026, bgo#770166, bgo#770236, bgo#770242, bgo#770332,
    bgo#770374, bgo#769788, bgo#770458, bgo#770550, bgo#770307.
  + Updated translations.
* Wed Aug 17 2016 zaitor@opensuse.org
- Update to version 3.21.4:
  + GtkHeaderBar supports expanding children.
  + GtkPrintDialog respects initially set capabilities.
  + GtkApplication supports registering with the Xfce session
    manager.
  + Keep firefox working after the introduction of
    GdkDrawingContext.
  + css: Support for background-blend-mode has been added.
  + Wayland: Fix some interoperability issues in clipboard
    handling.
  + Sandboxing:
  - GtkFileChooserNative gained portal support.
  - GtkPrintOperation gained portal support.
  - gtk_show_uri gained portal support.
  - GtkApplication gained portal support for inhibiting.
  + New APIs:
  - gtk_show_uri_on_window.
  - gtk_file_filter_to/from_gvariant.
  - gtk_file_chooser_add/remove/set/get_choice.
  - gtk_print_settings_to/from_gvariant.
  - gtk_paper_size_to/from_gvariant.
  - gtk_page_setup_to/from_gvariant.
  + Bugs fixed: bgo#693203, bgo#724332, bgo#767849, bgo#767851,
    bgo#767965, bgo#768016, bgo#768025, bgo#768082, bgo#768142,
    bgo#768184, bgo#768485, bgo#768499, bgo#768546, bgo#768657,
    bgo#768659, bgo#768756.
  + Updated translations.
- Stop passing V=1 to make, debugging is local, no need to clutter
  obs build logs.
* Wed Aug 17 2016 zaitor@opensuse.org
- Update to version 3.21.3:
  + GtkStack now has its own accessible implementation which only
    shows the currently visible child.
  + The GtkSizeGroup::ignore-hidden property has been documented as
    not working.
  + GDK_SOURCE_TRACKPOINT has been added to the GdkInputSource
    enumeration to allow special-casing this kind of input device.
  + Wayland:
  - Use separate devices to differentiate between various sources
    of scroll events.
  - Fall back to using shm_open if memfds are unavailable.
  + Styling of text in GtkScale and GtkProgressBar can now be
    influenced by the proper CSS nodes.
  + GtkScrolledWindow has new max-content-width/height properties
    to control its size.
  + GtkFileChooser search has been fixed to work with trackers FTS5
    syntax.
  + Bugs fixed: bgo#79229, bgo#118959, bgo#556254, bgo#578626,
    bgo#674215, bgo#708148, bgo#710471, bgo#742281, bgo#745622,
    bgo#751409, bgo#753202, bgo#764203, bgo#765410, bgo#765595,
    bgo#766341, bgo#766372, bgo#766569, bgo#766675, bgo#766860,
    bgo#766878, bgo#767052, bgo#767058, bgo#767093, bgo#767100,
    bgo#767108, bgo#767238, bgo#767241, bgo#767310, bgo#767312,
    bgo#767468, bgo#767705, bgo#767766, bgo#767795.
  + Updated translations.
* Wed Aug 17 2016 zaitor@opensuse.org
- Update to version 3.21.2:
  + GTK+ is now using upstream gettext instead of the GLib
    wrappers. This adds a requirement for the fairly recent gettext
    0.19.7 release.
  + GDK has a new GdkMonitor api that offers richer information
    about connected outputs.
  + Bugs fixed: bgo#373745, bgo#682080, bgo#747206, bgo#756570,
    bgo#759037, bgo#763852, bgo#764395, bgo#765471, bgo#765579,
    bgo#765676, bgo#765700, bgo#765742, bgo#765790, bgo#765793,
    bgo#765858, bgo#765907, bgo#765922, bgo#765924, bgo#765939,
    bgo#765966, bgo#765973, bgo#765981, bgo#766049, bgo#766120,
    bgo#766166, bgo#766175, bgo#766207, bgo#766233, bgo#766314,
    bgo#766323, bgo#766336, bgo#766405, bgo#766440, bgo#766442,
    bgo#766458, bgo#766530, bgo#766566, bgo#766569, bgo#766642,
    bgo#766643, bgo#766737, bgo#766782.
  + Updated translations.
- Disable gtk3-path-local.patch: It needs rebase again. Reverting
  patch to original we had before last rebase.
* Wed Aug 17 2016 zaitor@opensuse.org
- Update to version 3.21.1:
  + The GNU Affero General Public License has been added to the
    list of predefined licenses in GtkAboutDialog.
  + GtkShortcutWindow can now follow changes to accelerators.
  + GdkSeat and GdkDevice gained API for device tools, to support
    drawing tablets.
  + GtkInspector can now slow down (or speed up) animations. This
    functionality is also available via the GTK_SLOWDOWN
    environment variable.
  + GdkGLContext can now be instructed to use GLES.
  + CSS:
  - Inconsistencies in font size handling have been fixed.
  - The font shorthand is now parsed according to the CSS spec.
  + Windows:
  - Clipboard handling has been optimized.
  - The CSD implementation has been improved.
  + Wayland:
  - We print more debug information about pixel formats, outputs,
    etc.
  - The unstable tablet protocol is now supported.
  - Virtual modifier handling has been improved.
  - Reduce jitter in keyboard repeat.
  - Fix problems with multiple display connections.
  + Bugs fixed: bgo#573380, bgo#620065, bgo#693077, bgo#730821,
    bgo#743746, bgo#749405, bgo#761651, bgo#763013, bgo#763600,
    bgo#763627, bgo#763768, bgo#763783, bgo#763850, bgo#763851,
    bgo#763907, bgo#763913, bgo#764022, bgo#764060, bgo#764170,
    bgo#764210, bgo#764321, bgo#764376, bgo#764424, bgo#764664,
    bgo#764712, bgo#764845, bgo#764846, bgo#764863, bgo#764879,
    bgo#764925, bgo#764975, bgo#764996, bgo#765038, bgo#765065,
    bgo#765066, bgo#765100, bgo#765118, bgo#765122, bgo#765195,
    bgo#765213, bgo#765238, bgo#765259, bgo#765261, bgo#765270,
    bgo#765284, bgo#765486, bgo#765493, bgo#765496, bgo#765567,
    bgo#756570, bgo#765474, bgo#765565, bgo#765576, bgo#765577,
    bgo#765632, bgo#765640, bgo#765644.
  + Updated translations.
- Rebase gtk3-path-local.patch.
- Drop gtk3-gtkwindow-realize-toplevel-before-popover.patch: fixed
  upstream.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
* Wed Aug 17 2016 zaitor@opensuse.org
- Update to version 3.20.9:
  + Fix headerbar size allocation.
  + Use g_snprintf instead of snprintf.
  + Bugs fixed: bgo#769287, bgo#769603.
  + Updated translations.
* Thu Aug 11 2016 dimstar@opensuse.org
- Fix update-alternatives usage.
* Thu Aug  4 2016 dimstar@opensuse.org
- Update to version 3.20.8:
  + Revert an unintentional bump of the GLib requirement in 3.20.7.
* Thu Aug  4 2016 dimstar@opensuse.org
- Update to version 3.20.7:
  + Bugs fixed: bgo#118959, bgo#674215, bgo#708148, bgo#745622,
    bgo#747206, bgo#764060, bgo#764203, bgo#765924, bgo#766120,
    bgo#766122, bgo#766341, bgo#766643, bgo#766782, bgo#767058,
    bgo#767468, bgo#767705, bgo#767766, bgo#767795, bgo#767848,
    bgo#767851, bgo#768016, bgo#768025, bgo#768082, bgo#768142,
    bgo#768177, bgo#768485, bgo#768657, bgo#768930, bgo#769003,
    bgo#769047.
  + Updated translations.
- Drop gtk3-gtkwindow-realize-toplevel-before-popover.patch: fixed
  upstream.
* Mon Jul  4 2016 badshah400@gmail.com
- Add gtk3-gtkwindow-realize-toplevel-before-popover.patch:
  GtkWindow: Ensure the toplevel is realized before realizing
  popovers; patch taken from upstream master (bgo#764060).
* Mon May 23 2016 zaitor@opensuse.org
- Update to version 3.20.6:
  + Bugs fixed: bgo#766694, bgo#766323, bgo#766336, bgo#766737.
- Drop gtk3-bnc130159-bgo319483-async-font-selection.patch: It's
  been disabled since version 3.16.2 and upstream closed the bug as
  obsolete back in 2011.
* Thu May 19 2016 zaitor@opensuse.org
- Update to version 3.20.5:
  + Bugs fixed: bgo#763852, bgo#765973, bgo#766175, bgo#766233,
    bgo#766440, bgo#766442.
  + Updated translations.
* Fri May 13 2016 dimstar@opensuse.org
- Fix libgtk-3-0 dependency on gtk-data: require the data package
  for the latest installed version of libgtk-3-<n>. This is only
  needed for any eventual case where an ABI incompatible libgtk3
  might ever appear in order to allow them to be parallel
  installable - something upstream knows to avoid doing.
* Mon May  9 2016 zaitor@opensuse.org
- Update to version 3.20.4:
  + Bugs fixed: bgo#573380, bgo#620065, bgo#693077, bgo#749405,
    bgo#761651, bgo#762756, bgo#763768, bgo#764395, bgo#764424,
    bgo#764585, bgo#764825, bgo#764846, bgo#765038, bgo#765065,
    bgo#765066, bgo#765122, bgo#765213, bgo#765238, bgo#765261,
    bgo#765270, bgo#765284, bgo#765471, bgo#765474, bgo#765486,
    bgo#765493, bgo#765496, bgo#765565, bgo#765567, bgo#765592,
    bgo#765640, bgo#765644, bgo#765742, bgo#765790, bgo#765907,
    bgo#765922, bgo#765981, bgo#766166.
  + Updated translations.
* Wed Apr 13 2016 idonmez@suse.com
- Update to GNOME 3.20  Fate#318572
- Remove upstream patches: gtk3-icon-theme-reduce-io.patch,
  gtk3-icon-cache-index-only.patch,
  gtk3-bnc872820-headerbar-decoration-layout.patch,
  gtk3-bsc957399-gdkcairo-surface-error.patch,
  gtk3-bgo725733.patch,
  gtk3-bnc891647-generate-full-builtin-icon-cache.patch
* Tue Apr 12 2016 dimstar@opensuse.org
- Update to version 3.20.3:
  + Bugs fixed: bgo#764174, bgo#764203, bgo#764204, bgo#764261,
    bgo#764374, bgo#764378, bgo#764540, bgo#764585, bgo#764664,
    bgo#764686, bgo#764710, bgo#764835.
  + Updated translations.
- Drop gtk3-bgo764174-boo973416-no-undersize.patch,
  gtk3-Wayland-do-not-resize.patch and
  gtk3-stable-adwaita-fixes.patch: fixed upstream.
* Tue Apr  5 2016 zaitor@opensuse.org
- Add gtk3-Wayland-do-not-resize.patch: wayland: Do not resize with
  the same size, gnome-control-center is calling
  gtk_window_resize() on configure-event signals which leads to a
  busy loop (bgo#764374).
* Sat Apr  2 2016 zaitor@opensuse.org
- Add gtk3-stable-adwaita-fixes.patch: Add upstream adwaita fixes.
* Fri Apr  1 2016 egeorget@openmailbox.org
- Add gtk3-bgo764174-boo973416-no-undersize.patch: gtkwindow: Don't
  allow unresizable windows to be smaller than required. Patch from
  upstream git (bgo#764174, boo#973416).
* Thu Mar 31 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Fix blue background in Emacs windows.
  + Fix a performance issue with excessive redraws.
  + Bugs fixed: bgo#763627, bgo#763783, bgo#763851, bgo#764022,
    bgo#764170, bgo#764210, bgo#764321, bgo#764376.
  + Updated translations.
* Fri Mar 25 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Active GtkSwitch widgets now use the :checked state, to match
    GtkToggleButton.
  + Bugs fixed: bgo#641354, bgo#763350, bgo#763604, bgo#763659,
    bgo#763731, bgo#763741, bgo#763758, bgo#763779, bgo#763802,
    bgo#763804, bgo#763808, bgo#763859, bgo#763900, bgo#764118.
  + Updated translations.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Themes:
  - The HighContrast theme has been brought back up to par with
    Adwaita.
  - Adwaita has received detail fixes for many widgets.
  - Adwaita now transitions to backdrop.
  + Bugs fixed: bgo#746490, bgo#763609, bgo#763610, bgo#763612,
    bgo#763613, bgo#763696, bgo#763706, bgo#763707, bgo#763749,
    bgo#763774, bgo#763775, bgo#763777, bgo#763781, bgo#763796,
    bgo#763797, bgo#763823, bgo#763835, bgo#763846, bgo#763955.
  + Updated translations.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 3.19.12:
  + GTK+ now respects default size even for windows that are not
    resizable.
  + GtkScale and GtkScrollbar have received multiple fixes for
    fallout from the gadget port.
  + GtkStackSwitcher will now switch pages when hovered during
    drag-and-drop.
  + Inspector:
  - The per-object CSS editor has been dropped; the global one is
    sufficient.
  - The sidebar has been replaced by a combo box.
  - Add a Show Layout option to the Visual tab.
  - CSS node tree and style properties are now on the same page.
  - The frame clock is shown in the Miscellaneous page.
  - Isolate the inspector from visual debugging effects.
  - Numerous smaller UI improvements.
  + Themes:
  - Windows theme: handle spin buttons and switches.
  - Adwaita: Fixes for scales, combo boxes, info bars, action
    bars, radio and check buttons, side bars, etc.
  - Adwaita has gained a new style of drop target highlighting.
  + Wayland:
  - Synchronize key repeat with server.
  - Add a bell request to gtk_shell and use it to implement
    gdk_window_beep.
  - Add a focus request to gtk_shell and use it to implement
    gtk_window_present.
  - Dropping tabs to create new windows is now supported.
  + Windows:
  - Use a custom drag-resize implementation.
  - Use layered windows.
  - Provide workarea information.
  + OS X: Native zoom and rotate gestures are now supported.
  + Bugs fixed: bgo#583780, bgo#699891, bgo#720950, bgo#748872,
    bgo#756450, bgo#757942, bgo#759899, bgo#760276, bgo#761629,
    bgo#762397, bgo#762811, bgo#762820, bgo#762891, bgo#762902,
    bgo#762907, bgo#762945, bgo#762974, bgo#762996, bgo#763001,
    bgo#763012, bgo#763017, bgo#763023, bgo#763080, bgo#763103,
    bgo#763216, bgo#763285, bgo#763287, bgo#763298, bgo#763351,
    bgo#763380, bgo#763387, bgo#763628, bgo#763650.
  + Updated translations.
* Wed Mar  2 2016 zaitor@opensuse.org
- Update to version 3.19.11:
  + GtkRange, GtkScale and GtkScrollbar have been ported to use
    gadgets.
  + Themes: Windows theme improvements.
  + Inspector:
  - Show input device information.
  - Update monitor information when it changes.
  + Wayland: Implement primary selection (using a private protocol
    with mutter for now).
  + Bugs fixed: bgo#756751, bgo#760482, bgo#761767, bgo#762123,
    bgo#762561, bgo#762593, bgo#762614, bgo#762629, bgo#762677,
    bgo#762713, bgo#762720, bgo#762755, bgo#762820, bgo#762887,
    bgo#762891, bgo#761156, bgo#761686, bgo#762468.
  + Updated translations.
* Wed Feb 24 2016 zaitor@opensuse.org
- Update to version 3.19.10:
  + GTK+ will now list included backends when seeing the
    environment variable GDK_BACKEND=help.
  + Themes:
  - Windows theme improvements.
  - Adwaita cleanups.
  + Wayland: Implement startup notification.
  + Bugs fixed: bgo#309300, bgo#723659, bgo#754743, bgo#756659,
    bgo#760714, bgo#761431, bgo#761432, bgo#761760, bgo#762258,
    bgo#762315, bgo#762319, bgo#762392.
  + Updated translations.
* Wed Feb 17 2016 zaitor@opensuse.org
- Update to version 3.19.9:
  + gtk-builder-tool can now preview .ui files with custom CSS.
  + gtk3-demo now demonstrates saving window sizes in the
    application example, and has many more widgets in the foreign
    drawing example.
  + CSS changes:
  - the rem unit is now supported.
  - calc() expressions are supported, too.
  + Themes:
  - Many fixes to Adwaita.
  - The Windows theme is now included on all platforms.
  + Windows
  - The Classic and XP themes have been dropped.
  - The remaining theme is being fixed to work with CSS nodes.
  - React to theme changes.
  + Quartz: Fix image retrieval from the clipboard.
  + Wayland: Fix a significant buffer leak.
  + Bugs fixed: bgo#677329, bgo#698652, bgo#754990, bgo#759657,
    bgo#760996, bgo#761209, bgo#761309, bgo#761312, bgo#761332,
    bgo#761339, bgo#761363, bgo#761381, bgo#761402, bgo#761428,
    bgo#761474, bgo#761476, bgo#761484, bgo#761552, bgo#761571,
    bgo#761686, bgo#761716, bgo#761757, bgo#761775, bgo#761778,
    bgo#761791, bgo#761792, bgo#761826, bgo#761828, bgo#761829,
    bgo#761838, bgo#761900, bgo#761903, bgo#761954, bgo#762021,
    bgo#762032, bgo#762036, bgo#762067, bgo#762080, bgo#753351,
    bgo#762120, bgo#762165.
  + Updated translations.
* Wed Feb 17 2016 zaitor@opensuse.org
- Update to version 3.19.8:
  + GtkEntry:
  - Complete gadget conversion for entries and spin buttons.
  - Add a visual hint for scrolling ('undershoot').
  + GtkStack: Turn into a no-window widget.
  + CSS changes:
  - Allow loading svg images.
  - Fix baseline handling.
  - -gtk-recolor() works properly with hi-dpi now.
  - image() can be used in CSS now.
  + Themes: New radio / check implementation.
  + Tools: gtk-builder-tool can now preview .ui files.
  + Bugs fixed: bgo#464528, bgo#608865, bgo#688524, bgo#690791,
    bgo#727294, bgo#754868, bgo#754990, bgo#760522, bgo#760714,
    bgo#760754, bgo#760881, bgo#760891, bgo#760897, bgo#760933,
    bgo#760942, bgo#760967, bgo#761005, bgo#761095, bgo#761128,
    bgo#761254, bgo#761026, bgo#761318.
  + Updated translations.
* Wed Feb 17 2016 zaitor@opensuse.org
- Update to version 3.19.7:
  + GtkNotebook:
  - Has been converted to use gadgets.
  - Style properties have been deprecated.
  + GtkTextView: Offers (some) control over cursor blinking.
  + CSS changes:
  - Fix rendering of asymmetric borders.
  - Add CSS names to more widgets.
  - Support recoloring icons with -gtk-recolor.
  + Themes: Many Adwaita fixes.
  + GTK+ widget drawing scalability has been improved (for
    containers with many children, like large list boxes or flow
    boxes).
  + Drag-and-Drop has been rearchitected to move the input handling
    into GDK, where different backends can handle it according to
    their needs and capabilities. The new, 'managed' DND is
    currently implemented for X11 and Wayland.
  + Wayland:
  - Support kinetic scrolling, using the new events in version 5
    of the wl_pointer interface.
  - Suppport DND actions and drag cancellation that were added in
    version 3 of the wl_data_offer interface.
  + Bugs fixed: bgo#722727, bgo#722937, bgo#748327, bgo#756729,
    bgo#757503, bgo#759785, bgo#759898, bgo#760350, bgo#760388,
    bgo#760416, bgo#760427, bgo#760445, bgo#760509, bgo#760524,
    bgo#760525, bgo#760528, bgo#760536, bgo#760572, bgo#760596,
    bgo#760615, bgo#760640, bgo#760663, bgo#760668, bgo#760680,
    bgo#760748, bgo#760754, bgo#756729, bgo#760370.
  + Updated translations.
- Drop gtk3-qemu-usb-tablet-is-no-real-touchscreen.patch: Fixed
  upstream.
* Wed Feb 17 2016 damjanovic.ivo@gmail.com
- Updated to version 3.19.6:
  + CSS changes:
  - CSS margins, border and padding are more consistently
    supported.
  - More widgets support min-width and min-height.
  - More style properties have been superseded by CSS properties.
  - Pseudo state names have been aligned with what CSS uses:
    :disabled instead of :insensitive, :indeterminate instead of
    :inconsistent and :drop(active) instead of :dnd. The old
    names still work.
  - GTK+ specific CSS properties have been prefixed with -gtk-.
    The old names still work.
  - The CSS syntax for Radial gradients is now supported.
  - CSS documentation has been rewritten and expanded.
  + Themes: GTK+ now includes a HighContrastInverse theme which is
    a dark variant of the HighContrast theme.
  + Inspector: The inspector can now highlight widgets that are
    causing resizes, which can be helpful in tracking down
    allocation loops.
  + Wayland:
  - Prefer subsurfaces for temporary windows when possible,
    to fix placement issues.
  - Improve handling of dialogs without transient parent.
  - Force a grab cursor while a popup is shown.
  + Bugs fixed: bgo#728344, bgo#753520, bgo#756618, bgo#757147,
    bgo#757411, bgo#759161, bgo#759299, bgo#759541, bgo#759567,
    bgo#759586, bgo#759607, bgo#759664, bgo#759668, bgo#759670,
    bgo#759705, bgo#759738, bgo#759764, bgo#759768, bgo#759771,
    bgo#759857, bgo#759905, bgo#759917, bgo#760018, bgo#760082,
    bgo#760097, bgo#760141, bgo#760148, bgo#760169, bgo#760188,
    bgo#760202, bgo#760213, bgo#760238, bgo#760314.
  + Updated translations.
- Drop gtk3-fix-gtkborder-build-regression.patch: Fixed upstream.
- Drop gtk3-revert-kp_decimal_handling.patch: fixed upstream.
* Wed Feb 17 2016 fcrozat@suse.com
- Add gtk3-fix-gtkborder-build-regression.patch: backport fix
  gtkborder build regression with some libraries/applications.
* Wed Feb 17 2016 dimstar@opensuse.org
- Update to version 3.19.5:
  + GtkShortcutsWindow: GtkShortcutsGesture has been removed, since
    GtkShortcutsShortcut can now document gestures.
  + GtkFileChooser:
  - The places view now shows the available space when that
    information is available.
  - Problems with remembering the dialog size have been fixed.
  + CSS changes:
  - CSS margins, border and padding are more consistently
    supported.
  - Many widgets now support min-width and min-height.
  - Many style properties have been superseded by CSS properties.
  + Adwaita: Some visual updates and fixes.
  + Wayland: DND with icon widgets is working properly.
  + GDK:
  - More of the DND implementation is now handled in GDK:
    creating the drag window, moving the window along with the
    cursor, the drag cancel animation.
  - GdkSeat is a new API that supersedes grabs on individual
    devices and is a better fit for backends like Wayland or Mir.
  + Bugs fixed: bgo#708394, bgo#729593, bgo#755947, bgo#756191,
    bgo#758929, bgo#759079, bgo#759081, bgo#759091, bgo#759092,
    bgo#759168, bgo#759225, bgo#759260, bgo#759309, bgo#759323.
- Changes from version 3.19.4:
  + GtkPopover can now be instructed to stay within the toplevel
    window on platforms that don't already enforce this (such as
    Wayland).
  + Wayland:
  - Memory leak fixes.
  - Window positioning and sizing fixes.
  - Clipboard and DND fixes.
  - New build dependency: wayland-protocols.
  + CSS changes:
  - The -gtk-image-effect property was renamed to
  - gtk-icon-effect.
  - Active spinners are now :checked, not :active.
  - A -gtk-icontheme property has been added.
  - A -gtk-icon-palette has been added to allow recoloring
    symbolic icons.
  - Drag highlighting uses the new :dnd pseudoclass.
  + DND:
  - Make drag highlighting themable.
  - Stop using RGBA cursors for drag icons (this only ever worked
    on X11).
  - Change the handling of drag windows to work on Wayland. The
    drag window implementation has been moved to GDK, with the
    new function gdk_drag_context_get_drag_window.
  - Non-toplevel widgets can be used as drag widgets.
  + Bugs fixed: bgo#539944, bgo#732742, bgo#735847, bgo#747295,
    bgo#756618, bgo#757147, bgo#757282, bgo#757474, bgo#758483,
    bgo#758484, bgo#758563, bgo#758609, bgo#758634, bgo#758660,
    bgo#758661, bgo#758698, bgo#758713, bgo#758790, bgo#758901,
    bgo#758908, bgo#758930, bgo#758936, bgo#759018.
  + Updated translations.
- Add pkgconfig(wayland-protocols) BuildRequires: new dependency.
- Drop Add gtk3-gdk_pixbuf_get_from_surface.patch: Fixed upstream.
* Wed Feb 17 2016 zaitor@opensuse.org
- Update to version 3.19.3:
  + Theming changes:
  - Non-standard CSS properties have been renamed to have a -gtk-
    prefix (the old names still work, with a warning):
    gtk-key-bindings is now -gtk-key-bindings icon-shadow is now
  - gtk-icon-shadow.
  - CSS parsing errors and warnings are shown in the inspector
  + GtkShortcutsWindow:
  - Widgets are more complete, to allow supporting them in glade.
  - GtkShortcutsShortcut can now show gestures as well,
    GtkShortcutsGesture is no longer needed and will be removed
    soon.
  - GtkShortcutsShortcut supports standard gestures, with
    predefined icons and subtitles.
  + Bugs fixed: bgo#746745, bgo#758025, bgo#758094, bgo#758187,
    bgo#758367, bgo#758407, bgo#758442.
  + Updated translations.
- Changes from version 3.19.2:
  + Most widgets have been ported to CSS nodes. The element names
    and the tree relationships are documented now. The Adwaita and
    HighContrast themes have been mostly kept up-to-date with these
    changes. Third-party themes and custom CSS will need
    adjustments.
  + The inspector now shows CSS nodes and allows to manipulate
    them.
  + Size allocation has been simplified to avoid excessive resizes
    of the entire window.
  + GtkShortcutsWindow can now display direction-dependent
    shortcuts and sequences of keys.
  + Support for native file chooser on Win32 when using the new
    GtkFileChooserNative API, and when using GtkFileChooserButton.
  + The GtkFileChooser interface prerequisite was changed from
    GtkWidget to GObject to allow non-widget filechooser
    implementations.
  + focus-on-click has been moved from various subclasses to
    GtkWidget, so it is now available for every widget, in
    particular GtkListBoxRow.
  + Bugs fixed: bgo#735341, bgo#748904, bgo#756618, bgo#756625,
    bgo#756670, bgo#756978, bgo#757221, bgo#757269, bgo#757324,
    bgo#757358, bgo#757377, bgo#757397, bgo#757805, bgo#757888,
    bgo#757950, bgo#757968, bgo#757984, bgo#758072, bgo#758087,
    bgo#758208, bgo#758327, bgo#758086, bgo#758175.
  + Updated translations.
- Changes from version 3.19.1:
  + Support for help overlays to document keyboard shortcuts and
    gestures has been added.
  + GdkAppLaunchContext is now setting the DISPLAY environment
    variable for X11.
  + Support for GL legacy profiles has been added back.
  + GTK+ now loads compose tables in the format used by XLib from
    ~/.config/gtk-3.0/Compose, ~/.XCompose and the X11 locale
    information.
  + GtkBuilder can now create GFile objects, for use in e.g.
    GFileIcons.
  + New APIs:
  - GtkShortcutsWindow
  - gtk_text_tag_changed
  - gtk_settings_reset_property
  - gdk_rectangle_equal
  - gdk_gl_context_is_legacy
  + A new commandline utility, gtk-query-settings, to query GTK+
    settings, has been added.
  + Theming: Element names are now supported. A number of widgets
    have already been changed to use element names for the widget
    itself and its various subelements. This effort will continue
    in next development releases. This change will require
    adjustments in themes and custom css - as part of this
    transition, the element names and style classes in use are
    documented and will be stable going forward.
  + Debugging: GtkInspector can now edit string-array-valued
    properties.
  + Wayland:
  - Fix transparent terminals.
  - Fix treeview search popups.
  - Fix CSD window resizing / moving.
  + Bugs fixed: bgo#721120, bgo#735341, bgo#753371, bgo#753992,
    bgo#754983, bgo#755008, bgo#755413, bgo#755416, bgo#755654,
    bgo#755791, bgo#755927, bgo#755988, bgo#756042, bgo#756142,
    bgo#756160, bgo#756174, bgo#756195, bgo#756338, bgo#756428,
    bgo#756439, bgo#756449, bgo#756496, bgo#756505, bgo#756568,
    bgo#756589, bgo#756618, bgo#756625, bgo#756751, bgo#756770,
    bgo#756852, bgo#756881, bgo#756886, bgo#756780, bgo#757147.
  + Updated translations.
* Tue Feb 16 2016 fcrozat@suse.com
- Add patch gtk3-revert-kp_decimal_handling.patch: revert
  kp_decimal locale-based handling (already reverted upstream)
  (bgo#756751).
* Thu Jan 28 2016 zaitor@opensuse.org
- Update to version 3.18.7:
  + Bugs fixed: bgo#688524, bgo#722937, bgo#728344, bgo#754868,
    bgo#757147, bgo#758908, bgo#758929, bgo#759079, bgo#759081,
    bgo#759091, bgo#759260, bgo#759757, bgo#760141, bgo#760169,
    bgo#760416, bgo#760445, bgo#760615, bgo#760680, bgo#760891,
    bgo#760897, bgo#760964, bgo#761005, bgo#761095.
  + Updated translations.
- Drop gtk3-qemu-usb-tablet-is-no-real-touchscreen.patch and
  gtk3-gdk_pixbuf_get_from_surface.patch: Fixed upstream.
* Wed Jan 13 2016 mgorse@suse.com
- Add gtk3-bgo725733.patch: don't use signals for a11y. Fixes a
  crash. Backported from upstream (bsc#960612).
* Mon Jan 11 2016 dimstar@opensuse.org
- Add gtk3-qemu-usb-tablet-is-no-real-touchscreen.patch: The QEMU
  USB Tablet is not really a touchscreen - although it simulates
  it for VNC based viewers (making mouse-input more reliable).
  This patch fixes issues where openQA was not able to correctly
  handle the CTRL-ALT-DEL handler to show the logout dialog.
* Sat Dec 26 2015 zaitor@opensuse.org
- Add gtk3-gdk_pixbuf_get_from_surface.patch: Restore old behavior.
* Sun Dec  6 2015 zaitor@opensuse.org
- Update to version 3.18.6:
  + Bugs fixed: bgo#539944, bgo#732742, bgo#735847, bgo#746745,
    bgo#747295, bgo#748904, bgo#757358, bgo#758025, bgo#758072,
    bgo#758175, bgo#758327, bgo#758367, bgo#758407, bgo#758483,
    bgo#758484, bgo#758660, bgo#758661, bgo#758698, bgo#758790.
  + Updated translations.
* Sat Dec  5 2015 mgorse@suse.com
- Add gtk3-bsc957399-gdkcairo-surface-error.patch: don't abort when
  trying to paint a surface with an error (bsc#957399).
* Mon Nov 16 2015 zaitor@opensuse.org
- Update to version 3.18.5:
  + GtkFileChooser:
  - Make sure external drives show up either in the sidebar or
    the places view.
  - Ignore double-click events.
  + Avoid some crashes in CSS parsing error handling.
- Drop
  gtk3-gtkplacessidebar-improve-heuristics-external-drives.patch:
  Fixed upstream.
* Sat Nov 14 2015 zaitor@opensuse.org
- Add
  gtk3-gtkplacessidebar-improve-heuristics-external-drives.patch:
  Add missed commit for the sidebar refactor, without this external
  drives are not shown anywhere (bgo#756589).
* Thu Nov 12 2015 zaitor@opensuse.org
- Update to version 3.18.4:
  + Revert a GtkTextBuffer change that broke binding API.
  + Properly refresh styles when widget names change.
* Mon Nov  9 2015 zaitor@opensuse.org
- Update to version 3.18.3:
  + Bugs fixed: bgo#735342, bgo#753992, bgo#755654, bgo#756160,
    bgo#756385, bgo#756449, bgo#756496, bgo#756505, bgo#756568,
    bgo#756589, bgo#756625, bgo#756751, bgo#756780, bgo#756886,
    bgo#757147, bgo#757221, bgo#757298, bgo#757303, bgo#757324,
    bgo#757358, bgo#757377, bgo#757544.
  + Updated translations.
- Drop gtk3-places-sidebar-no-crash.patch: Fixed upstream.
* Thu Oct 29 2015 dimstar@opensuse.org
- Add gtk3-places-sidebar-no-crash.patch: Do not crash if dragging
  something over the places sidebar, that has no valid URI (mostly
  coming from a host system into a guest system) (boo#952356,
  bgo#757298).
* Mon Oct 12 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Bugs fixed: bgo#753371, bgo#755413, bgo#755791, bgo#755927,
    bgo#755988, bgo#756042, bgo#756195, bgo#756338.
  + Updated translations.
* Sun Oct  4 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Speed up rounded rectangle drawing by caching arcs.
  + Make popover animations faster.
  + Robustness fixes in GtkAppChooser.
  + Avoid showing duplicate entries in GtkAppChooser.
  + Inspector: ellipsize accessible names.
  + Bugs fixed: bgo#582747, bgo#751368, bgo#751787, bgo#753628,
    bgo#755038, bgo#755215, bgo#755268, bgo#755432, bgo#755435,
    bgo#755444, bgo#755455, bgo#755473, bgo#755528, bgo#755691,
    bgo#755692, bgo#755926, bgo#755931, bgo#755954.
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Speed up shadow drawing by caching corner shadows.
  + Memory leak fixes.
  + Bugs fixed: bgo#681965, bgo#754098, bgo#754629, bgo#754745,
    bgo#754952, bgo#755021, bgo#755274, bgo#755352,
  + Updated translations.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.9:
  + GtkPopover has been changed back to not inherit its style from
    the widget it is attached to.
  + The Ctrl-K key binding has been dropped from GtkEntry to avoid
    conflict with a firefox shortcut.
  + Theme:
  - Adwaita: fixes for rubberbanding, icon view highlighting.
  - HighContrast: fixes for path bar, linked entries, color
    button.
  + Wayland: Fix assertions when using GL.
  + gtk3-demo can now launch individual demos from the commandline.
  + Various optimizations:
  - Use g_object_notify_by_pspec.
  - Reduce g_return_if_fail in internal APIs.
  - Speed up some bitmask operations.
  - Avoid some copies in inner loops.
  - Make better use of GQuarks.
  - Use CAIRO_CONTENT_COLOR when possible.
  - Avoid allocations and referencing during repaint.
  - Stop sending Expose events for most widgets.
  - Avoid ::draw and ::size-allocate signal overhead when
    possible.
  + Bugs fixed: bgo#753431, bgo#753628, bgo#754143, bgo#754410,
    bgo#754411, bgo#754535, bgo#754559, bgo#754658, bgo#754687,
    bgo#754746, bgo#754770, bgo#754854, bgo#754866, bgo#754928,
    bgo#754987, bgo#754839.
  + Updated translations.
* Thu Sep  3 2015 zaitor@opensuse.org
- Update to version 3.17.8:
  + GtkFileChooser:
  - Show network:/// in the places view.
  - Provide better loading feedback.
  + GtkTextView: Fix fallout from margin/padding addition.
  + GtkOverlay: Always align widgets relative to the overlay, not
    to the main widget.
  + GtkListBox: Support focusable headers.
  + Theme:
  - Improve performance of GtkListBox.
  - Better GtkCalendar theming.
  + Wayland:
  - Make most tests work under Wayland.
  - Closing displays works now.
  - Fix key repeat sometimes running wild.
  + Bugs fixed: bgo#345345, bgo#736125, bgo#752615, bgo#753185,
    bgo#753357, bgo#753495, bgo#753644, bgo#753694, bgo#753786,
    bgo#753815, bgo#753856, bgo#753925, bgo#753969, bgo#754022,
    bgo#754086, bgo#754133, bgo#754150, bgo#754158, bgo#754410,
    bgo#754421.
  + Updated translations.
* Tue Aug 18 2015 zaitor@opensuse.org
- Update to version 3.17.7:
  + GtkFileChooser: Various refinements to the places view.
  + GtkFontChooser:
  - Make Escape stop search.
  - Various other keynav improvements.
  + GtkColorChooser: Make it possible to start with the editor.
  + GtkTextView:
  - Support top margins.
  - Use CSS padding from the theme.
  + GtkFlowBox: Allow using a GListModel.
  + GtkCellRendererText: Support alpha in foreground color.
  + Theme and CSS: HighContrast theme improvements.
  + GDK: Add support for touchpad gesture events.
  + OS X: Implement CSD resize for all corners and edges.
  + Wayland: Support touchpad gestures.
  + Bugs fixed: bgo#737804, bgo#752814, bgo#753329, bgo#753357,
    bgo#753391, bgo#753392, bgo#753451, bgo#753568, bgo#753621,
    bgo#406159, bgo#746435.
  + Updated translations.
* Thu Aug  6 2015 zaitor@opensuse.org
- Update to version 3.17.6:
  + GtkFileChooser:
  - Handle ., / and ~ in the location entry.
  - Improve keyboard navigation in save mode.
  - Don't search recursively in remote locations.
  - Allow activating without double-click.
  + GtkFontChooser: Bring back a lazy loading optimization that was
    lost.
  + GtkWindow:
  - Fix handling of window states before the window is mapped.
  - Add API to fullscreen on a given monitor.
  + GtkTextView: Support font features on tags.
  + Theme and CSS
  - Various HighContrast theme fixes and improvements.
  - Reduce redraws caused by irrelevant style changes.
  + gtk-demo gained some more examples.
  + GtkInspector
  - Show wayland display information.
  - Show monitor information.
  - Preserve the selected object when rescanning the object tree.
  + X11: Make copy-paste work across multiple screens again.
  + Bugs fixed: bgo#579466, bgo#610925, bgo#652085, bgo#721398,
    bgo#734984, bgo#741685, bgo#746491, bgo#748772, bgo#749339,
    bgo#751721, bgo#752327, bgo#752577, bgo#752633, bgo#752638,
    bgo#752664, bgo#752677, bgo#752707, bgo#752708, bgo#752761,
    bgo#752765, bgo#752810, bgo#752875, bgo#752920, bgo#752960,
    bgo#752965, bgo#752969, bgo#752975, bgo#752977, bgo#752978,
    bgo#753048, bgo#753051, bgo#753060, bgo#753130, bgo#753138,
    bgo#753142, bgo#753230, bgo#753256, bgo#753284.
  + Updated translations.
* Thu Jul 23 2015 zaitor@opensuse.org
- Update to version 3.17.5:
  + GtkFileChooser:
  - Always search in the current location, and indicate this in
    the subtitle. Show progress for long searches, and show a
    nice empty state.
  - Make search in recent files work.
  - Fix sorting order of recent files and search results.
  - Various improvements to keyboard navigation:
    . Ctrl-F toggles search.
    . . opens location entry.
    . Alt-P focuses the sidebar.
    . Escape stops search and closes the location entry.
  - Move the name entry to the header bar in Save modes.
  - Don't show Trash and Recent in the sidebar in Save modes.
  - Allow renaming and deleting files in Save modes.
  - Improved sizing behavior of columns.
  - Improved formatting of the time and location columns.
  - Time column can show date and time.
  - Move fixed and network drives and volumes from the sidebar
    to a new view that also allows to connect to remote servers.
  - Use popovers for context menus and support long press to make
    them accessible with touch.
  + GtkScrolledWindow:
  - Keep scrollbars below treeview headers.
  - Switch the roles of secondary and middle click on scrollbar
    steppers:
    . Primary click starts low-speed autoscrolling.
    . Secondary click start high-speed autoscrolling.
    . Middle click scrolls to the end.
  - Tweak button bindings on scrollbars (and scales):
    . Primary click warps to the location.
    . Primary click with Shift jumps by pages.
    . Secondary click starts variable-speed autoscrolling.
  + Theme and CSS:
  - GtkSwitch has a new slider-height style property to make
    square switches possible.
  - Support CSS letter-spacing for labels and entries.
  - Partial support for CSS text-decoration.
  + Font handling: Per-widget font options and font maps are
    supported now.
  + gtk-demo has various new and improved examples.
  + X11: Fix rendering stalls over remote ssh connections.
  + Wayland:
  - Various fixes to make Copy-Paste and Drag-and-Drop work
    better.
  - Ignore size increments for maximized and fullscreen windows.
  - Fix cursor handling in hi-dpi.
  + Mir: Various fixes and improvements.
  + Broadway: Windows can now be maximized:
  + Bugs fixed: bgo#325150, bgo#593372, bgo#720684, bgo#741800,
    bgo#748892, bgo#750870, bgo#750994, bgo#751341, bgo#751368,
    bgo#751401, bgo#751414, bgo#751443, bgo#751447, bgo#751448,
    bgo#751625, bgo#751677, bgo#751689, bgo#751739, bgo#751752,
    bgo#751754, bgo#751793, bgo#751800, bgo#751805, bgo#751811,
    bgo#751877, bgo#751910, bgo#752000, bgo#752016, bgo#752025,
    bgo#752034, bgo#752088, bgo#752093, bgo#752131, bgo#752509,
    bgo#752520, bgo#309300, bgo#725551, bgo#751812, bgo#752502,
    bgo#752616, bgo#752599.
  + Updated translations.
* Thu Jul 23 2015 dimstar@opensuse.org
- Update to version 3.17.4:
  + GtkStack animates size changes
  + GtkListBox and GtkFlowBox support positional css selectors
    like :first-child, :last-child and :nth-child
  + GtkPlacesSidebar has been rewritten to use GtkListBox
  + Touch selection in GtkTextView and GtkEntry has been greatly
    improved
  + There's now a way to have output-only windows, and this is
    used by GtkOverlay for pass-through overlays
  + Bugs fixed: bgo#724506, bgo#725441, bgo#745957, bgo#747793,
    bgo#748951, bgo#749650, bgo#749717, bgo#749737, bgo#750058,
    bgo#750068, bgo#750338, bgo#750343, bgo#750384, bgo#750396,
    bgo#750424, bgo#750477, bgo#750489, bgo#750505, bgo#750568,
    bgo#750605, bgo#750631, bgo#750690, bgo#750692, bgo#750718,
    bgo#750741, bgo#750883, bgo#750888, bgo#750892, bgo#750993,
    bgo#751018, bgo#751050, bgo#751082, bgo#751084, bgo#751098,
    bgo#751099, bgo#751169, bgo#751341.
  + Updated translations.
- Rebase gtk3-path-local.patch.
* Thu Jul 23 2015 zaitor@opensuse.org
- Update to version 3.17.3:
  + Respin to fix the tarball.
* Thu Jul 23 2015 dimstar@opensuse.org
- Update to version 3.17.2:
  + GtkFontChooser:
  - Allow custom font maps, to support application-specific
    fonts.
  - Improve the 'no search results' page.
  + GtkFileChooser:
  - Change simple search engine to search breadth-first.
  - Make the simple search engine use GIO, so it works on remote
    shares too.
  - Merge results from the tracker and simple search engines.
  - Add a 'no search results' page.
  + GtkPlacesSidebar: Use a popover for renaming bookmarks.
  + GtkPopover: Add support for default widgets.
  + GtkScrolledWindow: Support kinetic scrolling on touchpads.
  + GtkBuilder:
  - Improve error reporting.
  - gtk-builder-tool can validate templates.
  - gtk-builder-tool can enumerate named objects.
  + gtk3-demo:
  - New cursors demo.
  - New page setup demo.
  - Builder demo ported away from GtkUIManager.
  + GDK: Make css cursor names work across backends.
  + Windows:
  - Require Vista or newer.
  - Support RGBA windows.
  - Support css cursor names.
  - Support animated cursors.
  - Add cursor theme support. To take advantage of this, you will
    need a new adwaita-icon-theme with Windows cursors.
  + Wayland:
  - Remove assumptions on ordering of globals in startup.
  - Improve DND support in various places.
  - Support css cursor names.
  + X11:
  - Support XRANDR 1.5 monitor objects.
  - Support css cursor names.
  + OS X: Support css cursor names.
  + Bugs fixed: bgo#619493, bgo#693738, bgo#719683, bgo#719819,
    bgo#727316, bgo#744086, bgo#746916, bgo#747150, bgo#747634,
    bgo#747664, bgo#748234, bgo#748615, bgo#748640, bgo#748763,
    bgo#748771, bgo#748782, bgo#748783, bgo#748784, bgo#748833,
    bgo#749009, bgo#749012, bgo#749021, bgo#749178, bgo#749425,
    bgo#749451, bgo#749593, bgo#749679, bgo#749770, bgo#749893.
  + Updated translations.
* Thu Jul 23 2015 dimstar@opensuse.org
- Update to version 3.17.1:
  + Themes:
  - Many HighContrast theme improvements.
  - Stronger entry focus in Adwaita.
  - Improve client-side decorations without a compositor.
  + Scrolling:
  - Support horizontal wheel scrolling with Shift.
  - Make indicators pop up reliably.
  - Detect more trackpoints.
  - Handle pens, erasers and similar devices.
  + GtkTextView: Support underline and strikethrough color.
  + GtkFileChooser:
  - Open location entry more easily.
  - Ensure a directory is loaded.
  - Use a popover for new folder names.
  + GtkBuilder:
  - Improve error messages.
  - Add a gtk-builder-tool utility for ui file validation.
  + Inspector:
  - Show accessible name and description.
  - Add a tab for CSS nodes.
  + Wayland:
  - DND and clipboard fixes.
  - Support attached modal dialogs with mutter.
  + Windows:
  - Drop XP support.
  - Support horizontal mouse wheel scrolling.
  + Bugs fixed: bgo#132197, bgo#402168, bgo#671362, bgo#723394,
    bgo#734741, bgo#737175, bgo#741849, bgo#745721, bgo#746149,
    bgo#746188, bgo#746202, bgo#746301, bgo#746358, bgo#746368,
    bgo#746369, bgo#746370, bgo#746386, bgo#746435, bgo#746468,
    bgo#746493, bgo#746586, bgo#746602, bgo#746668, bgo#746688,
    bgo#746706, bgo#746712, bgo#746746, bgo#746784, bgo#746817,
    bgo#746821, bgo#746862, bgo#746893, bgo#746904, bgo#746925,
    bgo#746961, bgo#747096, bgo#747121, bgo#747133, bgo#747288,
    bgo#747305, bgo#747406, bgo#747407, bgo#747469, bgo#747471,
    bgo#747524, bgo#747539, bgo#747553, bgo#747560, bgo#747604,
    bgo#747608, bgo#747689, bgo#747805, bgo#747808, bgo#747827,
    bgo#748013, bgo#748014, bgo#748061, bgo#748156, bgo#748341,
    bgo#748346, bgo#748500, bgo#748509.
  + Updated translations.
* Tue Jul 21 2015 zaitor@opensuse.org
- Update to version 3.16.6:
  + OS X: Partial aspect ratio support.
  + Revert a problematic change to scroll event handling.
  + Bugs fixed: bgo#741800, bgo#751401, bgo#751625, bgo#752016,
    bgo#752093, bgo#752520.
  + Updated translations.
- Drop
  gtk3-Revert-x11-Query-pointer-devices-scroll-valuators.patch:
  Fixed upstream.
* Wed Jul 15 2015 zaitor@opensuse.org
- Add gtk3-Revert-x11-Query-pointer-devices-scroll-valuators.patch:
  Revert a commit as it makes hardware mouse-wheel scrolling
  unreliable (bgo#752184).
* Tue Jul  7 2015 zaitor@opensuse.org
- Update to version 3.16.5:
  + Fix ridge/groove border rendering.
  + GtkListBoxRow: propagate in the draw vfunc.
  + Bugs fixed: bgo#750489, bgo#750605, bgo#750690, bgo#750718,
    bgo#750870, bgo#750888, bgo#750994, bgo#751018, bgo#751050,
    bgo#751082, bgo#751227, bgo#751443, bgo#751739, bgo#751752,
    bgo#751754.
  + Updated translations.
* Thu Jun 18 2015 dimstar@opensuse.org
- Move pkgconfig(epoxy) BuildRequires out of with_wayland
  condition: it is used independent of wayland support.
* Wed Jun 10 2015 zaitor@opensuse.org
- Update to version 3.16.4:
  + Bugs fixed: bgo#693738, bgo#719683, bgo#745957, bgo#749451,
    bgo#749593, bgo#749893, bgo#750058, bgo#750384, bgo#750477,
    bgo#750505.
  + Updated translations.
* Tue May 12 2015 zaitor@opensuse.org
- Update to version 3.16.3:
  + Bugs fixed: bgo#737175, bgo#746916, bgo#746925, bgo#747634,
    bgo#747805, bgo#747808, bgo#748013, bgo#748014, bgo#748061,
    bgo#748341, bgo#748346, bgo#748500, bgo#748615, bgo#748640,
    bgo#748782, bgo#748783, bgo#748992, bgo#749009, bgo#749012,
    bgo#749021.
  + Updated translations.
* Tue Apr 14 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Avoid a crash in GtkApplication.
  + Avoid a crash with GtkTreeview rubberbanding.
  + GtkApplication: Prevent more crashes around shutdown.
  + Prevent tab close button size changes.
  + Bugs fixed: bgo#746706, bgo#747288, bgo#747471, bgo#747539,
    bgo#747608, bgo#747689.
  + Updated translations.
- Drop gtk3-find-wayland-includedir.patch: Not needed anymore.
- Disable gtk3-bnc130159-bgo319483-async-font-selection.patch:
  Upstream bug was closed as obsolete in 2011, lets disable for now
  and see if anyone misses it.
* Wed Apr  8 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Improve client-side decorations without a compositor.
  + Bugs fixed: bgo#132197, bgo#402168, bgo#613833, bgo#671362,
    bgo#734741, bgo#737175, bgo#746222, bgo#746253, bgo#746301,
    bgo#746391, bgo#746468, bgo#746586, bgo#746602, bgo#746688,
    bgo#746712, bgo#746746, bgo#746784, bgo#746817, bgo#746821,
    bgo#746862, bgo#746893, bgo#746904, bgo#746961, bgo#747096,
    bgo#747133, bgo#747305, bgo#747406, bgo#747407.
  + Updated translations.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Theming: Fixes for the HighContrast theme.
  + Wayland: Fix Clipboard handling.
  + Bugs fixed: bgo#746148, bgo#746149, bgo#746188, bgo#746358,
    bgo#746368, bgo#746369, bgo#746370, bgo#746386.
  + Updated translations.
* Thu Mar 19 2015 dimstar@opensuse.org
- Rebase and re-enable gtk3-path-local.patch.
* Tue Mar 17 2015 dimstar@opensuse.org
- Update to version 3.15.12:
  + GtkMenuButton: Improve accessible names.
  + GtkCellRendererPixbuf: Always follow state changes, the
    ::follow-state property is now ignored. This is necessary to
    make HighContrast and symbolic icons remain visible e.g. in
    selected rows.
  + GtkEntry: Rework the size allocation code to be less arcane.
    This changed the semantics of the get_frame_size() vfunc.
    GtkEntry subclasses that override this vfunc may need
    adjustment.
  + Wayland: Support hi-dpi cursors.
  + Bugs fixed: bgo#745829, bgo#746141, bgo#746192, bgo#746201,
    bgo#746202, bgo#746205, bgo#746282, bgo#746301.
  + Updated translations.
* Thu Mar 12 2015 zaitor@opensuse.org
- Update to version 3.15.11:
  + Go back to requiring GTK_FRAME_EXTENTS support for CSD, to fix
    shadow problems in KDE.
  + Print dialog: Fix icons in HighContrast.
  + Fix selected menu items in HighContrast.
  + App chooser: Fix icons in HighContrast.
  + Bugs fixed: bgo#535929, bgo#577862, bgo#669008, bgo#712760,
    bgo#739070, bgo#744288, bgo#744589, bgo#745065, bgo#745463,
    bgo#745479, bgo#745562, bgo#745578, bgo#745622, bgo#745721,
    bgo#745918, bgo#745969, bgo#746013.
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.10:
  + GtkFileChooser:
  - Don't start search too eagerly.
  - Use fts with tracker.
  - Make tracker queries more similar to nautilus.
  + GtkWindow: Improve window dragging on header bars.
  + Printing:
  - Make avahi-browsed printers work.
  - Set printer state correctly.
  + Wayland:
  - Exit cleanly if the compositor goes away.
  - Don't ignore early maximization/fullscreening.
  - Make subsurface popovers work under Weston.
  + GL: Port GdkGears example to modern OpenGL.
  + Bugs fixed: bgo#703610, bgo#729366, bgo#741511, bgo#743323,
    bgo#743427, bgo#744879, bgo#745225, bgo#745263, bgo#745289,
    bgo#745303, bgo#745315, bgo#745344, bgo#745400.
  + Updated translations.
* Thu Feb 26 2015 dimstar@opensuse.org
- Update to version 3.15.9:
  + GtkScrolledWindow:
  - Avoid 'jumping' when zoom scrolling kicks in.
  - Make zoom scrolling less easy to trigger.
  - Make steppers use smooth autoscrolling.
  + Input methods can now be turned off entirely, which can be
    useful to free up the Ctrl-Shift-u shortcut.
  + Add some DND support to gtk3-icon-browser.
  + Bugs fixed: bgo#696505, bgo#744942, bgo#744991, bgo#745052,
    bgo#745076.
  + Updated translations.
- Add pkgconfig(json-glib-1.0) and pkgconfig(rest-0.7)
  BuildRequires: used to enable cloud printing.
- Add explicit gettext-tools BuildRequires: the build uses msgfmt,
  but in some rare occasions, gettext-tools-mini is favored, which
  does not provide this tool.
* Thu Feb 26 2015 dimstar@opensuse.org
- Update to version 3.15.8:
  + CSS: Support animated font weight changes.
  + GtkScrolledWindow: Ensure indicators appear in the correct
    place.
  + Wayland: DND fixes.
  + GtkPopover: has a map/unmap animation now.
  + Bugs fixed: bgo#743647, bgo#744054, bgo#744683.
  + Updated translations.
* Thu Feb 26 2015 dimstar@opensuse.org
- Update to version 3.15.7:
  + GtkListBox now supports models with gtk_list_box_bind_model.
  + GtkNotebook has a new function to support tab dnd.
  + GtkSidebar was renamed to GtkStackSidebar to better convey what
    it does.
  + GtkFileChooser now has a location column for search.
  + GdkGLProfile has been removed.
  + Bugs fixed: bgo#695945, bgo#708320, bgo#741946, bgo#743350,
    bgo#744148, bgo#744172, bgo#744204, bgo#744394, bgo#744400,
    bgo#744407, bgo#744455.
  + Updated translations.
* Thu Feb 26 2015 zaitor@opensuse.org
- Update to version 3.15.6:
  + stylecontext: Don't use cache when unsaved. Fixes
    image-load-from-file reftest.
- Changes from version 3.15.5:
  + GTK+ types now support the GLib g_autoptr() facility for
    automatic cleanup of automatic variables. GTK+ itself does
    not use g_autoptr() internally.
  + GtkSearchEntry has gained ::next-match, ::previous-match
    and ::stop-search signals and a gtk_search_entry_handle_event()
    function, which help in providing a richer search experience
    and make search entries usable outside of GtkSearchBar.
  + GtkFileChooser:
  - The search has been reintegrated in the UI, there is now
    a toggle button on the header bar to go to search mode,
    in addition to the Alt-S shortcut.
  - The file chooser button now accepts files by drag-and-drop
    properly.
  + GtkScrolledWindow has gained a new ::edge-reached signal, which
    triggers when the edge of the scrollable area is reached.
  + CSS: Performance improvements.
  + OpenGL:
  - It is now possible to specify the required GL version, as
    well as some other options (debug, forward compatible) when
    creating a GdkGLContext.
  - Support for the OpenGL legacy profile has been dropped. Most
    examples have been updated, with the exception of gdkgears,
    which will be fixed in the next snapshot.
  - Use shader version 1.50.
  + Mir backend: Many improvements.
  + Bugs fixed: bgo#712752, bgo#725164, bgo#732051, bgo#735316,
    bgo#740336, bgo#740613, bgo#742636, bgo#742953, bgo#743146,
    bgo#743193, bgo#743229, bgo#743257, bgo#743286, bgo#743330,
    bgo#743341, bgo#743393, bgo#743422, bgo#743451, bgo#743592,
    bgo#743593, bgo#743633, bgo#743638, bgo#743647, bgo#743659,
    bgo#743660, bgo#743680, bgo#613833, bgo#741946, bgo#742566,
    bgo#742848, bgo#743395, bgo#743640, bgo#743770, bgo#743894,
    bgo#743917, bgo#743975, bgo#744203, bgo#744212.
  + Updated translations.
* Thu Feb 26 2015 dimstar@opensuse.org
- Update to version 3.15.4:
  + GtkTextView:
  - Allow to customize multi-click behaviors, using the new
    ::extend-selection signal.
  - Selection can now be extended by scrolling.
  - Better behavior and appearance for text selection with touch.
  + GtkApplication:
  - Use app menu fallback with ssh connections.
  - Provide a mechanism to hide unnecessary app menu items on
    OS X, so a single menu file can be used across platforms.
  + GtkCalendar:
  - Show other months in a different color under Adwaita again.
  - Ensure we always show a bit of the other month on both ends.
  + GtkScrolledWindow: Make overlay scrollbars more dynamic.
  + GtkFileChooser:
  - Make bookmark DND insert at the right location.
  - Make '~' and '/' work in recent mode.
  - Make Ctrl-L work in recent mode.
  - Re-integrate search.
  + CSS:
  - Introduce immutable style nodes.
  - Performance improvements.
  - Reduced memory consumption.
  + GtkInspector:
  - Add a magnifier for the selected widget.
  - Show more display information.
  - Show memory address of objects.
  + Wayland:
  - Use subsurfaces for popovers, so popovers can extend beyond
    the window boundaries.
  - Prefer the Wayland backend over X11 if both are available.
  + GL:
  - Fix interaction with hi-dpi.
  - Add OpenGL support to the Windows backend.
  + Bugs fixed: bgo#111503, bgo#301835, bgo#477454, bgo#671802,
    bgo#671895, bgo#674537, bgo#705582, bgo#710612, bgo#738338,
    bgo#738891, bgo#739038, bgo#740758, bgo#740795, bgo#741259,
    bgo#741569, bgo#741610, bgo#741652, bgo#741702, bgo#741827,
    bgo#741897, bgo#741969, bgo#742010, bgo#742170, bgo#742181,
    bgo#742243, bgo#742311, bgo#742343, bgo#742518, bgo#742631,
    bgo#742646, bgo#742653, bgo#742664, bgo#742702, bgo#742704,
    bgo#742727, bgo#742764, bgo#742771, bgo#742774, bgo#742778,
    bgo#742785, bgo#742786, bgo#742940, bgo#742980, bgo#743037,
    bgo#743101, bgo#743117, bgo#743157.
  + Updated translations.
* Thu Feb 26 2015 zaitor@opensuse.org
- Update to version 3.15.3:
  + GtkTextView:
  - Font fallback and letter spacing can be controlled with tags
    now.
  - Pango markup can be inserted in text buffers.
  + GtkEntry now has API to grab focus without selecting the
    contents.
  + GtkWindow now starts from the focused widget when looking for
    actions that are activated by accelerators.
  + GtkScrolledWindow draws an indication where an edge if hiding
    some content that can be scrolled in.
  + GtkStack has gained GtkNotebook-like focus handling.
  + Theming:
  - Support :not() in CSS.
  - GtkRange now supports :hover for the whole widget.
  - The HighContrast theme has caught up with some never GTK+
    features.
  - Avoid excessive shadow redraws.
  + Build:
  - gtk3-update-icon-cache is no longer used at build time, and
    the --enable-gtk2-dependency configure option has been
    removed.
  - The examples that are used in the documentation can now be
    built standalone.
  + Inspector:
  - Allow extension with loadable modules, the first use for this
    is gjs-inspector, which adds a JavaScript prompt.
  - Allow testing cursor theme changes.
  + Bugs fixed: bgo#59390, bgo#364566, bgo#461249, bgo#674537,
    bgo#708857, bgo#710793, bgo#721939, bgo#722781, bgo#729927,
    bgo#730232, bgo#730364, bgo#735122, bgo#735838, bgo#739453,
    bgo#739729, bgo#739977, bgo#740162, bgo#740287, bgo#740358,
    bgo#740374, bgo#740438, bgo#740447, bgo#740537, bgo#740605,
    bgo#740612, bgo#740613, bgo#740642, bgo#740682, bgo#740742,
    bgo#740770, bgo#740812, bgo#740851, bgo#740857, bgo#740860,
    bgo#740862, bgo#740863, bgo#740876, bgo#740896, bgo#740904,
    bgo#740954, bgo#740983, bgo#741027, bgo#741041, bgo#741117,
    bgo#741130, bog#741185, bgo#741249, bgo#741250, bgo#741251,
    bgo#741252, bgo#741254, bgo#741314, bgo#741375.
- Drop gtk3-support-cups-older-than-1.6.patch: Fixed upstream.
- Rebase gtk3-find-wayland-includedir.patch.
* Thu Feb 26 2015 zaitor@opensuse.org
- Update to version 3.15.2:
  + GtkPopoverMenu: A GtkPopover subclass that makes it easy to
    manually build menu-like popovers which can include arbitrary
    controls.
  + GtkModelButton: A button widget that is optimized for use
    inside popovers with a GAction as 'model'.
  + GL support:
  - Try harder to pick good visuals.
  - Rework the way GL rendering is done in GtkGLArea.
  - Support input events in GtkGLArea.
  - Use shaders.
  - The GDK_GL environment variable can be used for debugging.
  + Inspector:
  - Make picking widgets work in Wayland.
  - Rework search in all pages.
  - Improve space use.
  - Support GL information and debug flags.
  - Shield the inspector window from more debug settings.
  - Hide empty tabs.
  + Theming:
  - Include the HighContrast theme.
  - Add borders to menus in non-composited environments.
  - Load themes from versioned directories like
    .../themes/Emerald/gtk-3-14/.
  + Wayland:
  - Make window opacity work.
  - Propagate clipboard owner changes.
  + Mir:
  - Improved event handling.
  - Support cursors.
  - Enable CSD.
  - Better monitor support.
  - Add OpenGL support.
  + Deprecations:
  - gdk_cursor_new.
  - gdk_device_grab_info_libgtk_only.
  - gdk_display_open_default_libgtk_only.
  - gdk_add_option_entries_libgtk_only.
  - gdk_pre_parse_libgtk_only.
  + Bugs fixed: bgo#687963, bgo#734140, bgo#737891, bgo#738321,
    bgo#738648, bgo#738670, bgo#738800, bgo#738887, bgo#739474,
    bgo#739750, bgo#739781, bgo#739885, bgo#739977, bgo#740011,
    bgo#740346.
  + Updated translations.
- Drop gtk3-Dont-crash-if-invisible-files-are-deleted.patch: Fixed
  upstream.
* Thu Feb 26 2015 zaitor@opensuse.org
- Update to version 3.15.1:
  + An experimental mir backend has been added. Use
  - -enable-mir-backend to build it.
  + Inspector:
  - Show more information.
  - Use a separate display connection.
  + Deprecations: GtkStyleProperties.
  + Bugs fixed: bgo#707695, bgo#738982, bgo#739001 bgo#739150.
- Changes from version 3.15.0:
  + GDK supports rendering windows using OpenGL; currently
    this is implemented for X11 and Wayland using libepoxy.
  + GtkGLArea: A new widget for rendering with OpenGL.
  + GtkSidebar: A new switcher for GtkStack that looks like a
    sidebar.
  + Better typography: In many places, we now use proper Unicode
    characters for dashes, quotes, multiplication signs and the
    like, instead of ASCII approximations.
  + Theming:
  - Context menus use the default font instead of inheriting from
    the widget they are attached to.
  - Theming engines are no longer used.
  - Backdrop style has been fine-tuned to make the difference to
    the active window more evident without affecting readability.
  + Inspector:
  - Show nested tree models.
  - Add a checkbox to disable the warning dialog.
  - Rearrange the UI to gain space.
  - Show object counts.
  + GtkTextView has a monospace property.
  + GtkPaned has a wide-handle property.
  + GtkPrintUnixDialog:
  - Has improved appearance without headerbars.
  - Better rendering of sheet icons.
  - No more missing icons.
  + GtkScrolledWindow:
  - A new policy, GTK_POLICY_EXTERNAL, which allows scrolling
    without showing a scrollbar.
  - Scroll events can now overshoot as well.
  - The new signal ::edge-overshot is emitted when the scrolled
    window is fully overshot.
  - Scrollbars will be overlayed as narrow indicators when there
    is no mouse.
  + Deprecations:
  - gdk_window_set_static_gravities.
  - gdk_window_set_composited.
  - gtk_style_context_get_background_color.
  - gtk_style_context_get_border_color.
  - gtk_settings_set_string/long/double_property.
  - gtk_settings_install_property.
- Add pkgconfig(wayland-egl) and pkgconfig(epoxy), new
  dependencies.
- Add gtk3-support-cups-older-than-1.6.patch: Fix building with
  cups older than 1.6. Taken from upstream git.
* Thu Feb 26 2015 zaitor@opensuse.org
- Update to version 3.14.9 (boo#916784):
  + GtkScrolledWindow:
  - Avoid 'jumping' when zoom scrolling kicks in.
  - Make zoom scrolling less easy to trigger.
  + Fix crash and miscalculation in css bitmask manipulation.
  + Fix a crash due to too large surfaces.
  + Update on text scale factor changes.
  + Bugs fixed: bgo#743323, bgo#744172, bgo#744683, bgo#744942,
    bgo#744991, bgo#745052.
  + Updated translations.
* Sat Jan 31 2015 zaitor@opensuse.org
- Update to version 3.14.8:
  + Bugs fixed; bgo#613833, bgo#732051, bgo#735316, bgo#740613,
    bgo#741259, bgo#742181, bgo#742636, bgo#742664, bgo#742727,
    bgo#742764, bgo#742771, bgo#742774, bgo#742785, bgo#742786,
    bgo#742980, bgo#743229, bgo#743330, bgo#743422, bgo#743451,
    bgo#743592, bgo#743593.
  + Updated translations.
* Sun Jan 11 2015 zaitor@opensuse.org
- Update to version 3.14.7:
  + GtkFileChooser: Don't crash if invisible files are deleted.
  + Bugs fixed: bgo#477454, bgo#705582, bgo#735122, bgo#739038,
    bgo#739729, bgo#741130, bgo#741652, bgo#741702, bgo#741827,
    bgo#741897, bgo#741969, bgo#742010, bgo#742170, bgo#742311,
    bgo#742343, bgo#742631, bgo#742653, bgo#742664.
  + Updated translations.
- Drop gtk3-Dont-crash-if-invisible-files-are-deleted.patch: Fixed
  upstream.
* Fri Dec 12 2014 zaitor@opensuse.org
- Update to version 3.14.6:
  + Redraw problems with cairo 1.14.
  + Avoid excessive redraws due to CSD shadows.
  + Bugs fixed: bgo#364566, bgo#461249, bgo#721939, bgo#722781,
    bgo#730232, bgo#739453, bgo#739885, bgo#739977, bgo#740287,
    bgo#740374, bgo#740612, bgo#740613, bgo#740642, bgo#740742,
    bgo#740770, bgo#740896, bgo#741249, bgo#741250, bgo#741251,
    bgo#741252, bgo#741254, bgo#741314.
  + Updated translations.
- Add gtk3-Dont-crash-if-invisible-files-are-deleted.patch: Do not
  crash application using gtk file chooser when deleting file via
  an other app (patch from upstream git).
* Fri Dec 12 2014 fcrozat@suse.com
- Disable wayland on SLE12.
* Tue Nov 11 2014 zaitor@opensuse.org
- Update to version 3.14.5:
  + Bugs fixed: bgo#726316, bgo#737561, bgo#737891, bgo#738321,
    bgo#738648, bgo#738650, bgo#738886, bgo#738955, bgo#739005,
    bgo#739111.
  + Updated translations.
- Drop gtk3-fix-screen-changes-csd.patch: Fixed upstream.
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashism in post script
* Mon Nov  3 2014 badshah400@gmail.com
- Add gtk3-fix-screen-changes-csd.patch: fixes a problem with
  screen changes and csd that caused some applications to launch
  with ugly black borders (bgo#739812).
* Tue Oct 21 2014 dimstar@opensuse.org
- Update to version 3.14.4:
  + Bugs fixed: bgo#730893, bgo#737986, bgo#738636, bgo#738873,
    boo#900854.
  + Updated translations.
* Mon Oct 13 2014 zaitor@opensuse.org
- Update to version 3.14.3:
  + Bugs fixed: bgo#724096, bgo#737981, bgo#737983, bgo#737985,
    bgo#738158.
  + Updated translations.
* Wed Oct  8 2014 dimstar@opensuse.org
- Update to version 3.14.2:
  + GtkInspector now shows nested tree models.
  + Bugs fixed: bgo#737670, bgo#737679, bgo#737952, bgo#737929,
    bgo#737777.
  + Updated translations.
* Tue Sep 30 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + Bugs fixed: bgo#635258, bgo#654051, bgo#708206, bgo#719936,
    bgo#729782, bgo#734879, bgo#735054, bgo#735338, bgo#735749,
    bgo#736193, bgo#736338, bgo#736557, bgo#736702, bgo#736830,
    bgo#736971, bgo#737251, bgo#737297, bgo#737363, bgo#737386,
    bgo#737439, bgo#737517.
  + Updated translations.
* Mon Sep 22 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + GtkMisc::xalign has been undeprecated for now, it is still
    needed.
  + GtkIconView:
  - Always draw cell background.
  - Fix handling of prelight items.
  + GtkWindow: Fix growing nautilus windows.
  + Bugs fixed: bgo#736338, bgo#736622, bgo#736927, bgo#737000,
    bgo#737026,  bgo#737027.
  + Updated translations.
* Tue Sep 16 2014 dimstar@opensuse.org
- Update to version 3.13.9:
  + Adwaita:
  - Use sass functions more.
  - Theme .app-notification instead of .app-notification.frame.
  - Lots of button fine-tuning.
  - Avoid double background rendering in tooltips.
  + Inspector:
  - Show widget allocations.
  - Show hidden windows.
  - Fix initial state of dark switch.
  + Bugs fixed: bgo#328449, bgo#528800, bgo#579625, bgo#668258,
    bgo#698031, bgo#732916, bgo#735240, bgo#735953, bgo#735959,
    bgo#735965, bgo#736004, bgo#736056, bgo#736064, bgo#736121,
    bgo#736131, bgo#736155, bgo#736173, bgo#736178, bgo#736191,
    bgo#736201, bgo#736203, bgo#736205, bgo#736250, bgo#736269,
    bgo#736307, bgo#736512, bgo#736535, bgo#736557.
  + Updated translations.
- Rebase gtk3-find-wayland-includedir.patch.
* Mon Sep  8 2014 dimstar@opensuse.org
- Update to version 3.13.8:
  + Wayland:
  - Implement Drag-and-Drop.
  - Use subsurfaces for entry completion popups.
  - Use subsurfaces for tooltips.
  + Bugs fixed: bgo#156164, bgo#346886, bgo#415415, bgo#602443,
    bgo#641638, bgo#658722, bgo#674264, bgo#680067, bgo#695504,
    bgo#697855, bgo#720269, bgo#729215, bgo#731380, bgo#733967,
    bgo#734290, bgo#734374, bgo#734753, bgo#734961, bgo#735012,
    bgo#735014, bgo#735034, bgo#735119, bgo#735223, bgo#735226,
    bgo#735253, bgo#735294, bgo#735300, bgo#735301, bgo#735310,
    bgo#735321, bgo#735337, bgo#735353, bgo#735368, bgo#735389,
    bgo#735401, bgo#735428, bgo#735531, bgo#735545, bgo#735593,
    bgo#735830, bgo#735831.
  + Updated translations.
* Sun Aug 17 2014 dimstar@opensuse.org
- Update to version 3.13.7:
  + To align better with css, button and menuitem subclasses now
    use a :checked state to indicate their checkedness, instead of
    :active or :selected.
  + Deprecations: GtkStatusIcon, GtkThemingEngine.
  + Bugs fixed: bgo#724281, bgo#731013, bgo#731443, bgo#734143,
    bgo#734357, bgo#734420, bgo#734614, bgo#734641, bgo#734649,
    bgo#734651, bgo#734660, bgo#734668, bgo#734709, bgo#734735,
    bgo#734736, bgo#734737, bgo#734778, bgo#570414, bgo#665711,
    bgo#724996, bgo#733832, bgo#733967, bgo#734738, bgo#734826.
  + Updated translations.
* Fri Aug 15 2014 federico@suse.com
- Add gtk3-bnc872820-headerbar-decoration-layout.patch:
  When applications run in Classic mode, and they use GtkHeaderBar
  for a client-side window's decoration, they lacked
  minimize/maximize buttons like those in "traditional" windows
  which are completely decorated by the window manager.  This patch
  adds support for setting those buttons depending on the mode in
  which the desktop is running (bnc#872820).
* Wed Aug 13 2014 hpj@suse.com
- Add gtk3-bnc891647-generate-full-builtin-icon-cache.patch
  (bnc#891647). This fixes the missing builtin icon cache data
  caused by the fix for bgo#721895.
* Mon Aug 11 2014 dimstar@opensuse.org
- Update to version 3.13.6:
  + Theme:
  - Many Adwaita improvements in details.
  - Much faster blur implementation for shadows.
  - Support symbolic, recolorable pngs.
  + GtkFileChooser:
  - Fix editing of bookmarks.
  - Use symbolic icons in the path bar.
  + GtkTextView: Add a vfunc to allow subclasses to draw
    above/below text.
  + GtkImage: Support scale factor when loading from resources.
  + Inspector:
  - Show some widget states and buildable ids.
  - Add GtkTreeSelection to object tree.
  + Wayland: Support newer protocol versions.
  + Windows:
  - Fix handling of input shapes.
  - Support font scaling.
  - Dialog theming fixes.
  - Several crash fixes.
  + Bugs fixed: bgo#624791, bgo#638709, bgo#641638, bgo#705054,
    bgo#715176, bgo#721367, bgo#726224, bgo#729140, bgo#729636,
    bgo#729809, bgo#729924, bgo#730450, bgo#732137, bgo#733312,
    bgo#733406, bgo#733416, bgo#733610, bgo#733671, bgo#733679,
    bgo#733766, bgo#733767, bgo#733768, bgo#733769, bgo#733773,
    bgo#733782, bgo#733923, bgo#733925, bgo#733965, bgo#733979,
    bgo#734033, bgo#734038, bgo#734053, bgo#734129, bgo#734213,
    bgo#734292, bgo#734485, bgo#734526.
  + Updated translations.
* Thu Aug  7 2014 hpj@suse.com
- Add gtk3-icon-theme-reduce-io.patch (bgo#721895). This reduces
  the amount of I/O performed in order to load individual icon
  images.
* Thu Aug  7 2014 hpj@suse.com
- Add gtk3-icon-cache-index-only.patch (bgo#721895). This makes
  it generate an index-only icon cache without image data, in
  line with what the most recent gtk2 does. It can save as
  much as 100MB on disk and a corresponding amount of VM space
  per process.
* Tue Jul 22 2014 dimstar@opensuse.org
- Update to version 3.13.5:
  + Adwaita:
  - Many improvements in details.
  - Style .needs-attention in GtkStackSwitcher.
  + CSS: Selectors can now match state pseudo classes on all
    elements.
  + GtkListBox: Rows now have a selectable property and will be
    styled accordingly.
  + Inspector:
  - Add an easy way to change the font.
  - Show widget state and other misc. info.
  + Wayland:
  - Fix repaint artifacts.
  - Update xdg-shell.
  + Windows: Fix icon theme loading.
  + Bugs fixed: bgo#591258, bgo#618852, bgo#707153, bgo#731582,
    bgo#733099, bgo#733174, bgo#733189, bgo#733321, bgo#733360,
    bgo#733361, bgo#733407, bgo#733431, bgo#733441.
  + Updated translations.
- No longger obsolete gtk3-metatheme-adwaita by libgtk-3-0: the
  package has been re-introduced by gnome-themes-standard.
* Wed Jul 16 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Theming:
  - Adwaita is much more complete.
  - Shadows, reliefs and frames in GtkScrolledWindow,
    GtkViewport, GtkButton, GtkEntry, GtkFrame, etc are now
    translated to style classes and themed.
  + GtkApplication:
  - gtk_application_prefers_app_menu is a new function to
    facility adapting UIs to platform expectations.
  - GtkApplication now tries to load menus from resources in the
    resource path that is defined by GApplication.
  - GtkApplication set up a resource path for loading icons as
    well.
  + GtkScrolledWindow:
  - Scrolling in response to user input (scrollbar clicks,
    keynav) is now animated.
  - The displacement animation has been replaced edge gradients.
  + GtkScaleButton:
  - The orientation is now changed on the fly to make the popup
    fit into small windows.
  + GtkEntry: Activity mode progress is now smooth.
  + Client-side decorations:
  - The default button layout includes minimize and maximize
    again.
  - Dialogs are no longer using client-side decorations when
    use-header-bar is unset.
  + GTK+ now ships a simple icon theme browser, gtk3-icon-browser.
  + GtkInspector:
  - Can change hi-dpi scale on the fly.
  - Can simulate touchscreen at runtime.
  - Shows style properties.
  - Ctrl-Shift-I selects the widget under the pointer.
  - Property editors show property and settings bindings.
  + Wayland:
  - Always use CSD under Wayland.
  - Avoid a crash on pointer-less systems.
  - Context menus work now.
  + Deprecations, removals:
  - GtkWindow no longer supports resize grips.
  - builtin icons have been deprecated in favor of loading icons
    from resources.
  + Bugs fixed: bgo#484640, bgo#618852, bgo#629129, bgo#672676,
    bgo#680885, bgo#710449, bgo#722092, bgo#722633, bgo#724084,
    bgo#726566, bgo#729620, bgo#730730, bgo#730893, bgo#731158,
    bgo#731297, bgo#731463, bgo#731711, bgo#732134, bgo#732206,
    bgo#732229, bgo#732256, bgo#732298, bgo#732330, bgo#732433,
    bgo#732441, bgo#732443, bgo#732454, bgo#732494, bgo#732667,
    bgo#732681, bgo#732861, bgo#732894, bgo#732900, bgo#732933,
    bgo#732970, bgo#732991, bgo#733027, bgo#733076, bgo#733092,
    bgo#733099, bgo#733112.
  + Updated translations.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + GtkInspector:
  - Support saving custom CSS.
  - Show GMenus and GActions.
  - Show combobox menus and submenus.
  - Lower the inspector window when picking.
  - Misc. navigation improvements.
  + Gestures: Convert most widgets to use gestures internally.
  + Theming:
  - Use client-side shadows for menus and tooltips.
  - Include the Adwaita theme.
  - The default theme is now Adwaita.
  - Icon loading now respects limits specified in the icon theme,
    unless GTK_ICON_LOOKUP_FORCE_SIZE is set.
  - Don't include image content in icon caches, to avoid huge
    caches.
  - GtkSwitch gained a hover state.
  + Widget factory: Improve coverage of GTK+ features.
  + Wayland: Support GNOME classic mode.
  + Deprecations:
  - Style regions.
  - Support for .icon files.
  - gdk_window_flush, drawing outside of begin/end paint.
  + Bugs fixed: bgo#721895, bgo#729820, bgo#730615, bgo#730745,
    bgo#730767, bgo#730833, bgo#730924, bgo#731016, bgo#731020,
    bgo#731187, bgo#731273, bgo#731299, bgo#731371, bgo#731377,
    bgo#731382, bgo#731429, bgo#731602, bgo#731658, bgo#731790,
    bgo#731834, bgo#731866, bgo#731908.
- Changes from version 3.13.2:
  + Interactive debugging support.
  + Gesture support has landed.
  + GTK+ widgets can now draw outside their allocation, by setting
    a clip with gtk_widget_set_clip().
  + GtkStack has added a few more transition types.
  + GtkProgressBar is now narrower.
  + CSS:
  - Support outline-radius in CSS.
  - Implement 'unset' and 'all'.
  - Support -gtk-icontheme.
  - Support -gtk-icon-source.
  - Add -gtk-icon-transform, supporting the 2D parts of CSS
    transforms.
  - Support -gtk-icon-style.
  + Theme:
  - Use outlines to render focus rings.
  - Use icons to render spinners, expanders and arrows.
  - GtkIconTheme can force symbolic or regular icon variants.
  - GtkIconTheme will automatically load rtl icon variants.
  + Win32: Theme improvements.
  + Wayland: Update to the latest xdg-shell protocol.
  + Bugs fixed: bgo#119906, bgo#525206, bgo#614717, bgo#636695,
    bgo#641836, bgo#645966, bgo#698396, bgo#700030, bgo#708037,
    bgo#720330, bgo#721069, bgo#726676, bgo#727147, bgo#727994,
    bgo#728135, bgo#728284, bgo#729346, bgo#729353, bgo#729451,
    bgo#729461, bgo#729473, bgo#729475, bgo#729496, bgo#729564,
    bgo#729594, bgo#729598, bgo#729607, bgo#729670, bgo#729817,
    bgo#729834, bgo#729915, bgo#729983, bgo#730007, bgo#730008,
    bgo#730035, bgo#730043, bgo#730095, bgo#730142, bgo#730183,
    bgo#730306, bgo#730353, bgo#730526.
- Changes from version 3.13.1:
  + GtkListBox can now do multi-selection.
  + GtkSwitch has a way to delay state changes.
  + GtkMenuButton is using a popover for menu models by default.
  + GtkPopover can have horizontal sections.
  + GtkFileChooser received some design improvements.
  + GtkBuilder:
  - Supports property binding.
  - Supports dialog actions.
  + Client-side decorations:
  - The requirement for _GTK_FRAME_EXTENTS has been dropped to
    avoid 'double headers' with most window managers.
  - Drawing of DND highlights around the entire window works.
  + Windows backend:
  - *Many* theme improvements.
  - Add popover theming.
  - Enable introspection.
  + Wayland backend:
  - Updates for xdg_shell protocol changes.
  - Touch support.
  + Broadway backend: Now builds on OpenBSD.
  + Bugs fixed: bgo#495105, bgo#654417, bgo#686170, bgo#712752,
    bgo#722058, bgo#722211, bgo#722817, bgo#723963, bgo#725648,
    bgo#726179, bgo#726271, bgo#726298, bgo#726475, bgo#726592,
    bgo#726859, bgo#726870, bgo#726871, bgo#726996, bgo#727009,
    bgo#727022, bgo#727035, bgo#727036, bgo#727037, bgo#727075,
    bgo#727078, bgo#727080, bgo#727210, bgo#727211, bgo#727213,
    bgo#727244, bgo#727245, bgo#727313, bgo#727322, bgo#727391,
    bgo#727410, bgo#727414, bgo#727487, bgo#727643, bgo#727644,
    bgo#727662, bgo#727908, bgo#727973, bgo#728023, bgo#728054,
    bgo#728073, bgo#728140, bgo#728165, bgo#728183, bgo#728272,
    bgo#728426, bgo#728745, bgo#728806, bgo#728807, bgo#728808,
    bgo#728810, bgo#728846, bgo#728992, bgo#729013, bgo#729095,
    bgo#729097.
  + Updated translations.
- Add adwaita-icon-theme requires to libgtk-3-0: Upstream promises
  that any icon from the adwaita themeset is available to any
  GTK application.
- Obsolete gtk3-metatheme-adwaita by libgtk-3-0: anything that is
  not part of the icon-theme is embedded as gresource into the
  library.
- Extend gtk3-find-wayland-includedir.patch also over
  gtk/inspector.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Bugs fixed: bgo#495105, bgo#686170, bgo#726592, bgo#727487,
    bgo#728093, bgo#728140, bgo#728183, bgo#728272, bgo#728284,
    bgo#728526, bgo#728745, bgo#728806, bgo#728807, bgo#728808,
    bgo#728810, bgo#728992, bgo#729346, bgo#729451, bgo#729670.
  + Updated translations.
* Sun Apr 13 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Bugs fixed: bgo#712752, bgo#722058, bgo#722817, bgo#726298,
    bgo#726475, bgo#726859, bgo#726870, bgo#726871, bgo#726996,
    bgo#727009, bgo#727022, bgo#727035, bgo#727036, bgo#727037,
    bgo#727075, bgo#727078, bgo#727080, bgo#727210, bgo#727211,
    bgo#727213, bgo#727244, bgo#727245, bgo#727313, bgo#727322,
    bgo#727391, bgo#727410, bgo#727414, bgo#727643, bgo#727662,
    bgo#727973, bgo#728023, bgo#727644.
  + Updated translations.
* Tue Mar 25 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + Wayland:
  - Add support for input regions.
  - Correctly report display capabilities.
  - Fix resizing from the north-east corner.
  + Bugs fixed: bgo#723045, bgo#724728, bgo#726369, bgo#726476,
    bgo#726717, bgo#726749, bgo#726825, bgo#726838, bgo#726855,
    bgo#726858, bgo#726900.
  + Updated translations.
* Wed Mar 19 2014 mgorse@suse.com
- Add gtk3-gtkwindow-cleanup.patch -- remove delete-event idle
  function on finalize (bgo#723771).
* Tue Mar 18 2014 dimstar@opensuse.org
- Update to version 3.11.9:
  + GtkPopover:
  - Improve focus and grab handling.
  - Add accessibility support.
  + Client-side decorations:
  - Make F10 move focus to the header bar.
  - Make header bars draggable on touch systems.
  - Make shadows unclickable.
  + Bugs fixed: bgo#591258, bgo#693200, bgo#701884, bgo#709914,
    bgo#723668, bgo#724785, bgo#725141, bgo#725727, bgo#725733,
    bgo#725754, bgo#725824, bgo#725864, bgo#725866, bgo#726125,
    bgo#726135, bgo#726136, bgo#726149, bgo#726187, bgo#726209,
    bgo#726492.
  + Updated translations.
* Mon Mar 10 2014 dimstar@opensuse.org
- Update to version 3.11.8:
  + Printing: Google cloud print support.
  + Documentation: Update screenshots.
  + Bugs fixed: bgo#724742, bgo#724895, bgo#481073, bgo#547988,
    bgo#554618, bgo#723368, bgo#723438, bgo#724411, bgo#724799,
    bgo#724891, bgo#724921, bgo#724968, bgo#724999, bgo#725089,
    bgo#725172, bgo#725205, bgo#725225, bgo#725345, bgo#725559,
    bgo#725560.
  + Updated translations.
* Mon Mar 10 2014 zaitor@opensuse.org
- Update to version 3.11.7:
  + GtkActionBar: Fix theming.
  + GtkBox:
  - Allow setting center widget to NULL.
  - Fix a size-allocation error.
  + GtkPopover:
  - Fix a crash with text handles (bgo#724392).
  - Allow resetting relative-to (bgo#724407).
  + Wayland:
  - Use new xdg-shell ping.
  - Use new xdg-shell focus methods.
  + Printing: Fix a small memory leak (bgo#724631).
* Mon Mar 10 2014 zaitor@opensuse.org
- Update to version 3.11.6:
  + GtkActionBar is a new widget that is meant to be used for
    actions at the bottom of a window.
  + GtkPopover:
  - A ::closed signal has been added.
  - Style propagation to popovers has been fixed.
  - Popovers can now be populated from a menu model.
  - GtkMenuButton can use popovers instead of menus.
  + GtkAppChooserDialog has been redesigned.
  + GtkBox can now place a widget centered, regardless of the sizes
    of children on either side, similar to GtkHeaderBar.
  + The API documentation has been converted to markdown, and many
    cleanups and improvements have been made at the same time.
  + Bugs fixed: bgo#706515, bgo#707999, bgo#721309, bgo#723014,
    bgo#723394, bug#723627, bgo#723637, bgo#723672, bgo#723716,
    bgo#723771, bgo#723863, bgo#723929, bgo#724008, bgo#724094,
    bgo#724218, bgo#724411, bgo#724503, bgo#724539, bgo#724541.
  + Updated translations.
* Mon Mar 10 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + GtkPopover: A new widget that is can be used for transient
    views, as an alternative to menus or dialogs.
  + Dialogs:
  - Dialogs have been modernized, can use a header bar now.
  - Built-in dialogs react to a setting, gtk-dialogs-use-header
    for this, dialogs derived from GtkDialog: default to no
    headerbar.
  - GtkAssistant also respects the setting.
  + Theming:
  - GTK+ now uses RGBA visuals by default.
  - Notebook tabs now support a prelight state.
  - Reorderable notebook tabs can be themed differently.
  + Documentation:
  - The API documentation has seen numerous fixes and
    improvements.
  - Docbook markup is being phased out in favor of markdown.
  + OS X Fixes.
  + Bugs fixed: bgo#350190, bgo#566945, bgo#630217, bgo#634793,
    bgo#636594, bgo#665928, bgo#692931, bgo#699224, bgo#704456,
    bgo#711298, bgo#720059, bgo#720552, bgo#721895, bgo#722429,
    bgo#722515, bgo#722574, bgo#722588, bgo#722638, bgo#722642,
    bgo#722722, bgo#722919, bgo#723119, bgo#723121, bgo#723157,
    bgo#723159, bgo#723181, bgo#723183, bgo#723212, bgo#723366,
    bgo#723390, bgo#723402, bgo#723555.
  + Updated translations.
* Mon Mar 10 2014 dimstar@opensuse.org
- Update to version 3.11.4:
  + GtkActionBar: A new container, which has a centered child like
    GtkHeaderBar. It can be used in places where header bar theming
    is not suitable.
  + GtkAppChooser: The online support has been simplified and
    modernized.
  + GtkHeaderBar button theming has been changed to be more
    flexible. There is now a gtk-decoraton-layout setting and a
    decoration-layout property.
  + Accessibility:
  - Links in labels are now accessible.
  - Model-based menus are accessible.
  - Accessible roles of several widgets have been fixed.
  - GtkColorChooser accessibility is improved.
  + Theming: The Raleigh theme has been updated for several new
    features, including client-side decorations.
  + Model-based menus now support a hidden-when attribute on items
    that allows them to be hidden on various conditions.
  + Bugs fixed: bgo#688421, bgo#698248, bgo#698786, bgo#706119,
    bgo#707729, bgo#709491, bgo#710315, bgo#710351, bgo#711552,
    bgo#711826, bgo#720264, bgo#720357, bgo#720401, bgo#720535,
    bgo#720551, bgo#720554, bgo#720939, bgo#720945, bgo#720983,
    bgo#721045, bgo#721048, bgo#721086, bgo#721119, bgo#721304,
    bgo#721317, bgo#721346, bgo#721406, bgo#721407, bgo#721410,
    bgo#721421, bgo#721480, bgo#721530, bgo#721633, bgo#721665,
    bgo#721700, bgo#721800, bgo#721836, bgo#722029, bgo#722030,
    bgo#722070, bgo#722076, bgo#722106.
  + Updated translations.
* Mon Mar 10 2014 dimstar@opensuse.org
- Update to version 3.11.2:
  + Theming:
  - A number of containers have been changed to draw backgrounds
    and borders. By default these are fully transparent, so
    nothing should change: GtkBox GtkFixed GtkGrid GtkEventBox.
  - Link colors are not rendered using the :visited and :link
    states instead of the link-color and visited-link-color
    style properties.
  + Broadway:
  - Use client-side decorations.
  - Implement window movement, raise/lower.
  - Use rolling hashes for optimizing scrolling.
  - Use click-to-focus.
  - Support touch events.
  - Support IPad on-screen keyboard.
  + GtkFileChooser:
  - Respect local-only in the places sidebar.
  - Filter out duplicate application shortcuts.
  - Show unmounted bookmarks.
  + GtkProgressBar:
  - Activity mode is now using a tick callback to move the block
    smoothly.
  + GtkWindow:
  - Fix size allocation for the fallback menubar.
  - Improve application menu fallback if we have client-side
    decorations or a header bar.
  + GtkBuilder:
  - No longer requires every object to have an id.
  + Bugs fixed: bgo#577642, bgo#635499, bgo#668598, bgo#679019,
    bgo#693227, bgo#699574, bgo#700419, bgo#702392, bgo#703784,
    bgo#705176, bgo#709629, bgo#710238, bgo#710533, bgo#710909,
    bgo#710987, bgo#711110, bgo#711158, bgo#711255, bgo#711324,
    bgo#711354, bgo#711494, bgo#711545, bgo#711548, bgo#711553,
    bgo#711574, bgo#711611, bgo#711636, bgo#712164, bgo#712302.
  + Updated translations.
- Add hicolor-icon-theme BuildRequires: needed in order to have
  %%icon_theme_cache_post available and for directory ownership.
- Split out new subpackage immodule-broadway.
* Mon Mar 10 2014 dimstar@opensuse.org
- Update to version 3.11.0:
  + New notebook tab styling: GtkNotebook now offers a way for
    themes to opt out of the tab rendering, with the 'has-tab-gap'
    style property. The Adwaita theme is using this to achieve a
    more modern tab appearance.
  + GtkFlowBox: A container that its children in a reflowing grid,
    which can be oriented horizontally or vertically.
  + GtkStack: children can now indicate that they require attention
    by setting the needs-attention child property.
  + Broadway now requires binary array buffers and modern WebSocket
    protocol support.
  + Autoscrolling in range widgets has been improved to work more
    reliably in maximized windows.
  + GtkSpinner has been changed to render in in a limited set of
    sizes.
  + GtkApplication now stores and handles accelerators for GActions
    itself.
  + GtkIconTheme now falls back to the gnome icontheme to fix
    problems with the availability of symbolic icons in other icon
    themes.
  + GTK+ respects the deprecated gtk-button-images and
    gtk-menu-images settings again.
  + Bugs fixed: bgo#168530, bgo#341146, bgo#467720, bgo#586107,
    bgo#643914, bgo#651224, bgo#681484, bgo#691163, bgo#693586,
    bgo#697031, bgo#702196, bgo#703062, bgo#703603, bgo#707132,
    bgo#707187, bgo#707524, bgo#707920, bgo#708019, bgo#708024,
    bgo#708414, bgo#708423, bgo#708547, bgo#708583, bgo#708584,
    bgo#708787, bgo#709049, bgo#709212, bgo#709215, bgo#709264,
    bgo#709323, bgo#709420, bgo#709522, bgo#709613, bgo#709687,
    bgo#709854, bgo#710134.
  + Updated translations.
- No longer delete gtk-shell-client-protocol.h and
  gtk-shell-protocol.c: they are no longer part of the tarball.
* Sun Mar  9 2014 mgorse@suse.com
- Update to version 3.10.9:
  + Bugs fixed: bgo#495105, bgo#709914, bgo#721119, bgo#727487,
    bgo#728992, bgo#729670, bgo#566945, bgo#591258, bgo#692931,
    bgo#693200, bgo#701884, bgo#704456, bgo#712752, bgo#722058,
    bgo#722722, bgo#723121, bgo#723159, bgo#723183, bgo#723366,
    bgo#723390, bgo#723555, bgo#723621, bgo#723771, bgo#724008,
    bgo#724541, bgo#724631, bgo#724891, bgo#724895, bgo#725089,
    bgo#725172, bgo#725205, bgo#725225, bgo#725754, bgo#725824,
    bgo#725866, bgo#726136, bgo#726476, bgo#726717, bgo#726858,
    bgo#726859, bgo#726871, bgo#726996, bgo#727643
  + Translation updates: Catalan, Kannada, Russian, Scottish Gaelic
- Drop gtk3-gtkwindow-cleanup.patch: fixed upstream.
* Sat Mar  8 2014 zaitor@opensuse.org
- Update to version 3.10.7:
  + Bugs fixed: bgo#386569, bgo#709491, bgo#711298, bgo#719314,
    bgo#719970, bgo#719977, bgo#721700.
  + Updated translations.
- No longer delete gtk-shell-client-protocol.h and
  gtk-shell-protocol.c: they are no longer part of the tarball.
* Sat Dec  7 2013 dimstar@opensuse.org
- Update to version 3.10.6:
  + Bugs fixed: bgo#709027, bgo#711715, bgo#719469, bgo#719505,
    bgo#719510, bgo#719516, bgo#719568, bgo#719569, bgo#719595,
    bgo#719762.
- Changes from version 3.10.5:
  + Bugs fixed: bgo#691974, bgo#694859, bgo#699574, bgo#702663,
    bgo#705203, bgo#709716, bgo#712302, bgo#712632, bgo#712760,
    bgo#712799, bgo#715029.
  + Updated translations.
- Delete gtk-shell-client-protocol.h and gtk-shell-protocol.c
  before building: those are generated files, based on wayland
  versions.
* Sun Nov 17 2013 dimstar@opensuse.org
- Update to version 3.10.4 (bnc#849913):
  + Bugs fixed: bgo#705176, bgo#710909, bgo#711545, bgo#711548,
    bgo#711574, bgo#711636, bgo#712164, bgo#712213, bgo#712302.
  + Updated translations.
- Changes from version 3.10.3:
  + Theme support
  - Always fall back to 'gnome' icon theme in addition to
    'hicolor'.
  - Respect deprecated gtk-button-images setting.
  - Respect deprecated gtk-menu-images setting.
  + Bugs fixed: bgo#577642, bgo#693227, bgo#703784, bgo#710389,
    bgo#710411, bgo#710666, bgo#710958, bgo#711110, bgo#711255,
    bgo#711553, bgo#711611.
  + Updated translations.
- Rebase gtk3-find-wayland-includedir.patch.
- Enable building of wayland support: set build_wayland_backend 1.
* Wed Oct 16 2013 dimstar@opensuse.org
- Update to version 3.10.2:
  + Bugs fixed: bgo#168530, bgo#698730, bgo#708163, bgo#708346,
    bgo#709621, bgo#709697, bgo#709854, bgo#709939, bgo#709967,
    bgo#710073, bgo#710096, bgo#710141.
  + Updated translations.
- Drop gtk3-enable-mnemonics.patch: fixed upstream.
* Mon Oct 14 2013 dimstar@opensuse.org
- Add gtk3-enable-mnemonics.patch: Revert missing parts to allow
  apps to override disabling mnemonics (like gnome-terminal does)
  (bgo#709764, bgo#708346, bnc#844929).
* Fri Oct 11 2013 dimstar@opensuse.org
- Update to version 3.10.1 (bnc#845548):
  + Bugs fixed: bgo#341146, bgo#586107, bgo#681484, bgo#684076,
    bgo#702196, bgo#703062, bgo#707524, bgo#708019, bgo#708024,
    bgo#708414, bgo#708423, bgo#708547, bgo#709049, bgo#709056,
    bgo#709212, bgo#709264, bgo#709522, bgo#709613, bgo#709745.
  + Updated translations.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Accessibility improvements:
  - Add accessible names to csd window buttons.
  - Mark GtkLinkButton as visited when appropriate.
  - Add a GtkListBoxRow accessible.
  + Bugs fixed: bgo#692258, bgo#702681, bgo#704087, bgo#708320,
    bgo#708384.
  + Updated translations.
* Tue Sep 17 2013 dimstar@opensuse.org
- Update to version 3.9.16:
  + Bugs fixed: bgo#339539, bgo#513812, bgo#696756, bgo#702034,
    bgo#702423, bgo#706269, bgo#706345, bgo#706708, bgo#707129,
    bgo#707244, bgo#707328, bgo#707445, bgo#707488, bgo#707519,
    bgo#707659, bgo#707704, bgo#707778, bgo#707786, bgo#707844,
    bgo#707872, bgo#707915, bgo#707926, bgo#707981, bgo#708012,
    bgo#708067, bgo#708076, bgo#708128, bgo#708150.
  + Updated translations.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 3.9.14:
  + GtkLabel can now ellipsize just the last line, ellipsized in
    multi-line labels.
  + Bugs fixed: bgo#680953, bgo#700428, bgo#701125, bgo#704278,
    bgo#705980, bgo#706323, bgo#706448, bgo#706451, bgo#706493,
    bgo#706529, bgo#706563, bgo#706592, bgo#706722, bgo#706728,
    bgo#706740, bgo#706756, bgo#706778, bgo#706802, bgo#706870,
    bgo#706922, bgo#706929, bgo#706938, bgo#707051, bgo#707201.
  + Updated translations.
- Drop gtk3-password-hint-timeout.patch: fixed upstream.
- Drop gtk3-build-without-wayland.patch: fixed upstream.
* Thu Aug 22 2013 dimstar@opensuse.org
- Add gtk3-password-hint-timeout.patch: Revert the removal of
  password-hint-timeout: We do go with upstreams defined 600ms to
  show the last character of the password (stay close), but we do
  want to keep the configure option. Users that are really worried
  about this can change the settings in .gtkrc.
- Add the default configure value as comment in settings.ini, to
  make it easier discoverable.
* Wed Aug 21 2013 dimstar@opensuse.org
- Update to version 3.9.12:
  + GtkInfoBar now uses a GtkRevealer internally to slide in place.
  + GtkHeaderBar can now add a window close button.
  + The fine adjustment mode for scrolling has been revamped to be
    easier discoverable, and visual feedback and autoscrolling has
    been added.
  + GtkIconTheme now supports 2x scaled icons for hi-dpi displays.
  + The Wayland and X11 clipboard implementations can now coexist.
  + Bugs fixed: bgo#448637, bgo#672220, bgo#674108, bgo#680926,
    bgo#688738, bgo#692548, bgo#694831, bgo#697127, bgo#697399,
    bgo#700029, bgo#701571, bgo#702144, bgo#702971, bgo#704173,
    bgo#704334, bgo#704703, bgo#705068, bgo#705181, bgo#705182,
    bgo#705215, bgo#705320, bgo#705372, bgo#705443, bgo#705498,
    bgo#705524, bgo#705529, bgo#705558, bgo#705601, bgo#705605,
    bgo#705624, bgo#705640, bgo#705672, bgo#705692, bgo#705750,
    bgo#705765, bgo#705809, bgo#705918, bgo#706014, bgo#706045,
    bgo#706152, bgo#706220, bgo#706028, bgo#706335.
  + Updated translations.
- Add gtk3-build-without-wayland.patch: Fix build without wayland.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 3.9.10:
  + GtkInfoBar updates:
  - Turn action area horizontal.
  - Fix spacing.
  - Add an easy way to add a close button.
  + Updated documentations.
  + Deprecations: tear-off menuitems.
  + Bugs fixed: bgo#684558, bgo#694086. bgo#698758, bgo#700229,
    bgo#700896, bgo#700898, bgo#701332, bgo#701365, bgo#701613,
    bgo#702563, bgo#704104, bgo#704164, bgo#704171, bgo#704216,
    bgo#704274, bgo#704392, bgo#704554, bgo#704700, bgo#704747,
    bgo#704894, bgo#704937, bgo#705060.
  + Updated translations.
- Remove language handling targetted at openSUSE <= 11.3.
* Wed Jul 10 2013 dimstar@opensuse.org
- Update to version 3.9.8:
  + Started deprecating GtkStock apis.
  + The GtkSettings cleanup that was discussed at the recent GTK+
    hackfest has started to land.
  + Initial support for scaled output (on high-dpi screens) has
    been added.
  + Bugs fixed: bgo#390048, bgo#672271, bgo#696498, bgo#701119,
    bgo#702332, bgo#702831, bgo#702913, bgo#702977, bgo#702981,
    bgo#702996, bgo#703069, bgo#703154, bgo#703220, bgo#703313,
    bgo#703406, bgo#703533, bgo#703606, bgo#703616, bgo#703618,
    bgo#703656, bgo#703765, bgo#703827.
  + Updated translations.
* Sun Jun 23 2013 zaitor@opensuse.org
- Update to version 3.9.6:
  + GtkListBox:
  - Handle double-clicks properly.
  - Add an example in gtk3-demo.
  + Bugs fixed: bgo#390048, bgo#560337, bgo#649390, bgo#679930,
    bgo#698183, bgo#701174, bgo#702598, bgo#702695, bgo#702763.
  + Updated translations.
* Fri Jun 21 2013 dimstar@opensuse.org
- Update to version 3.9.4:
  + GtkSearchBar: a toolbar that will popup automatically when
    searches should be started, and dismissed when they are
    finished.
  + GtkListBox a vertical container that can sort and filter its
    children.
  + GtkStack has gained position dependent transitions (left-right
    and up-down).
  + The Broadway GDK backend can be built on Windows now.
  + Bugs fixed: bgo#593079, bgo#692638, bgo#699673, bgo#700185,
    bgo#700444, bgo#700779, bgo#701463, bgo#701840, bgo#702370.
  + Updated translations.
* Wed May 29 2013 dimstar@opensuse.org
- Update to version 3.9.2:
  + The GDK initialization code has been refactored.
    GdkDisplayManager is no longer backend-specific.
  + The symbol exporting functionality has been refactored. We no
    longer use .symbols files, and instead rely on explicit header
    annotations for every exported symbol. the abicheck scripts are
    no longer used.
  + The GDK drawing and scrolling has been simplified. We no longer
    use XCopyArea for scrolling, instead an offscreen cache is
    used. There is a new debug flag, GTK_DEBUG=pixel-cache for
    this.
  + Window sizing issues have been addressed.
  + Implement height-for-width for GtkEventBox and GtkCheckButton.
  + Custom titlebars can now be set from GtkBuilder files.
  + Optionally install tests, when configured with
  - -enable-installed-tests. To run these tests,
    gnome-desktop-testing-runner can be used.
  + Native input methods are supported on OS X now.
  + Bugs fixed: bgo#360131, bgo#561221, bgo#591969, bgo#628902,
    bgo#667759, bgo#691921, bgo#694273, bgo#695120, bgo#696001,
    bgo#696640, bgo#698051, bgo#698361, bgo#698933, bgo#699104,
    bgo#699140, bgo#699239, bgo#699289, bgo#699633, bgo#699690,
    bgo#699739, bgo#699750, bgo#699901, bgo#699929, bgo#699970,
    bgo#700007, bgo#700053, bgo#700054, bgo#700056, bgo#700079,
    bgo#700233, bgo#700301, bgo#700465, bgo#700575, bgo#700578,
    bgo#700737, bgo#700787, bgo#700844, bgo#700864, bgo#700979.
* Mon May  6 2013 dimstar@opensuse.org
- Update to version 3.9.0:
  + GtkFileChooser:
  - Always show fuse-mounted locations in shortcuts.
  - GtkFileChooserButton has received a lot of fixes and tests
    have been added for many of them.
  + GtkWindow:
  - Initial support for client-side decorations has been added.
  - gtk_window_set_titlebar: A new function that can set a
    custom, client-side titlebar on toplevel windows.
  + Wayland:
  - Use client-side decorations.
  - Implement maximization.
  - Improve cursor handling.
  - Improve multi-monitor handling.
  - Support most GtkSettings (for now by reading GSettings
    directly).
  - Complete the keymap implementation.
  + Broadway:
  - Improve window size handling.
  - Implement frame synchronization.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Broadway backend improvements:
  - Ensure window sizes are synched right.
  - Sync surface updates with paint clock.
  - Add support for password authentication.
  - Reuse surfaces passed to server.
  + CSS improvements:
  - Add cycle detection to color resolving
  + Bugs fixed: bgo#675649, bgo#681446, bgo#685419, bgo#685420,
    bgo#690275, bgo#696370, bgo#696622, bgo#696623, bgo#696882,
    bgo#697144, bgo#697263, bgo#697427.
  + Updated translations.
* Fri Mar 29 2013 zaitor@opensuse.org
- Disable building of wayland backend, and conditionally apply
  gtk3-find-wayland-includedir.patch as it's only needed when
  building wayland backend.
* Tue Mar 26 2013 zaitor@opensuse.org
- Update to version 3.8.0:
  + Bugs fixed: bgo#674759, bgo#695493, bgo#696051, bgo#696171,
    bgo#696202, bgo#696232, bgo#696405, bgo#696546, bgo#696553.
  + Updated translations.
* Sun Mar 24 2013 zaitor@opensuse.org
- Add build_wayland_backend define and set it to 1. Build the
  wayland backend.
- Conditionally, based on %%{build_wayland_backend},
  + Pass --enable-wayland-backend to configure.
  + BuildRequire pkgconfig(wayland-client, wayland-cursor and
    xkbcommon).
- Add gtk3-find-wayland-includedir.patch, build does not find our
  wayland headerfiles since they are in a non standard includedir
  (bgo#696507).
* Thu Mar 21 2013 sbrabec@suse.cz
- Check completeness of translations sets introduced by
  translation-update-upstream (bnc#690180).
* Tue Mar 19 2013 sbrabec@suse.cz
- Add support for translation-update-upstream.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 3.7.14:
  + A lot of filechooser button fixes.
  + Bugs fixed: bgo#586367, bgo#671939, bgo#674759, bgo#691040,
    bgo#694339, bgo#695200, bgo#695278, bgo#695304, bgo#695312,
    bgo#695375, bgo#695391, bgo#695473, bgo#695482, bgo#695682,
    bgo#695714, bgo#695715, bgo#695772, bgo#695783, bgo#695874,
    bgo#695948.
  + Updated translations.
- Remove enable_avahi_browsing: upstream removed the avahi browsing
  capability again:
  + No longer pass --enable-avahi-browsing to configure.
  + Drop cups-devel >= 1.6 BuildRequires.
* Wed Mar  6 2013 dimstar@opensuse.org
- Update to version 3.7.12:
  + We now support touch friendly popups on entries and text views
    in place of context menus, on touch devices.
  + The print dialog now shows printers that are discovered using
    avahi, if configured with --enable-avahi-browsing.
  + Bugs fixed: bgo#650424, bgo#674207, bgo#675333, bgo#688956,
    bgo#691426, bgo#692955, bgo#693995, bgo#694059, bgo#694162,
    bgo#694217, bgo#694274, bgo#694302, bgo#694395, bgo#694406,
    bgo#694451, bgo#694732, bgo#694742, bgo#694924, bgo#694925,
    bgo#694968, bgo#694990, bgo#695131.
  + Updated translations.
- Conditionally, based on %%{enable_avahi_browsing},
  + pass --enable-avahi-browsing to configure for the new avahi
    based printer autodetection.
  + BuildRequire cups-devel >= 1.6
- Define enable_avahi_browsing to 0, as cups 1.6 is not available
  in Factory yet.
* Tue Feb 19 2013 dimstar@opensuse.org
- Update to version 3.7.10:
  + We now support the Window Manager frame synchronization
    protocol draft.
  + We now support setting an opacity to any GtkWidget.
  + GtkIconTheme gained asynchronous loaders for GtkIconInfo
    objects.
  + GtkIconInfo has changed from being a boxed type to a GObject.
  + Bugs fixed: bgo#590325, bgo#673243, bgo#681578, bgo#683311,
    bgo#685460, bgo#687842, bgo#690247, bgo#692411, bgo#692728,
    bgo#693251, bgo#693253, bgo#693256, bgo#693257, bgo#693313,
    bgo#693338, bgo#693400, bgo#693709, bgo#693724, bgo#693802,
    bgo#693912, bgo#693913, bgo#693934, bgo#694022, bgo#694075.
  + Updated translations.
- Add gnome-common BuildRequires and call to autogen.sh:
  gtk3-path-local.patch actually touches the build system (and with
  automake 1.13, an automatic bootstrap would be triggered).
* Mon Feb  4 2013 dimstar@opensuse.org
- Update to version 3.7.8:
  + GtkTreeView and GtkIconView allow single-click activation.
  + GtkImage can be set from a resource.
  + GdkWaylandDisplay is now public.
  + gdk_window_set_fullscreen_mode: new function to let windows
    be fullscreened across multiple monitors.
  + Bugs fixed: bgo#345023, bgo#687025, bgo#691572, bgo#691592,
    bgo#691639, bgo#691751, bgo#691842, bgo#691856, bgo#692163,
    bgo#692188, bgo#692203, bgo#692467, bgo#692481, bgo#692605,
    bgo#692659, bgo#692766, bgo#692844, bgo#692934, bgo#682824,
    bgo#692637, bgo#692823, bgo#692899, bgo#693015, bgo#693066,
    bgo#525226, bgo#553334, bgo#658148, bgo#680048, bgo#687825,
    bgo#693050.
  + Updated translations.
* Tue Jan 15 2013 dimstar@opensuse.org
- Update to version 3.7.6:
  + We now use state flags for text direction:
    GTK_STATE_FLAG_LTR/RTL. gtk_style_context_set_direction() has
    been deprecated.
  + We install headers for accessible implementations of GTK+
    widgets.
  + Invisible widgets now return a size of 0x0.
  + GtkFrame now draws a background.
  + The Broadway backend now installs a separate server: broadwayd.
  + Bugs fixed: bgo#687025, bgo#687633, bgo#688140, bgo#688362,
    bgo#689810, bgo#690305, bgo#691186, bgo#691301, bgo#691515,
    bgo#691677.
  + Updated translations.
* Tue Jan  8 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + GtkBuilder now lets you refer to external objects from a ui
    file if the objects have been exported with the new function
    gtk_builder_expose_object().
  + Font handling has been improved.
  + GTK+ now uses proper Unicode ellipses in strings.
  + The releases includes several noticable performance
    improvements.
  + Various deprecations.
  + Bugs fixed: bgo#132333, bgo#371034, bgo#447972, bgo#548793,
    bgo#595615, bgo#626499, bgo#668239, bgo#677339, bgo#680065,
    bgo#687065, bgo#687816, bgo#688710, bgo#688744, bgo#688884,
    bgo#689012, bgo#689047, bgo#689081, bgo#689168, bgo#689401,
    bgo#689584, bgo#689847, bgo#689923, bgo#690099, bgo#690266.
  + Updated translations.
* Tue Jan  8 2013 dimstar@opensuse.org
- Update to version 3.7.2:
  + Accessibility: Make entry icons accessible.
  + Filechooser:
  - Don't add duplicate bookmarks.
  - Remember sidebar width.
  + Geometry management:
  - Size groups now handle height-for-width.
  - Fix corner cases in label size allocation.
  + Theming:
  - Improve touch text handle theming.
  - Always draw background of menuitems.
  + Bugs fixed: bgo#524295, bgo#577806, bgo#677609, bgo#683896,
    bgo#686021, bgo#686347, bgo#687059, bgo#687196, bgo#687467,
    bgo#687842, bgo#687872, bgo#687977.
  + Updated translations.
* Mon Jan  7 2013 dimstar@opensuse.org
- Update to version 3.7.0:
  + Add an "inverted" property to GtkLevelBar
  + Support RTL flipping in GtkLevelBar
  + Various memory leak fixes
  + Wayland: Update for protocol changes
  + Bugs fixed: bgo#684288, bgo#684415, bgo#684980, bgo#686013,
    bgo#686152, bgo#686209, bgo#686265, bgo#686280, bgo#686366.
  + Updated translations.
* Mon Jan  7 2013 dimstar@opensuse.org
- Update to version 3.6.4:
  + Stylecontext: Make font hack not crash (bgo#691186).
* Fri Jan  4 2013 dimstar@opensuse.org
- Update to version 3.6.3:
  + The Wayland backend works with Wayland 1.0.0 now.
  + Bugs fixed: bgo#132333, bgo#371034, bgo#548793, bgo#577806,
    bgo#626499, bgo#668239, bgo#672193, bgo#677339, bgo#683072,
    bgo#687065, bgo#687816, bgo#688710, bgo#688884, bgo#689235,
    bgo#690266.
  + Updated translations.
* Fri Nov 23 2012 jengelh@inai.de
- Make gtk3-devel-32bit available on all arches
- Remove redundant tags/sections from specfile
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + Bugs fixed: bgo#677609, bgo#686021, bgo#686265, bgo#686280,
    bgo#687196, bgo#687467, bgo#687872.
  + Updated translations.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Broadway:
  - use binary websockets when available
  + CSS:
  - huge refactoring to avoid computing wrong values
  - treeview: Invalidate children properly
  - treeview: Fix computing child paths
  + Bugs fixed: bgo#646221, bgo#682395, bgo#684517, bgo#684639,
    bgo#684984, bgo#685449, bgo#685996
  + updated translations.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Add support for blur to CSS shadows
  + Bugs fixed: bgo#679883, bgo#684258, bgo#684606, bgo#684607
  + Updated translations.
* Wed Sep 19 2012 dimstar@opensuse.org
- Update to version 3.5.18:
  + GMenu:
  - Support namespaces for actions
  - Allow submenus to have actions for opening
  - New function: gtk_menu_shell_bind_model
  + CSS:
  - Parse and support CSS animations
  - Support cross-fading and transitions
  + OS X:
  - Adjust scrollbar and scale behavior according to platform
  + Bugs fixed: bgo#643611, bgo#658694, bgo#670390, bgo#671786,
    bgo#674108, bgo#676890, bgo#677559, bgo#680962, bgo#682630,
    bgo#682831, bgo#683474, bgo#683627, bgo#683718, bgo#683738,
    bgo#683874, bgo#683896, bgo#684038, bgo#684076, bgo#684096,
    bgo#684156.
  + Updated translations.
* Wed Sep  5 2012 dimstar@opensuse.org
- Update to version 3.5.16:
  + Fix critical warnings on startup of nautilus.
* Tue Sep  4 2012 dimstar@opensuse.org
- Update to version 3.5.14:
  + Input method support
  - Propagate input purpose and hints to individual IMs
  - Add a hint to suppress on-screen keyboards
  + GtkEntry can now set Pango attributes for its text
  + GtkEntry and GtkTextView show 'selection handles' when used
    with touch devices
  + GtkSpinButton can be oriented vertically
  + Bugs fixed: bgo#645065, bgo#661973, bgo#672046, bgo#672431,
    bgo#676787, bgo#679144, bgo#681617, bgo#682129, bgo#682291,
    bgo#682552, bgo#682662, bgo#682724, bgo#682825, bgo#682919,
    bgo#683001, bgo#683168
  + Updated translations.
* Tue Aug 21 2012 dimstar@opensuse.org
- Update to version 3.5.12:
  + GtkApplication:
  - Add gtk_application_get_active_window to get the active
    window
  - Add gtk_widget_insert_action_group to allow more flexibility
    when associating widgets with actions
  + GtkMenuButton:
  - The gtk_menu_button_set_menu function is getting renamed
    to gtk_menu_button_set_popup. The old name is still available
    for now, but will be removed before 3.6
  + GtkToolbar:
  - Use CSS properties instead of style properties for padding
  + Input method support:
  - GtkEntry and GtkTextView now have input-purpose and
    input-hints properties that let applications provide useful
    hints to input methods, like 'this entry is for a phone nr'.
  + Bugs fixed: bgo#373279, bgo#651244, bgo#673478, bgo#681577,
    bgo#681591, bgo#681613, bgo#682193, bgo#682235
  + Updated translations.
* Tue Aug  7 2012 dimstar@opensuse.org
- Update to version 3.5.10:
  + Wayland:
  - Add keyboard handling
  - Improve clipboard handling
  - Add default settings implementation
  + GDK thread support has been deprecated
  + Bugs fixed: bgo#679910, bgo#679978, bgo#680754, bgo#680803,
    bgo#680822, bgo#680901, bgo#680949, bgo#680988, bgo#681005,
    bgo#681006, bgo#681064
  + Updated translations.
- Add docbook-xsl-stylesheets and xsltproc BuildRequires: new
  dependencies in order to build the man pages.
* Tue Jul 17 2012 dimstar@opensuse.org
- Update to version 3.5.8:
  + gtk-launch: A new commandline utility to launch an application
    from its desktop file
  + GtkStrengthBar: A new widget for displaying the strength or
    level or some quantity
  + Wayland: Updates for changes in the Wayland protocol
  + Bugs fixed: bgo#667808, bgo#671437, bgo#671817, bgo#675990,
    bgo#677347, bgo#677491, bgo#678828, bgo#678829, bgo#679092,
    bgo#679166, bgo#679228, bgo#679409, bgo#679449, bgo#679454,
    bgo#679537, bgo#679705, bgo#677892, bgo#679342.
  + Updated translations.
* Mon Jul 16 2012 dimstar@opensuse.org
- Update to version 3.5.6:
  + GtkSearchEntry is a subclass of GtkEntry that is set up to be
    used as a search entry
  + GtkMenuButton is button that pops up a menu. The menu can be
    generated from a GMenu or provided manually
  + The GtkMountOperation code will now use gnome-shell to present
    a system-modal mount dialog when available
  + The accessibility bridge code that exports accessible objects
    on the bus is used by default.
  + Bugs fixed: bgo#613561, bgo#652809, bgo#668013, bgo#669986,
    bgo#670369, bgo#674963, bgo#676077, bgo#677491, bgo#677551,
    bgo#677649, bgo#677774, bgo#677809, bgo#677915, bgo#677941,
    bgo#677943, bgo#678175, bgo#678407, bgo#678418.
  + Updated translations.
- Add pkgconfig(atk-bridge-2.0) BuildRequires: new dependency for
  the accessibility support.
* Mon Jul 16 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + GtkIconView size allocation has been rewritten to support
    height-for-width and work better.
  + The theming code now supports multiple backgrounds and
    transitions.
  + Bugs fixed: bgo#162865, bgo#460908, bgo#478344, bgo#531319,
    bgo#571254, bgo#587873, bgo#643490, bgo#645514, bgo#646798,
    bgo#647779, bgo#649569, bgo#652304, bgo#657322, bgo#659613,
    bgo#663072, bgo#663991, bgo#664646, bgo#665243, bgo#670449,
    bgo#671025, bgo#671249, bgo#672947, bgo#673237, bgo#673749,
    bgo#674192, bgo#674409, bgo#674549, bgo#675365, bgo#675421,
    bgo#675423, bgo#675501, bgo#675535, bgo#675809, bgo#675895,
    bgo#675899, bgo#675951, bgo#676087, bgo#676196, bgo#676198,
    bgo#676243, bgo#676329, bgo#676356, bgo#676429, bgo#677055,
    bgo#677109, bgo#677202, bgo#677203, bgo#677293, bgo#677363.
  + Updated translations.
* Mon Jul 16 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + Wayland:
  - Allow the wayland backend to be used without cairo-gl
  - Expose GdkWaylandDisplayManager for runtime checks
  + Theming:
  - Optimizations to style invalidation
  - Support CSS animatable properties
  + Bugs fixed: bgo#563688, bgo#646631, bgo#672361, bgo#672993,
    bgo#674468, bgo#674577, bgo#674808, bgo#674809.
  + Updated translations.
- Rebase Patches:
  + gtk3-GTK_PATH64.patch
  + gtk3-path-local.patch.
  + gtk3-bnc130159-bgo319483-async-font-selection.patch
* Sun Jul 15 2012 zaitor@opensuse.org
- Update to version 3.4.4:
  + GtkIconView: Fallout from the layout rewrite has been fixed.
  + Bugs fixed: bgo#531319, bgo#571254, bgo#613561, bgo#643490,
    bgo#646798, bgo#647779, bgo#649569, bgo#659613, bgo#663991,
    bgo#664646, bgo#667808, bgo#670369, bgo#671437, bgo#671817,
    bgo#673749, bgo#675167, bgo#675423, bgo#675535, bgo#675809,
    bgo#675899, bgo#675990, bgo#676077, bgo#676243, bgo#676262,
    bgo#676329, bgo#677127, bgo#677293, bgo#677363, bgo#677551,
    bgo#677649, bgo#677774, bgo#677775, bgo#677809, bgo#677915,
    bgo#677941, bgo#678175, bgo#678407, bgo#678829, bgo#679166,
    bgo#679228, bgo#679409, bgo#679454, bgo#679537.
  + Updated translations.
* Tue May 15 2012 dimstar@opensuse.org
- Update to version 3.4.3:
  + GtkIconView: The sizing and layout has been rewritten.
  + Bugs fixed: bgo#478344, bgo#587873, bgo#663072, bgo#670449,
    bgo#672947, bgo#673237, bgo#674192, bgo#674549, bgo#675421,
    bgo#675501
  + Updated translations.
* Sun May  6 2012 dimstar@opensuse.org
- Update to version 3.4.2:
  + Bugs fixed: bgo#668931, bgo#669989, bgo#670373, bgo#671249,
    bgo#672789, bgo#673259, bgo#673644, bgo#673650, bgo#674050,
    bgo#674102, bgo#674118, bgo#674200, bgo#674286, bgo#674326,
    bgo#674587, bgo#674806, bgo#674807, bgo#674890
  + Updated translations.
* Sat Apr 14 2012 dimstar@opensuse.org
- Update to version 3.4.1:
  + Win32 fixes
  + OS X fixes.
  + Bugs fixed: bgo#587441, bgo#672133, bgo#672358, bgo#672544,
    bgo#672961, bgo#673090, bgo#673125, bgo#673139, bgo#673200,
    bgo#673328, bgo#673440, bgo#673441, bgo#673458, bgo#673693,
    bgo#673882
  + Updated translations.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Bugs fixed: bgo#658875, bgo#671006, bgo#672163, bgo#672587,
    bgo#672763.
  + Updated translations.
* Tue Mar 20 2012 dimstar@opensuse.org
- Update to version 3.3.20:
  + Theming:
  - Reduced memory consumption in the css parser
  - Fixed Windows theme rendering under XP
  - Support for background-position
  + Bugs fixed: bgo#657385, bgo#662023, bgo#670176, bgo#671065,
    bgo#671453, bgo#671488, bgo#671588, bgo#671659, bgo#671819,
    bgo#671898, bgo#672009, bgo#672117, bgo#672125, bgo#672173,
    bgo#672182, bgo#672367.
* Tue Mar  6 2012 vuntz@opensuse.org
- Update to version 3.3.18:
  + Add support for touch devices:
  - New device types GDK_SOURCE_TOUCHSCREEN and
    GDK_SOURCE_TOUCHPAD for direct and indirect touch devices
  - New event GdkEventTouch and GDK_TOUCH_MASK
  - New signal GtkWidget::touch-event
  + Add support for smooth scrolling:
  - Scroll events can contain scroll deltas, obtainable via
    gdk_event_get_scroll_deltas()
  - Scroll direction for such events is GDK_SCROLL_SMOOTH
  - To receive scroll events, widgets must now set either
    GDK_SCROLL_MASK or GDK_SMOOTH_SCROLL_MASK
  + GtkScrolledWindow will do kinetic scrolling with touch devices
  + XInput2 is now required for building the X11 backend, support
    for XInput1 has been removed
  + Deprecations are now versioned, and new API is marked with the
    version it was introduced. Use these with
    GDK_VERSION_{MIN,MAX}_REQUIRED
  + Theming:
  - Memory consumption of the CSS parser has been reduced
  - CSS selectors of the form "a + b" and "a ~ b" work now
  + Bugs fixed: bgo#650693, bgo#655065, bgo#668141, bgo#669335,
    bgo#669342, bgo#670555, bgo#670881, bgo#671057, bgo#671070,
    bgo#671170.
  + Updated translations.
* Tue Feb 21 2012 vuntz@opensuse.org
- Update to version 3.3.16:
  + The widget-factory theme test is now installed as a demo named
    gtk3-widget-factory
  + The Raleigh theme is now a pure fallback theme that doesn't
    share any CSS with other themes anymore
  + GtkColorSelectionDialog has been deprecated in favor of a new
    color chooser widget named GtkColorChooserDialog
  + The GtkApplication session support has been simplified
  + Bugs fixed: bgo#612283, bgo#668114, bgo#669116, bgo#669208,
    bgo#669511, bgo#669636, bgo#669638, bgo#669794, bgo#669947,
    bgo#670077, bgo#670078, bgo#670400.
  + Updated translations.
* Tue Feb  7 2012 vuntz@opensuse.org
- Update to version 3.3.14:
  + Theming:
  - Fixes for border handling in GtkEntry, GtkCellRendererText,
    GtkComboBox
  - Parse values more carefully, supporting percentages, angles
  - Implement CSS linear-gradient syntax
  - Support background-size
  - Support a gtk.gresource file in themes
  + Bugs fixed: bgo#543520, bgo#649121, bgo#669176.
  + Updated translations.
- Remove xz BuildRequires now that it comes for free in the build
  system.
* Tue Jan 31 2012 vuntz@opensuse.org
- Update to version 3.3.12:
  + GtkApplication:
  - Add API to create menus from models
  - New format for <menu> in GtkBuilder files
  + Add a RELAX NG schema for the GtkBuilder XML.
  + Several cleanups and bug fixes.
- Use %%glib2_gsettings_schema_* macros in devel subpackage for new
  GSettings schema.
* Tue Jan 24 2012 vuntz@opensuse.org
- Move ChangeLog to devel subpackage, as it can be big and is not
  needed on a default install.
* Fri Jan 20 2012 vuntz@opensuse.org
- Update to version 3.3.10:
  + GtkApplication:
  - Move application menu handling over from GIO
  - Fix resize grip positioning in GtkApplicationWindow
  + Wayland:
  - Make combo boxes work
  - Make key modifiers work like on X11
  - Make mouse buttons work correctly
  + Quartz:
  - Make key modifiers work more like they do on X11
  + Printing:
  - Fix handling of custom cups options
  + Accessibility:
  - Bring key snooping support back for now
  + Updated translations.
- Drop gtk3-unbreak-apps.patch: fixed upstream.
* Fri Jan 20 2012 vuntz@opensuse.org
- Add gtk3-unbreak-apps.patch: revert a change in 3.3.8 that breaks
  eog and epiphany.
* Tue Jan 17 2012 vuntz@opensuse.org
- Update to version 3.3.8:
  + GtkApplication:
  - Supports logout notification and inhibiting
  - Buttons, toolbuttons and switches can now be connected to
    GActions
  + GtkSpinButton no longer allows to change the value when not
    editable
  + GtkLabel link support has been rewritten to be be more robust
  + GtkBuilder:
  - Supports the 'id' in GtkComboBoxText
  - Can parse GVariant-valued properties
  - Support loading from a GResource
  + GtkImage:
  - Support loading from a GResource
  + GtkUIManager:
  - Support loading from a GResource
  + Accessibility:
  - Key snooping support has been removed
  + Wayland backend:
  - Cursor handling updates
  - Look for cursors in the 'weston' directory
  - Make resize grips work
  - Implement device grabs
  - Implement window geometry hints
  - Set surface type based on window type hint
  - Add basic clipboard and selection implementations
  - Implement client-side keyboard repeat
  - Update GdkWindow focus state to match reality
  + Theming:
  - Improved CSS compliance for selector matching
  - Improved CSS compliance for value resolution, including full
    support for 'inherit', 'initial', 'currentColor', 'none'
  - Support border-style properties
  - 'window-unfocused' has been renamed to 'backdrop'
  + New deprecations:
  - GdkColor
  - GtkButton::inner-border
  + Miscellaneous:
  - Turn default theme css files and dnd cursors into
    GResources
  + Bugs fixed: bgo#543520, bgo#612396, bgo#613728, bgo#620240,
    bgo#629878, bgo#631414, bgo#639875, bgo#657367, bgo#659516,
    bgo#660139, bgo#660309, bgo#663479, bgo#665015, bgo#666103,
    bgo#666600, bgo#666685, bgo#666710, bgo#666842, bgo#667018,
    bgo#667229, bgo#667394, bgo#667473, bgo#667485, bgo#667534,
    bgo#667546, bgo#667628, bgo#667695, bgo#667705, bgo#666921.
  + Updated translations.
* Tue Dec 20 2011 vuntz@opensuse.org
- Update to version 3.3.6:
  + GtkApplication has grown support for exporting application
    menus and menubars on the bus, as a GMenuModel. The new
    GtkApplicationWindow toplevel automatically displays these menu
    models when needed.
  + GtkSpinButtons have received a long-overdue face-lift to make
    them easier to use with both mouse and touch.
  + GtkScale has gained a has-origin property to request filled-in
    drawing of the trough.
  + GtkWindow can now request that the window manager hide the
    titlebar when the window is maximized.
  + The GtkTreeView accessibility support and the core treeview
    code have been extensively refactored; performance should be
    much improved. But watch out for regressions.
  + The GtkFileChooser entry completion code has been extensively
    refactored; it now uses GtkEntryCompletion.
  + Excessive dependencies have been culled from Requires: lines in
    pc files. Dependent modules may have to declare dependencies
    that they were getting 'for free' in the past.
  + Theming improvements:
  - The background-clip and background-origin CSS properties have
    been implemented.
  + Win32 improvements:
  - Theming of column headers, radio buttons and menuitems,
    notebook tabs, etc has been fixed.
  - Menus, tooltips, and other popups show above the task bar.
  + Wayland:
  - The Wayland backend has been updated to the current Wayland
    API.
  + Bugs fixed:
  - bgo#664640: CUPS authentication does not work
  - bgo#641999: Consider adding a workarea API
  - bgo#603823, bgo#640317, bgo#646461, bgo#650943, bgo#661428,
    bgo#662814, bgo#664137, bgo#664456, bgo#664467, bgo#664469,
    bgo#664537, bgo#665140, bgo#665326, bgo#665616, bgo#665741,
    bgo#665999, bgo#666242, bgo#657578, bgo#659445, bgo#663573,
    bgo#666392, bgo#666552.
  + Updated translations.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Add explicit pkgconfig(gmodule-2.0) and pkgconfig(pangoft2)
  BuildRequires: they were missing before.
- Drop gtk3-parallel-build.patch: fixed upstream.
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib files into typelib-1_0-Gtk-3_0 subpackage.
- Add typelib-1_0-Gtk-3_0 Requires to devel subpackage.
* Wed Nov 30 2011 dimstar@opensuse.org
- Add gtk3-parallel-build.patch: Fix up makefile rules for parallel
  builds. Avoids random build failures. Taken from git, commit
  id=7756f49.
* Tue Nov 22 2011 dimstar@opensuse.org
- Update to version 3.3.4:
  + The beagle search backend has been dropped
  + Stop using GDK/GTK_DISABLE_DEPRECATED guards for deprecated
    functions; instead use function attributes
  + Make GtkCellRendererAccel support naked keyvals, so it can
    be used in gnome-control-center
  + GDK changes:
  - Make the Mod1 == Alt assumption official
  - The Broadway backend has initial support for V7+ websockets
  + GtkApplication no longer uses gtk_main internally
  + GtkNotebook now destroys its action widgets, instead of leaking
    them
  + Theming improvements:
  - Background images can now be tiled instead of stretched,
    using the background-repeat CSS property
  - Unfocused windows can be themed differently, using
    the 'window-unfocused' state flag
  + Accessibility improvements:
  - Much better treeview performance
  - Completely ignore invisible columns in treeviews
  - Many a11y/treeview-related crashes fixed
  - Combo box keybindings are reported again
  - Textview respects display lines again
  + OS X improvements
  + Win32 improvements
  + Bugs fixed: bgo#84314, bgo#142874, bgo#169811, bgo#171456,
    bgo#324254, bgo#516822, bgo#542777, bgo#552041, bgo#603559,
    bgo#604156, bgo#606727, bgo#612359, bgo#616544, bgo#628049,
    bgo#631384, bgo#647460, bgo#652239, bgo#658841, bgo#658842,
    bgo#659151, bgo#659257, bgo#661858, bgo#661859, bgo#661997,
    bgo#662160, bgo#662628, bgo#662670, bgo#662691, bgo#662755,
    bgo#662839, bgo#662870, bgo#662953, bgo#663073, bgo#663138,
    bgo#663182, bgo#663345, bgo#663396, bgo#663522, bgo#663605,
    bgo#663694, bgo#663761, bgo#663825, bgo#663856, bgo#663994,
    bgo#664021, bgo#664027, bgo#664132.
- Drop gtk3-immodule-fallback.patch: fixed upstream.
- Rebase gtk3-bnc130159-bgo319483-async-font-selection.patch.
* Sat Oct 29 2011 dimstar@opensuse.org
- Update to version 3.3.2:
  + GtkCellRendererAccel can show virtual modifiers
  + Theming improvements:
  - CSS: 'transparent' can be used a color
  - Improved notebook tab rendering
  - Support opacity and rounded corners for tooltips
  + Improvements of cross-platform key and button event handling:
  - Support '<Primary>' in accelerator strings
  - Use appropriate modifiers for extending and modifying
    selections, depending on the platform
  - Use the appropriate button for triggering context menus,
    depending on the platform
  + OS X improvements.
  + Bugs fixed: bgo#628936, bgo#653289, bgo#655057, bgo#657770,
    bgo#658767, bgo#658772, bgo#659022, bgo#659655, bgo#660687,
    bgo#660730, bgo#659602, bgo#659406, bgo#660619, bgo#599617,
    bgo#628936, bgo#631167, bgo#651818, bgo#659672, bgo#660139,
    bgo#660833, bgo#661032, bgo#661089, bgo#661780, bgo#661835,
    bgo#662024, bgo#662132, bgo#662177, bgo#662230, bgo#662308,
    bgo#662467, bgo#662481, bgo#662629.
  + Updated translations.
- Rebase gtk3-path-local.patch.
* Fri Oct 28 2011 vuntz@opensuse.org
- Add gtk3-immodule-fallback.patch: make it possible to specify
  fallback input method modules in the GTK_IM_MODULE environment
  variable. This is useful in case a module doesn't exist for both
  gtk2 and gtk3. Fix bnc#723382.
* Sat Oct 15 2011 vuntz@opensuse.org
- Update to version 3.2.1:
  + GtkCellRendererAccel can show virtual modifiers
  + CSS improvements: 'transparent' can be used a color
  + OS X improvements
  + Improvements of cross-platform key and button event handling:
  - Support '<Primary>' in accelerator strings
  - Use approprivate modifiers for extending and modifying
    selections, depending on the platform
  - Use the appropriate button for triggering context menus,
    depending on the platform
  + Bugs fixed: bgo#628936, bgo#653289, bgo#655057, bgo#657770,
    bgo#658767, bgo#658772, bgo#659022, bgo#659655, bgo#660687,
    bgo#660730.
  + Updated translations.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + GtkFontChooser: More speed ups. The font chooser will now load
    instanteously, even if you have thousands of fonts
  + Bug fixes, including bgo#659826, bgo#659966, bgo#640741.
  + Updated translations.
- Drop gtk3-bnc129753-localize-font-style-name.patch: GTK+ 3 now
  heavily relies on pango to display the font style name, so we
  can't have a patch like this one without fixing pango, which
  implies solving the real issue (and therefore removing the need
  for the patch). See bgo#95731 and bgo#123498 for the upstream
  pango bug.
- Remove gnome-patch-translation support as there is no string
  added by patches anymore:
  + Remove gnome-patch-translation BuildRequires.
  + Remove call to gnome-patch-translation-prepare and
    gnome-patch-translation-update in %%prep.
* Tue Sep 20 2011 vuntz@opensuse.org
- Update to version 3.1.92:
  + GtkIconView: Cells will now be prelighted, if you set the
    GtkCellRendererPixbuf::follow-state property.
  + GtkFontChooser: Speed up population of the font list somewhat.
  + Bugs fixed: bgo#615501, bgo#658981, bgo#659241, bgo#659247.
  + Updated translations.
- Rebase gtk3-bnc129753-localize-font-style-name.patch.
* Wed Sep 14 2011 vuntz@opensuse.org
- Update to version 3.1.90:
  + GtkAppChooserButton: A new function has been added that makes
    it possible to have the button select the default app (as
    opposed to the most-recently-used app).
  + A lot of feedback on the the tree model refactoring has been
    incorporated via new test cases and bug fixes
  + The filechooser search has been ported to tracker 0.12 and is
    using the tracker DBus API directly now.
  + The new fontchooser API has been reworked a bit to make it
    follow the same pattern we use else where. GtkFontChooser is
    now an interface that is implemented by GtkFontChooserButton,
    GtkFontChooserDialog and GtkFontChooserWidget (to which the
    original GtkFontChooser has been renamed).
  + Bugs fixed: bgo#514843, bgo#617583, bgo#642706, bgo#657353,
    bgo#657627, bgo#658272, bgo#658379, bgo#658398, bgo#658507,
    bgo#658600, bgo#658696, bgo#658774.
  + Updated translations.
- Update gtk3-bnc129753-localize-font-style-name.patch: rebase the
  patch, and localize font style names in new font-related widgets
  too.
* Tue Sep  6 2011 vuntz@opensuse.org
- Update to version 3.1.18:
  + GtkFileChooser: It is no possible to go to the containing
    folder of a selected file in recent files or search results.
  + Bugs fixed: bgo#530253, bgo#566202, bgo#581435, bgo#655631,
    bgo#657793, bgo#657882, bgo#657963, bgo#657985, bgo#658008,
    bgo#658077, bgo#658111, bgo#658168, bgo#658200.
  + Updated translations.
- Pass explicit --enable-colord to configure to make sure we build
  colord support.
* Wed Aug 31 2011 vuntz@opensuse.org
- Update to version 3.1.16:
  + Make distcheck work again, and fix errors that crept in by lack
    of a working distcheck.
  + Bugs fixed: bgo#656223.
- Remove sed hack in %%prep introduced for 3.1.14 since it's now
  unneeded.
* Tue Aug 30 2011 vuntz@opensuse.org
- Update to version 3.1.14:
  + GtkTreeView: The GtkTreeModelFilter and GtkTreeModelSort
    implementations have been improved and a comprehensive test
    suite has been added.
  + GtkFileChooser: The selected file(s) can now be copied to the
    clipboard.
  + Bugs fixed: bgo#656851, bgo#344858, bgo#349502, bgo#621076,
    bgo#634136, bgo#649588, bgo#650762, bgo#651827, bgo#656986,
    bgo#657146, bgo#657260, bgo#657359, bgo#657384.
  + Updated translations.
- Remove build of tests with a sed hack in %%prep due to missing
  file in this tarball. This hack will get removed with the next
  release.
- Drop gtk3-enabledeprecated.patch: fixed upstream.
* Tue Aug 16 2011 dimstar@opensuse.org
- Update to version 3.1.12:
  + GtkFontChooserDialog: A newly designed font selection dialog
    that is intended to replace GtkFontSelectionDialog
  + Drawing of focus rectangles is now optional; it can be turned
    off altogether, or until actual keyboard interaction happens,
    with the gtk-visible-focus setting.
  + OS X: Fixes for 10.7 (Lion)
  + Bugs fixed: bgo#407885, bgo#508601, bgo#599664, bgo#645258,
    bgo#649567, bgo#652991, bgo#653817, bgo#653964, bgo#655074,
    bgo#655122, bgo#655173, bgo#655495, bgo#655496, bgo#655545,
    bgo#655822, bgo#656098, bgo#656421.
  + Updated translations.
- Add gtk3-enabledeprecated.patch: Fix build by enabling deprecated
  symbols for the test suite.
* Sun Jul 24 2011 vuntz@opensuse.org
- Update to version 3.1.10:
  + Assorted file chooser improvements/redesign:
  - Remove the expander in Save mode
  - Move the path bar up in Save mode
  - Remember the last opened directory
  - Start in recently-used mode when no folder is set
  - Update recent-files when confirming in the file chooser
  + Accessibility:
  - Gail has been merged into GTK+ and is no longer a module
  - A testsuite for a11y functionality has been added
  + Theming:
  - Icon view cells can now have a border
  + GtkMountOperation can now show processes on OpenBSD
  + Gdk input devices now expose their XInput2 device ID via
    gdk_x11_device_get_id()
  + Bugs fixed: bgo#653450, bgo#653705, bgo#653947, bgo#654125,
    bgo#654179, bgo#654428, bgo#654678, bgo#654695, bgo#654720,
    bgo#655009, bgo#654266.
  + Updated translations.
- Drop gtk3-fix-crash-recent-glib.patch: fixed upstream.
- Rebase gtk3-path-local.patch.
- Manually create %%{_libdir}/gtk-3.0/modules: it used to exist
  because of the libgail module, but now that the module is gone,
  we need to manually create the directory for external modules
  that will be installed there.
* Thu Jul 21 2011 vuntz@opensuse.org
- Add gtk3-fix-crash-recent-glib.patch: this fixes a crash in all
  apps with glib 2.29.12. Taken from git.
* Wed Jul  6 2011 vuntz@opensuse.org
- Change branding-upstream subpackage:
  + Add Requires for libgtk-3-0 since the branding package is
    useless without it.
  + Update summary and description.
  + Make noarch.
  + Add branding comments to let people know how gtk3 branding
    works.
* Tue Jul  5 2011 vuntz@opensuse.org
- Update to version 3.1.8:
  + Theming improvements:
  - Multiple colors are now supported
  - Support CSS font properties like font-size, font-family, etc
  - nth-child works for toolbars too
  + Bug fixes: bgo#652506, bgo#652618, bgo#652769, bgo#653053,
    bgo#653191, bgo#653333, bgo#653512, bgo#653785.
  + Updated translations.
- Drop gtk3-fix-crash.patch: fixed upstream.
- Drop gtk3-fix-100-empathy.patch: fixed upstream another way.
* Tue Jun 28 2011 vuntz@opensuse.org
- Add gtk3-fix-100-empathy.patch to fix empathy taking 100%% of the
  CPU.
- Add gtk3-fix-crash.patch to fix a crash in empathy, when opening
  the context menu for a contact.
* Thu Jun 16 2011 vuntz@opensuse.org
- Pass --enable-x11-backend to configure to make sure we always
  build the X11 backend, that we always want.
- Add a build_broadway_backend define, that controls whether we
  build the broadway (HTML5!) backend. If set:
  + we pass --enable-broadway-backend to configure
  + we package the additional files
- Set build_broadway_backend to 1 for now, so people can play with
  the backend.
* Wed Jun 15 2011 dimstar@opensuse.org
- Update to version 3.1.6:
  + GtkOverlay is a new container that allows to place one or more
    'overlay' widgets on top of another widget. This can be used
    for 'floating statusbars' and similar interfaces.
  + GtkLockButton has been simplified in appearance to look like a
    normal button
  + GtkNotebook now supports height-for-width layout
  + Accessibility for menuitems and combo boxes has been restored
  + The horizontal and vertical subclasses of GtkBox, GtkPaned,
    GtkSeparator, GtkScrollbar, GtkScale and GtkButtonBox have
    been deprecated
  + The print dialog can now display color profile information
  + Many enhancements and fixes to CSS theming
  - The CSS parser has been rewritten with the goal of better CSS
    compliance and improved error handling
  - A testsuite for the parser has been added
  - Attributes can be inherited from parent widgets
  - Shorthand properties are supported
  - Color and font attributes are now inherited
  - Borders and padding are now handled much more consistently,
    and border-radius support is more complete
  - text-shadow, box-shadow and icon-shadow attributes are now
    supported
  - nth-child works for boxes
  + Bugs fixed: bgo#353712, bgo#576492, bgo#624539, bgo#634491,
    bgo#634994, bgo#641087, bgo#642768, bgo#642773, bgo#642929,
    bgo#644906, bgo#646859, bgo#649314, bgo#649779, bgo#649972,
    bgo#649979, bgo#650012, bgo#650110, bgo#650114, bgo#650167,
    bgo#650202, bgo#650302, bgo#650382, bgo#650418, bgo#650420,
    bgo#650424, bgo#650530, bgo#650664, bgo#651194, bgo#651706,
    bgo#651707, bgo#651734, bgo#651979, bgo#652045, bgo#652102,
    bgo#652103, bgo#652282.
  + Updated translations.
- Add pkgconfig(colord) BuildRequires for new color profile
  information feature.
* Tue Jun  7 2011 dimstar@opensuse.org
- Update to version 3.1.4:
  + GtkAssistant has received a visual refresh; as a side-effect,
    the various image properties are no longer used
  + GtkTextView can now handle RGBA colors
  + GtkFileChooser now remembers the last opened directory
  + GtkLockButton is a new widget to control dialogs with
    PolicyKit (or other) permissions
  + Size allocation changes:
  - GtkPaned and GtkMenuBar now do height-for-width
  - GtkAccelLabel is smarter about hiding the accel if too small
  - GTK+ now warns if widgets are under-allocated; this
    may cause considerable noise, it will be turned off
    before the next stable release
  - Label size allocation has been reworked, check your labels
  - No longer try to guess the size of labels; this makes
    it more important to give windows reasonable default
    sizes or set width-chars/max-width-chars on labels
  - The computation of initial window size has been reworked,
    check your windows
  + A test framework for mozilla-style reftests has been added
  + GDK Broadway backend changes:
  - Improved key event handling
  - Make resize grips work
  - Make window close buttons work
  - Stream data over websocket
  + Bugs fixed: bgo#618815, bgo#626457, bgo#626503, bgo#642214,
    bgo#644426, bgo#646517, bgo#646876, bgo#647284, bgo#647790,
    bgo#647806, bgo#647962, bgo#648136, bgo#648419, bgo#648570,
    bgo#648943, bgo#649295, bgo#649313, bgo#649457, bgo#649593.
  + Updated translations.
- Changes from version 3.1.2:
  + Theming fixes and enhancements
  - GtkNotebook has an initial-gap style property
  - GtkNotebook tab drawing fixes
  - Fix problems with transparent backgrounds in panel applets
  - Style classes for 'inline' and 'primary' toolbars and
    sidebars
  - Dark theme information is made available to window managers
    via the _GTK_THEME_VARIANT property
  - Improved rendering of insensitive text
  - Support non-uniform border withs in the default engine
  - Fix prelight on treeview expanders
  + GtkEntry supports 'hinting'
  + GtkExpander can resize toplevel windows when expanding
  + GtkGrid supports RTL flipping
  + GtkStatusIcon reads the _NET_SYSTEM_TRAY_ICON_SIZE property
    to get information about the preferred icon size
  + To help with debugging of rendering problems, GDK consults
    the GDK_RENDERING environment variable. Possible values include
    'similar', 'image' and 'recording'
  + Fix some problems with XI2 and input methods
  + New, experimental GDK backends:
  - broadway, which targets HTML5
  - wayland, which targets the wayland display server
  + Bugs fixed: bgo#440963, bgo#635254, bgo#639584, bgo#640692,
    bgo#642712, bgo#642918, bgo#643805, bgo#643841, bgo#644276,
    bgo#644348, bgo#644353, bgo#644355, bgo#644570, bgo#644777,
    bgo#644836, bgo#644847, bgo#644925, bgo#644975, bgo#644976,
    bgo#645057, bgo#645134, bgo#645172, bgo#645176, bgo#645232,
    bgo#645234, bgo#645235, bgo#645236, bgo#645341, bgo#645354,
    bgo#645405, bgo#645458, bgo#645937, bgo#645960, bgo#646338,
    bgo#646446, bgo#646457, bgo#646458, bgo#646460, bgo#646461,
    bgo#646462, bgo#646500, bgo#646815, bgo#646882, bgo#646886,
    bgo#647086, bgo#647152, bgo#647244, bgo#647275, bgo#647278,
    bgo#647594, bgo#554057.
* Tue Jun  7 2011 fcrozat@novell.com
- Update to version 3.0.11:
  + Modernize custom paper size dialog look.
  + Add an app chooser to the gtk-demo 'Pickers' example.
  + Bugs fixed: bgo#642773, bgo#576492, bgo#642929.
  + Updated translations.
* Tue May 31 2011 fcrozat@novell.com
- Update to version 3.0.10:
  + Bugs fixed: bgo#649880, bgo#647284, bgo#648570, bgo#649779,
    bgo#650382.
  + Updated translations.
* Tue Apr 26 2011 fcrozat@novell.com
- Update to version 3.0.9:
  + Fix some interference between XI2 and input methods, XEmbed and
    user-time tracking.
  + Theming improvements
  - Make it possible to give combo boxes, buttons, entries a
    uniform height.
  + GtkGrid now does RTL flipping like other containers.
  + Updated translations.
* Mon Apr  4 2011 fcrozat@novell.com
- Update to version 3.0.8:
  + The size negotiation optimizations turned out to have
    problematic side effects in some applications, and have been
    reverted for now
  + Fix prelight of selected row expanders
  + Bugs fixed: bgo#645341, bgo#646446, bgo#646462, bgo#646498.
  + Updated translations
- Changes from version 3.0.7:
  + Performance improvements for theming and size allocation
  + Thread-safety fixes in file chooser and app chooser code
  + GtkStatusIcon can now receive icon size hints from the tray
    it is embedded in
  + RTL fixes for GtkGrid and GtkWidget::halign
  + Bugs fixed: bgo#639584, bgo#642918, bgo#645232.
* Mon Mar 28 2011 fcrozat@novell.com
- Update to version 3.0.6:
  + Export dark themes for the window manager.
  + Make selectable labels work again.
  + Updated translations.
* Wed Mar 23 2011 fcrozat@novell.com
- Update to version 3.0.5:
  + reverts a problematic change in 3.0.4 which caused application
    font settings to be ignored.
- Changes from version 3.0.4:
  + New style classes for 'inline' toolbars and sidebars have been
    added.
  + Theming fixes and enhancement in many widgets, including
    GtkRange, GtkFileChooser, GtkNotebook, GtkTreeview and
    GtkRadioButton.
  + Bugs fixed: bgo#640692, bgo#642712, bgo#644836, bgo#644975,
    bgo#644976, bgo#645057, bgo#645134, bgo#645172, bgo#645234,
    bgo#645235, bgo#645405, bgo#635254.
  + Updated translations.
- Changes from version 3.0.3:
  + Support for the GDK_NATIVE_WINDOWS environment variable has
    been removed
  + Bugs fixed: bgo#642604, bgo#643416, bgo#644119, bgo#644248,
    bgo#644276, bgo#644348, bgo#644353, bgo#644355, bgo#644570.
  + Updated translations.
* Mon Mar  7 2011 fcrozat@novell.com
- Update to version 3.0.2:
  + GtkSettings have been made multi-backend-safe
  + Many improvements to themability and the default theme:
  - GtkScale slider theming can adjust to scale marks, using
    style classes.
  - A new style class for 'primary' toolbars
  - Widget style classes can now be specified in GtkBuilder
    files.
  - Improved scrollbar drawing
  - Improved combobox drawing
  - Improved spinbutton drawing
  - Improved switch drawing
  - Improved checkbutton drawing
  - Improved menu drawing
  - Improved notebook tab drawing
  + Bugs fixed: bgo#643041, bgo#643131, bgo#643170, bgo#643216,
    bgo#643321, bgo#643347, bgo#643370, bgo#643440, bgo#643496,
    bgo#643543, bgo#643584, bgo#643630, bgo#643685, bgo#643911,
    bgo#643912, bgo#643925, bgo#643967, bgo#644089.
* Tue Feb 22 2011 fcrozat@novell.com
- Update to version 3.0.1:
  + A autoconf macro, GTK_CHECK_BACKEND, has been added
    to allow easy checking for certain gdk backends
  + A number of memory leaks and segfaults involving accessibility
    have been fixed
  + Bugs fixed: bgo#586201, bgo#599907, bgo#626730, bgo#630971,
    bgo#633291, bgo#642213, bgo#642263, bgo#642541, bgo#642677,
    bgo#642681, bgo#642751, bgo#642771, bgo#642772, bgo#642778,
    bgo#642782, bgo#642791.
  + Updated translations.
* Sat Feb 19 2011 vuntz@opensuse.org
- Remove update-alternatives Requires in devel subpackage, since we
  don't use this mechanism anymore there.
* Sun Feb 13 2011 vuntz@opensuse.org
- Add Provides/Obsoletes for libgtk-3_0-0 to libgtk-3-0 since there
  are some files that are shared between the two and some users
  might have libgtk-3_0-0 already.
- Remove default gtkrc that was used in branding-upstream, and
  replace it with a settings.ini file, since this is the new
  mechanism.
* Fri Feb 11 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Library sonames have been changed from libgdk-3.0 and
    libgtk-3.0 to libgdk-3 and libgtk-3.
  + Bugs fixed: bgo#632775, bgo#639846, bgo#639945, bgo#640801,
    bgo#641196, bgo#641302, bgo#641367, bgo#641409, bgo#641429,
    bgo#641431, bgo#641517, bgo#641558, bgo#641621, bgo#641640.
  + Updated translations.
- Rename library package accordingly with new library soname.
- Remove update-alternatives mechanism for gtk-builder-convert
  since the tool is not in gtk3 anymore. Also remove python-xml
  Requires of devel package, which was there only for this tool.
* Thu Feb  3 2011 dimstar@opensuse.org
- Update to version 2.99.3:
  + This release adds some forgotten padding to class structs,
    and thus breaks ABI for a last time before 3.0
  + Many Introspection annotation improvements
  + We no longer build the gtk-update-icon-cache utility, and
    use a preexisting one, if --enable-gtk2-dependency is passed
    to configure
  + GtkBuilder can now fill GtkComboBoxText and GtkMenuToolButton
    widgets with data, as well as GtkFileFilters and
    GtkTextTagTables
  + GtkImage now has a ::use-fallback property to allow generic
    fallback with GIcons and icon-names (e.g. for symbolic icons)
  + There's a new gtk_text_view_get_cursor_locations() to enable
    popup-at-cursor functionality
  + The application chooser widgets can now set a custom dialog
    heading
  + The file chooser and application chooser widgets have received
    minor visual improvements
  + gtk-auto-mnemonics is now backed by an XSetting
  + Defaults for GtkSettings, as well as theme-specific settings,
    are now read from key files
  + Key themes are now supported again, their syntax has been
    changed to be CSS-like
  + More objects use GtkStyleContext directly
  + GtkPlug and GtkSocket have been reduced to X11-specific API,
    and using them requires including the <gtk/gtkx.h> header, and
    uses of GdkNativeWindow in their APIs have been replaced by the
    X11 Window type.
  + Bugs fixed: bgo#351755, bgo#586635, bgo#590459, bgo#598952,
    bgo#626336, bgo#634677, bgo#635287, bgo#636691, bgo#638920,
    bgo#639139, bgo#639186, bgo#639325, bgo#639380, bgo#639455,
    bgo#639520, bgo#639531, bgo#639625, bgo#639750, bgo#639754,
    bgo#639767, bgo#639792, bgo#639822, bgo#639845, bgo#639931,
    bgo#639949, bgo#640005, bgo#640006, bgo#640011, bgo#640105,
    bgo#640161, bgo#640188, bgo#640195, bgo#640282, bgo#640313,
    bgo#640391, bgo#640487, bgo#640698, bgo#640712, bgo#640744,
    bgo#640902, bgo#640965, bgo#640983, bgo#640999, bgo#641023,
    bgo#641039, bgo#641042, bgo#641059, bgo#641073
  + Updated translations.
* Thu Jan 13 2011 vuntz@opensuse.org
- Update to version 2.99.2:
  + More widgets are using GtkStyleContext directly.
  + gtk-builder-convert now accepts a --target-version option
  + Bug fixes: bgo#637965, bgo#639127, bgo#639157, bgo#639209,
    bgo#639286, bgo#639327.
  + Updated translations.
* Wed Jan 12 2011 vuntz@opensuse.org
- Update to version 2.99.1:
  + More widgets are using GtkStyleContext directly.
  + GtkBuilder support has been added for setting menus on
    GtkMenuToolButtons and for adding tags to GtkTextTagTable as
    well as adding items to GtkComboBoxText.
  + Bug fixes: bgo#350618, bgo#612918, bgo#635687, bgo#638017,
    bgo#638119, bgo#638880, bgo#639030, bgo#639047, bgo#639079,
    bgo#639105, bgo#639106, bgo#639127, bgo#639157.
  + Updated translations.
* Fri Jan  7 2011 vuntz@opensuse.org
- Update to version 2.99.0:
  + Various API deprecations and removals, see NEWS for details.
  + The gtk-update-icon-cache and gtk-builder-convert utilities
    have been renamed back to their un-suffixed names.
    Distributions will have to resolve the conflict between GTK+
    2.x and 3.0 packages by dropping one set of the utilities and
    adding a dependency.
  + It is now possible to include multiple GDK backends in a single
    library. The --with-gdk-backend option has been split into
    separate --enable-{x11,win32,quartz}-backend options.
  + The GDK Quartz backend has been ported to the new GDK backend
    API.
  + A number of widgets have been ported to use GtkStyleContext
    directly.
  + Various problems with width-for-height geometry management have
    been fixed in GtkAlignment, GtkCheckButton, GtkBin.
  + The GtkComboBox, GtkIconView and GtkCellView widgets have been
    ported to use GtkCellArea for their cell layouts.
  + The cups print backend can now send print jobs directly in PDF
    if cups supports it.
  + GtkNumerableIcon is a variant of GEmblemedIcon for using
    numbers as emblems.
  + Bugs fixed: bgo#144324, bgo#165987, bgo#307963, bgo#321958,
    bgo#533745, bgo#553404, bgo#559503, bgo#560177, bgo#562182,
    bgo#599130, bgo#617312, bgo#617315, bgo#617322, bgo#617327,
    bgo#617471, bgo#621720, bgo#622125, bgo#629955, bgo#633795,
    bgo#634711, bgo#635299, bgo#637691, bgo#637721, bgo#637736,
    bgo#637763, bgo#637834, bgo#637849, bgo#637895, bgo#637907,
    bgo#637910, bgo#637958, bgo#637974, bgo#638179, bgo#638193,
    bgo#638231, bgo#638386, bgo#638580, bgo#638608.
  + Updated translations.
- Remove --with-xinput=xfree from configure call: the option
  has been renamed to --enable-xinput, and there's no need to
  specify it in our case, really.
- Use update-alternatives mechanism for gtk-update-icon-cache and
  gtk-builder-convert since both tools are shipped with the same
  names in gtk2 and gtk3:
  + Rename the non-versioned tools and man pages to versioned
    filenames.
  + Add update-alternatives Requires(post/postun) to tools and
    devel subpackages.
  + Call update-alterantives in %%post/%%postun of the tools and
    devel subpackages.
* Wed Dec 22 2010 dimstar@opensuse.org
- Update to version 2.91.7:
  + The treeview-refactor branch has been merged, bringing more
    flexible cell arrangement with GtkCellArea, GtkCellAreaBox,
    etc.
  + The gdk-backend branch has been merged. This branch cleans up
    the internal frontend/backend separation in GDK, with the
    ultimate goal of allowing to build a single gdk library that
    contains multiple backends (interesting combinations are
    x11+wayland or quartz+x11).
  + Various API deprecations and removals, see NEWS for details.
  + A number of GTK+ widgets have been ported to use
    GtkStyleContext directly for rendering.
  + The tracker search backend for the file chooser has been
    updated to work with libtracker-sparql as available in
    tracker >= 0.9.
  + The GtkAboutDialog has been given a facelift. It no longer
    opens second-level dialogs.
  + The GDK X11 backend now uses XI2 (including multi-device
    capabilities) by default. Use gdk_disable_multidevice() to
    switch back to the XI1/Core implementation.
  + Bugs fixed: bgo#629923, bgo#634657, bgo#635401, bgo#636732,
    bgo#636777, bgo#637018, bgo#637069, bgo#637155, bgo#637156,
    bgo#637189, bgo#637243, bgo#637256, bgo#637464, bgo#637471,
    bgo#637520, bgo#637606, bgo#637608
  + Updated translations.
- Remove -DGTK_COMPILATION in CFLAGS fixup: it's no longer needed.
- Enable parallel build again.
* Sat Dec 11 2010 dimstar@opensuse.org
- Update to version 2.91.6:
  + Deprecations, cleanups and API changes:
  - GdkDrawable and some X11-specific APIs have been removed
  - GtkStyle and GtkRcStyle have been deprecated
  - The GdkWindowClass enumeration is now GdkWindowWindowClass
  - gdk_window_get_geometry lost its depth argument
  - The old, unused gtk_decorated_window_... functions have been
    removed.
  + GtkComboBox has gained an 'active id' property that is
    intended for easy binding to settings
  + GtkAppChooser: A new family of widgets that allow choosing
    an application to open a file. This is strongly based on
    the corresponding nautilus dialog, which it is replacing.
  + The GtkStyleContext branch has been merged, changing the APIs
    that are used to do themed drawing, and the theme engine
    interfaces. Among the new classes are GtkStyleContext
    (replacing GtkStyle) and GtkCssProvider (replacing the gtkrc
    parser). The migration guide contains a chapter about porting
    from GtkStyle to GtkStyleContext.
  + Bugs fixed: bgo#549720, bgo#582557, bgo#619148, bgo#636060,
    bgo#636129, bgo#636388, bgo#636511
  + Updated translations.
- Note: this update will break GTK+ 3 engines that were not ported
  to the new API.
- Add -DGTK_COMPILATION to CFLAGS to fix a build issue.
- Remove kg translation on 11.3 and earlier.
* Tue Nov 30 2010 dimstar@opensuse.org
- Update to version 2.91.5:
  + GtkSwitch: a new widget that provides switch-like on/off
    functionality
  + Deprecations and cleanups:
  - GtkCallbackMarshal and GtkFunction have been deprecated
  - gtk_init_add has been removed
  - The ::size-request signal has been removed
  - GtkRuler has been removed
  + The default value for the GtkBox::fill property has been
    changed back to TRUE
  + Bugs fixed: bgo#613942, bgo#629955, bgo#633324, bgo#633896,
    bgo#634474, bgo#634558, bgo#634592, bgo#634697, bgo#634821,
    bgo#634987, bgo#635175, bgo#635253, bgo#635307, bgo#635380,
    bgo#635588, bgo#635693, bgo#635879.
  + Updated translations.
- Drop gtk3-introspection-build-fix.patch: fixed upstream.
* Tue Nov 30 2010 vuntz@opensuse.org
- Make gtk3-devel depend on python-xml instead of pyxml: pyxml will
  be removed, and we really wanted to use python-xml anyway.
* Wed Nov 17 2010 dimstar@opensuse.org
- Update to version 2.91.4:
  + bgo#609622: disappearing statusicon
  + bgo#631331: window icons don't work anymore
  + bgo#632894: Only show Desktop in file chooser button if there
    is one
  + bgo#633670: Child minimum/natural size is not respected by
    GtkScrolledWindow
  + bgo#633762: Correctly convert colors to CSS and deal with
    librsvg limitations
  + bgo#633915: gtk_button_box_child_requisition() mishandles size
    allocations
  + bgo#634060: Support for GIcon pixbufs
  + bgo#634338: Move GtkPaned documentation to inline comments
  + bgo#634339: Move GtkProgressBar documentation to inline
    comments
  + bgo#634340: Move GtkPageSetup documentation to inline comments
- Changes from version 2.91.3:
  + The scrollable interface has gained some extra properties
    to influence scrolling behaviour: [hv]scroll-policy
  + The size_request vfunc and signal have been deprecated and
    are no longer used inside GTK+ itself
  + GtkAssistant has added a custom page type that gives full
    control of button visibility
  + The homogeneous parameter has been removed from gtk_box_new
  + Bugs fixed: bgo#61852, bgo#576498, bgo#612611, bgo#633050,
    bgo#633216, bgo#633274, bgo#633374, bgo#633500.
  + Updated translations.
- Drop gtk3-fix-tests-build.patch: fixed upstream.
- Add gtk3-introspection-build-fix.patch to fix the introspection
  build, based on changes from git.
* Thu Oct 28 2010 vuntz@opensuse.org
- Update to version 2.91.2:
  + GtkApplication has been rewritten. It mostly relies on
    GApplication API now. Remaining functions include
    gtk_application_new() and gtk_window_set_application()
  + A GtkScrollable interface has been added and implemented by all
    scrollable widgets. GtkScrolledWindow has
    ::min-display-width/height properties to control the minimal
    size of the content area.
  + GtkComboBox changes:
  - Popups can be wider than the combo box itself
  - The deprecated GtkComboBoxEntry subclass has been removed
  - The deprecated combo box text convenience API has been
    removed
  + GtkRecentManager changes:
  - Store xbel file in XDG_USER_DATA
  - Add gtk_recent_info_create_app_info()
  - Add gtk_recent_info_get_gicon()
  - Coalesce multiple changes
  + GtkIconView allows tree models (ignoring anything below the
    root level)
  + GtkProgressBar, GtkSpinButton, GtkEntry and GtkCalendar no
    longer have their own input-output window
  + gtk_widget_hide_all() has been removed
  + GtkGrid: A legacy-free, height-for-width grid container
  + GDK gained a GdkRGBA color struct containing 4 doubles, and
    various GdkColor APIs have GdkRGBA counterparts now.
  + Bugs fixed: bgo#324899, bgo#438318, bgo#524304, bgo#617174,
    bgo#632381, bgo#632538, bgo#632539, bgo#632677, bgo#632736,
    bgo#632936.
  + Updated translations.
- Changes from version 2.91.1:
  + GTK+ can now add a resize grip to any window. The resize grip
    functionality in GtkStatusbar has been removed.
  + A very old bug in the handling of geometry widgets has been
    fixed, and a way to set geometry in terms of the geometry
    widget has been added: gtk_window_resize_to_geometry()
  + The GtkFileChooser now uses GSettings to store its settings
    instead of the keyfile ~/.config/gtk-2.0/gtkfilechooser.ini
  + GtkWrapBox has been dropped from GTK+ again. The widget will be
    available in libegg until clear use cases have been
    established.
  + GtkWidget now has horizontal and vertical expand flags, in the
    form of ::hexpand and ::vexpand properties. These flags are
    intended to obsolete most custom container-specific expand
    child properties, over time. Expandability is inherited up the
    widget hierarchy.
  + GtkComboBoxEntry has been deprecated in favor of a ::has-entry
    property on GtkComboBox.
  + The GtkComboBox text convenience API (gtk_combo_box_new_text(),
    etc) has been deprecated in favor of a new GtkComboBoxText
    class.
  + GtkLinkButton has gained a ::activate-link signal that can be
    used to suppress the default behavior.
  + The very outdated tutorial has been dropped from the GTK+
    distribution, and a new 'Getting started' section has been
    added to the API documentation that will accumulate tutorial
    material over time.
  + Bugs fixed: bgo#68668, bgo#313350, bgo#351247, bgo#423201,
    bgo#563002, bgo#612396, bgo#613728, bgo#628902, bgo#629722,
    bgo#629778, bgo#629955, bgo#630850, bgo#630900, bgo#631203,
    bgo#631311, bgo#631473, bgo#631475, bgo#631599, bgo#631719,
    bgo#631794, bgo#631976, bgo#632059, bgo#632095, bgo#632140,
    bgo#632218.
  + Updated translations.
- Drop gtk3-fix-badmatch-gnome-shell.patch: fixed upstream.
- Add gtk3-fix-tests-build.patch to fix the build in the tests.
- Change gtk3-data Recommends to Requires in libgtk-3_0-0 since it
  now contains a GSettings schemas, and GSettings schemas are
  definitely required at runtime.
- Use %%glib2_gsettings_schema_* macros for GSettings schemas
  installation.
- Ship README.multipress in gtk3-immodule-multipress.
* Fri Oct 15 2010 vuntz@opensuse.org
- Add gtk3-fix-badmatch-gnome-shell.patch to fix a crash in
  gnome-shell.
* Wed Oct 13 2010 vuntz@opensuse.org
- Change hicolor-icon-theme Recommends to a Requires in
  libgtk-3-0_0 since we need to make sure it gets installed, and
  libgtk-3-0_0 is low-level enough for this.
- Put comments that are in the scriptlets area of the spec file in
  "%%if 0" statement: if we don't do that, they actually end up in
  the scriplets and can even make them fail if the scriptlets were
  just "-p /sbin/ldconfig".
* Mon Oct 11 2010 vuntz@opensuse.org
- Split input methods in subpackages:
  + Create gtk3-immodule-amharic, gtk3-immodule-inuktitut,
    gtk3-immodule-multipress, gtk3-immodule-thai,
    gtk3-immodules-tigrigna, gtk3-immodule-vietnamese,
    gtk3-immodule-xim subpackages. For the modules that are useful
    for specific locales, we use a locale(gtk3:$locale) Provides to
    make those packages installed by default when the locale is
    used.
  + Add Recommends to libgtk-3_0-0 for gtk3-immodule-amharic,
    gtk3-immodule-inuktitut, gtk3-immodule-thai,
    gtk3-immodules-tigrigna, gtk3-immodule-vietnamese. This makes
    sense since this helps people discover them without having to
    look for them.
  + gtk3-immodule-multipress is not useful by default.
  + gtk3-immodule-xim is creating performance issues, so we don't
    want it by default.
  + Fix bnc#629995.
- Make the gtk3-data package own the directories of the themes,
  instead of just the files.
- Move the ferret module to the devel package: it's useful for
  tests, but not in general.
- Update the %%gtk3_immodule_post and %%gtk3_immodule_postun macros
  to use --update-cache instead of redirecting the output to a
  file. That's more solid.
- Remove gtk3-tools Requires(postun) in libgtk-3_0-0: it's not
  needed.
- Do not version the Recommends on the lang package.
- Update baselibs.conf to remove assumption in the scriptlets of
  the generated packages that they are 32bit packages.
- Use <prefix> in baselibs.conf since we use full paths there, and
  this is needed for x86 packages that put files in
  /emul/ia32-linux.
* Tue Oct  5 2010 vuntz@opensuse.org
- Update to version 2.91.0:
  + The rendering cleanup work has landed. This is a large change
    that affects many APIs.
  - All gtkstyle functions have been changed to take a cairo_t
    argument instead of a window + area.
  - GdkPixmap is gone. APIs that took pixmaps are being replaced
    by ones that take pixbufs or cairo surfaces, or regions
    (where pixmaps were used as masks). In background handling,
    pixmaps have been replaced by cairo patterns, see
    gdk_window_set_background_pattern().
  - GdkColormap is gone. It is replaced by visuals, see
    gtk_widget_set_visual().
  - The ::expose-event signal on GtkWidget has been replaced by a
    ::draw signal.
  - gtk_widget_get_snapshot() has been removed. Instead,
    gtk_widget_draw() can render a widget onto an cairo_t.
  + The GtkSizeRequest interface has been merged into GtkWidget,
    and GtkCellSizeRequest has been merged into GtkCellRenderer.
    The wrapper functions have been renamed to include 'preferred',
    e.g gtk_size_request_get_width() is now
    gtk_widget_get_preferred_width() and
    gtk_cell_size_request_get_width_for_height() is now
    gtk_cell_renderer_get_preferred_width_for_height().
  + GtkObject has been removed. The ::destroy signal has been moved
    to GtkWidget. At the same time, GtkWidgetFlags have been
    removed, they already had getters and setters anyway.
  + GtkWidget has gained generic alignment and padding properties:
    halign, valign, margin-left, margin-right, margin-top,
    margin-bottom. These can be used instead of container-specific
    child properties or GtkMisc and GtkAlignment widgets.
  + Container widgets can now let GTK+ handle border-width for
    them, using gtk_container_class_handle_border_width()
  + The GtkEditableClass struct has been renamed to
    GtkEditableInterface
  + Mouse wheel scrolling has been removed from GtkNotebook
  + The default policy for scrolled windows has been changed to
    'automatic'
  + Global url hooks have been removed from GtkAboutDialog and
    GtkLinkButton
  + The global window creation hook has been removed from
    GtkNotebook
  + The error handling in GDK has been modernized and avoids
    synchronizing X requests as much as possible
  + Fixed Bugs: bgo#323904, bgo#339745, bgo#468672, bgo#486839,
    bgo#601731, bgo#617316, bgo#621590, bgo#623664, bgo#628829,
    bgo#629177, bgo#629277, bgo#629387, bgo#629598, bgo#629608,
    bgo#629733, bgo#629748, bgo#629785, bgo#630033, bgo#630226,
    bgo#630520, bgo#630521, bgo#630532.
  + Updated translations.
- Drop gtk3-no-gtkapplication.patch: we have glib 2.27.0 now.
* Sat Sep 18 2010 vuntz@opensuse.org
- Update to version 2.90.7:
  + Various deprecated APIs have been removed:
  - the GtkWidget::draw-border style property
  - the GtkEntry::state-hint style property
  - the GtkTreeView::row-ending-details style property
  - the GtkRange::trough-side-details style property
  - the GtkRange::stepper-position-details style property
  - the GtkRange::activate-slider style property
  - the GTK_CALENDAR_WEEK_START_MONDAY option
  - the GtkFrame::shadow and GtkHandleBox::shadow properties
  - the GtkTextView::page-horizontally signal
  - the GDK_WINDOW_DIALOG window type
  - the GTK_SELECTION_EXTENDED selection mode
  - the GtkProgressBarOrientation, GtkAnchorType and
    GtkVisibility enumerations
  - GtkDialog separators, including the GtkDialog::has-separator
    property, including setter/getter, the
    GTK_DIALOG_NO_SEPARATOR flag and the
    GtkMessageDialog::use-separator style property
  - gtk_status_icon_set/get_blinking
  - gdk_window_set_deskrelative_origin
  - The GtkItem class has been removed. Its functionality has
    been merged into is sole subclass, GtkMenuItem
  + The GtkIconView::orientation property has been renamed to
    'item-orientation'
  + GtkProgressBar and GtkCellRendererProgress implement
    GtkOrientable now, and their 'orientation' property have been
    split into a 'orientation' property of type GtkOrientation and
    a boolean 'inverted' property
  + GDK no longer exports variables: gdk_threads_lock,
    gdk_threads_unlock, gdk_threads_mutex and gdk_display are no
    longer available
  + GTK no longer exports variables: gtk_major_version,
    gtk_minor_version, gtk_micro_version, gtk_binary_age,
    gtk_interface_age have been converted to functions.
    gtk_debug_flags has a getter and a setter. Misc. variables that
    had been exported by the semi-private text API have been
    removed.
  + All GDK keysym names have been changed from GDK_keysym to
    GDK_KEY_keysym; the previous names are still available in
    gdkkeysyms-compat.h.
  + GtkWrapBox is a new container, which distributes its children
    over multiple rows/columns
  + GTK+ now uses standard icon names when looking up stock icons
  + More widgets and cell renderers have been converted to support
    width-for-height: GtkCellRendererText, GtkAccelLabel,
    GtkCellView, GtkComboBox, GtkMenu, GtkMenuItem
  + Button boxes are now semi-homogeneous.
  + The directfb backend has been removed
  + Bugs fixed: bgo#77669, bgo#84188, bgo#414712, bgo#527499,
    bgo#528257, bgo#605186, bgo#614006, bgo#616401, bgo#626710,
    bgo#627028, bgo#627139, bgo#627445, bgo#627580, bgo#627643,
    bgo#627828, bgo#627843, bgo#627867, bgo#627912, bgo#628160,
    bgo#628308, bgo#628656, bgo#628807, bgo#628808, bgo#628884,
    bgo#628935, bgo#629110
  + Updated translations.
- Add gtk3-no-gtkapplication.patch: GApplication is gone in glib
  2.26, so we can't build GtkApplication. Remove this API for now
  to keep gtk3 building.
- Rebase gtk3-bnc130159-bgo319483-async-font-selection.patch.
- Update the %%post scriptlet to not fail if gtk3-tools is not
  installed. Also make it easier to read by using a %%define to
  use the right binary for gtk-query-immodules-3.0.
* Thu Sep  9 2010 vuntz@opensuse.org
- Remove pkgconfig(xrender) BuildRequires: it's not needed anymore.
- Rebase gtk3-bnc130159-bgo319483-async-font-selection.patch.
* Wed Sep  1 2010 dimstar@opensuse.org
- Update to version 2.90.6:
  + All drawing done by GTK+ itself has been ported from GDK
    drawing APIs to cairo
  + GtkExpander and GtkFrame now implement GtkSizeRequest
  + GtkExpander gained a ::label-fill property to make the label
    fill the entire horizontal space
  + Allow windows to be dragged by clicking on empty areas in
    menubars and toolbars
  + GtkAboutDialog can now refer to licenses using a ::license-type
    enumeration instead of embedding the license text
  + Deprecations and cleanups:
  - Remove GtkNotebookPage
  - Remove public struct members in many classes
  - Remove the GtkRecentManager::limit property
  - Remove all GDK drawing functions, ie gdk_draw_*. Use cairo
    instead.
  - Remove all GdkGC functions. Use cairo instead.
  - Remove all of GdkImage. Use cairo instead.
  - Remove all of GdkRGB. Use cairo instead.
  - Remove gdk_{bit,pix}map_create_from_data
  - GDK no longer depends on the render X extension
  + New accessors:
  - gdk_cursor_get_cursor_type
  - gdk_device_get_n_axes
  - gdk_display_is_closed
  - gtk_notebook_get_tab_[hv]border
  + New cairo-related APIs:
  - gdk_window_create_similar_surface
  - gdk_window_get_background_pattern
  + Bugs fixed: bgo#90935, bgo#97414, bgo#336225, bgo#554926,
    bgo#557263, bgo#579583, bgo#580291, bgo#596125, bgo#604391,
    bgo#605190, bgo#609264, bgo#611313, bgo#612919, bgo#614049,
    bgo#614443, bgo#615474, bgo#618327, bgo#621571, bgo#622658,
    bgo#623603, bgo#623865, bgo#624087, bgo#624224, bgo#624270,
    bgo#624333, bgo#624362, bgo#624367, bgo#624397, bgo#624432,
    bgo#624540, bgo#624687, bgo#624707, bgo#624779, bgo#625104,
    bgo#625235, bgo#625300, bgo#625416, bgo#625650, bgo#625655,
    bgo#625715, bgo#625953, bgo#626052, bgo#626276, bgo#626514
  + Updated translations.
- Patch gtk3-bnc130159-bgo319483-async-font-selection.patch has
  been marked as NEEDS-REBASE. According to bgo#319483, a lot has
  changed in the underlying libraries (fontconfig/pango) and
  re-evaluation of the patch might be required.
* Wed Aug 25 2010 vuntz@opensuse.org
- Add RPM macros (macros.gtk3) to make it easier to handle
  installation of a GTK+ 3 IM module.
* Wed Jul 21 2010 vuntz@opensuse.org
- Clean up package.
- Improve summaries and descriptions.
- Remove _with_gobject define, which isn't needed anymore.
- Add README.SUSE for biarch systems.
- Add baselibs.conf.
- Add missing cups-devel BuildRequires, as well as many explicit
  pkgconfig() BuildRequires.
- Rename gtk3 to gtk3-tools, and split some data files to
  gtk3-data.
- Make libgtk-3_0-0 provide gtk3, and add Requires for gtk3-tools
  for the post/postun scriptlets. Also add Recommends for branding,
  data and lang subpackages, as well as gvfs and hicolor-icon-theme
  for improved user experience.
- Add pyxml Requires to devel package, since it's needed by
  gtk-builder-convert.
- Remove hack on gtk-query-immodules-3.0 since there's no need to
  make it parallel installable, and instead add back the change
  from gtk2 needed for biarch, where gtk-query-immodules-3.0-64 is
  used on 64bit systems.
- Move %%{_sysconfdir}/gtk-3.0/im-multipress.conf to libgtk-3_0-0
  and gtk-builder-convert-3.0 to devel subpackage.
- Add patches based on the gtk2 package:
  + gtk3-GTK_PATH64.patch: contains the remaining part of
    gtk64.patch, to use the GTK_PATH64 environment variable on
    64bit systems
  + gtk3-path-local.patch: based on gtk-path-local.patch
  + gtk3-bnc129753-localize-font-style-name.patch: based on
    bugzilla-129753-gtk+-2.8.9-localize-font-style-name.diff
  + gtk3-bnc130159-bgo319483-async-font-selection.patch: based on
    gtk2-bnc130159-bgo319483-async-selection-in-gtk-font-selection.diff
- Add gnome-patch-translation support because of
  gtk3-bnc129753-localize-font-style-name.patch.
- Comments on patches not brought from the gtk2 package:
  + bugzilla-131498-allow-xim-for-all-languages.patch: this was a
    patch to make it possible to set input to Japanese characters
    on 32bit applications running on a 64bit system. This is
    needed because somehow, scim-32bit is not installed by default.
    The right fix is to have scim-32bit installed by default, then.
* Wed Jul  7 2010 dimstar@opensuse.org
- Initial package of GTK+ 3.0
